#
# spec file for package mutter
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with profiler

%define api_major 16
%define api_minor 0
%define libmutter libmutter-%{api_major}-%{api_minor}

Name:           mutter
VCS: https://src.suse.de/SLFO-pool/mutter#85adeaec05b585661970a6ed1ecaa14b1d9aa4f2b5f06f5fb24c8e399eca9fee
Version:        48.0+5
Release:        160000.2.3
Summary:        Window and compositing manager based on Clutter
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
URL:            https://www.gnome.org
Source0:        %{name}-%{version}.tar.zst
Source1:        gvdb-0.gitmodule.tar.zst

# PATCH-FIX-UPSTREAM mutter-disable-cvt-s390x.patch bsc#1158128 fcrozat@suse.com -- Do not search for cvt on s390x, it doesn't exist there
Patch1:         mutter-disable-cvt-s390x.patch
# PATCH-FIX-OPENSUSE mutter-window-actor-Special-case-shaped-Java-windows.patch -- window-actor: Special-case shaped Java windows
Patch2:         mutter-window-actor-Special-case-shaped-Java-windows.patch
# PATCH-FIX-OPENSUSE 0001-Revert-clutter-actor-Cache-stage-relative-instead-of.patch glgo#GNOME/mutter#3302 bsc#1219546 alynx.zhou@suse.com -- Fix partial update on VT switch
Patch4:         0001-Revert-clutter-actor-Cache-stage-relative-instead-of.patch
#PATCH-FEATURE-OPENSUSE mutter-implement-text-input-v1.patch glgo#GNOME/mutter!3751 bsc#1219505 alynx.zhou@suse.com -- Allow input method to work in Wayland Chromium
Patch5:         mutter-implement-text-input-v1.patch
# PATCH-FIX-UPSTREAM 0001-cursor-Unify-prepare_func-for-shape-cursors.patch https://gitlab.gnome.org/GNOME/mutter/-/issues/3975 -- Solves the problem of changing the size of the cursor in gtk applications on HiDPI displays.
Patch6:         0001-cursor-Unify-prepare_func-for-shape-cursors.patch

## SLE-only patches start at 1000
# PATCH-FEATURE-SLE mutter-SLE-bell.patch FATE#316042 bnc#889218 idonmez@suse.com -- make audible bell work out of the box.
Patch1000:      mutter-SLE-bell.patch

BuildRequires:  Mesa-libGLESv3-devel
BuildRequires:  fdupes
%ifnarch s390x
BuildRequires:  (libxcvt if xorg-x11-server > 21)
%endif
BuildRequires:  meson >= 1.3.0
BuildRequires:  pkgconfig
BuildRequires:  python3-argcomplete
BuildRequires:  python3-docutils
BuildRequires:  xorg-x11-server
BuildRequires:  xvfb-run
BuildRequires:  pkgconfig(bash-completion)
BuildRequires:  pkgconfig(cairo) >= 1.10.0
BuildRequires:  pkgconfig(colord) >= 1.4.5
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(fribidi) >= 1.0.0
BuildRequires:  pkgconfig(gbm) >= 21.3
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.69.0
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(glib-2.0) >= 2.81.1
BuildRequires:  pkgconfig(gnome-desktop-4)
BuildRequires:  pkgconfig(gnome-settings-daemon)
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 0.9.5
BuildRequires:  pkgconfig(graphene-gobject-1.0)
BuildRequires:  pkgconfig(gsettings-desktop-schemas) >= 47.beta
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(gudev-1.0) >= 232
BuildRequires:  pkgconfig(lcms2) >= 2.6
BuildRequires:  pkgconfig(libcanberra-gtk3) >= 0.26
BuildRequires:  pkgconfig(libdisplay-info)
BuildRequires:  pkgconfig(libdrm) >= 2.4.118
BuildRequires:  pkgconfig(libeis-1.0) >= 1.3.901
BuildRequires:  pkgconfig(libinput) >= 1.26.0
BuildRequires:  pkgconfig(libpipewire-0.3) >= 1.2.0
BuildRequires:  pkgconfig(libstartup-notification-1.0) >= 0.7
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libudev) >= 228
BuildRequires:  pkgconfig(libwacom) >= 0.13
BuildRequires:  pkgconfig(pango) >= 1.46.0
BuildRequires:  pkgconfig(pixman-1) >= 0.42
BuildRequires:  pkgconfig(sm)
%if %{with profiler}
BuildRequires:  pkgconfig(sysprof-6)
BuildRequires:  pkgconfig(sysprof-capture-4) >= 3.37.2
%endif
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(upower-glib) >= 0.99.0
BuildRequires:  pkgconfig(wayland-eglstream)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.36
BuildRequires:  pkgconfig(wayland-server) >= 1.23
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(x11-xcb)
BuildRequires:  pkgconfig(xau)
BuildRequires:  pkgconfig(xcb-randr)
BuildRequires:  pkgconfig(xcomposite) >= 0.4
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes) >= 3
BuildRequires:  pkgconfig(xi) >= 1.7.4
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xkbcommon) >= 0.4.3
BuildRequires:  pkgconfig(xkbcommon-x11)
BuildRequires:  pkgconfig(xkbfile)
BuildRequires:  pkgconfig(xkeyboard-config)
BuildRequires:  pkgconfig(xrandr) >= 1.5.0
BuildRequires:  pkgconfig(xrender)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(xwayland)
Requires:       gnome-settings-daemon
Provides:       windowmanager
# Obsolete the now private typelib.
Obsoletes:      typelib-1_0-Meta-3_0
# libmutter-<n>-0 and mutter-data were folded into the main package after GNOME 40
# The library is not realy usable decoupled from the mutter version, and offering to
# parallel install it only gives a false sense of capability. A full GNOME Stack
# has a matching gnome-shell, mutter, libmutter version.
Obsoletes:      libmutter-8-0 <= %{version}
# mutter-data was essentilly hard-required at the same version, as mutter requires
# libmutter-<n>-0 (which has a soname bump at every major version change), libmutter
# required mutter-data >= %%{version} and mutter-data required mutter=%%{version}.
Obsoletes:      mutter-data <= %{version}

%description
Mutter is a window and compositing manager based on Clutter, forked
from Metacity.

%package devel
Summary:        Development files for mutter, a window and compositing manager
Group:          Development/Libraries/GNOME
Requires:       %{name} = %{version}

%description devel
This subpackage contains libraries and header files for developing
applications that want to make use of the mutter library.

%lang_package

%prep
%autosetup -N
pushd subprojects
tar xf %{SOURCE1}
mv gvdb-0.gitmodule gvdb
popd
%if 0%{?is_opensuse}
%autopatch -p1 -M 999
%else
# SLE-only patches (apply all patches).
%autopatch -p1
%endif

%build
%meson \
	-Degl_device=true \
	-Dwayland_eglstream=true \
	-Dcogl_tests=false \
	-Dclutter_tests=false \
	-Dtests=disabled \
	-Dinstalled_tests=false \
	-Dxwayland_initfd=auto \
%if %{with profiler}
	-Dprofiler=true \
%else
	-Dprofiler=false \
%endif
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_prefix}

%ldconfig_scriptlets

%files
%license COPYING
%doc NEWS
%{_mandir}/man1/mutter.1%{?ext_man}
%{_bindir}/mutter
%{_libexecdir}/mutter-restart-helper
%{_libexecdir}/mutter-x11-frames
%{_udevrulesdir}/61-mutter.rules

# These so files are not split out since they are private to mutter
%{_libdir}/mutter-%{api_major}/libmutter-clutter-%{api_major}.so.*
%{_libdir}/mutter-%{api_major}/libmutter-cogl-%{api_major}.so.*
%{_libdir}/mutter-%{api_major}/libmutter-mtk-%{api_major}.so.*
%{_libdir}/mutter-%{api_major}/plugins/libdefault.so

# These typelibs are not split out since they are private to mutter
%{_libdir}/mutter-%{api_major}/Clutter-%{api_major}.typelib
%{_libdir}/mutter-%{api_major}/Cogl-%{api_major}.typelib
%{_libdir}/mutter-%{api_major}/Meta-%{api_major}.typelib
%{_libdir}/mutter-%{api_major}/Mtk-%{api_major}.typelib

%{_libdir}/libmutter-%{api_major}.so.*
%dir %{_libdir}/mutter-%{api_major}/
# users of libmutter need this directory
%dir %{_libdir}/mutter-%{api_major}/plugins/

# Do not depend on g-c-c just for a directory
%dir %{_datadir}/gnome-control-center
%dir %{_datadir}/gnome-control-center/keybindings
%{_datadir}/gnome-control-center/keybindings/50-mutter-windows.xml
%{_datadir}/gnome-control-center/keybindings/50-mutter-navigation.xml
%{_datadir}/gnome-control-center/keybindings/50-mutter-system.xml
%{_datadir}/gnome-control-center/keybindings/50-mutter-wayland.xml
%{_datadir}/GConf/gsettings/mutter-schemas.convert
%{_datadir}/glib-2.0/schemas/org.gnome.mutter.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.mutter.wayland.gschema.xml

%{_bindir}/gdctl
%{_datadir}/bash-completion/completions/gdctl
%{_mandir}/man1/gdctl.1%{ext_man}

%files devel
%{_includedir}/mutter-%{api_major}/
%{_libdir}/mutter-%{api_major}/Meta-%{api_major}.gir
%{_libdir}/mutter-%{api_major}/Clutter-%{api_major}.gir
%{_libdir}/mutter-%{api_major}/Cogl-%{api_major}.gir
%{_libdir}/mutter-%{api_major}/Mtk-%{api_major}.gir
%{_libdir}/mutter-%{api_major}/libmutter-clutter-%{api_major}.so
%{_libdir}/mutter-%{api_major}/libmutter-cogl-%{api_major}.so
%{_libdir}/mutter-%{api_major}/libmutter-mtk-%{api_major}.so
%{_libdir}/libmutter-%{api_major}.so
%{_libdir}/pkgconfig/libmutter-%{api_major}.pc
%{_libdir}/pkgconfig/mutter-clutter-%{api_major}.pc
%{_libdir}/pkgconfig/mutter-cogl-%{api_major}.pc
%{_libdir}/pkgconfig/mutter-mtk-%{api_major}.pc

%files lang -f %{name}.lang

%changelog
* Fri Mar 21 2025 dead_mozay@opensuse.org
- Add 0001-cursor-Unify-prepare_func-for-shape-cursors.patch.
  Solves the problem of changing the size of the cursor in gtk
  applications on HiDPI displays.
* Thu Mar 20 2025 bjorn.lie@gmail.com
- Update to version 48.0+5:
  * Revert "ci: Disable container building temporarily"
  * Revert "ci: Disable sysext temporarily"
  * tests: Raise the timeout on monitor-unit from 1 minute to 5
    minutes
  * Revert "onscreen/native: Account for all posted frames"
  * kms/impl-device: Always catch pending KMS update in
    _schedule_process
* Tue Mar 18 2025 xiaoguang.wang@suse.com
- Drop mutter-SLE-relax-some-constraints-on-CSD-windows.patch:
  sle-classic is not supported.
* Sun Mar 16 2025 bjorn.lie@gmail.com
- Update to version 48.0:
  + Improve wp_color_management_v1 support
  + Fix cursor brightness not following HDR luminance setting
  + Fix black screen with nvidia driver
  + Adjust presentation time feedback for triple buffering
  + Fix broken overlay cursor damage tracking
  + Add support for Kana and Compose USB HID LEDs
  + Fix frequent frame skips under some circumstances
  + Fix random output freezes
  + Fixed crashes
  + Misc. bug fixes and cleanups
  + Updated translations.
- Rebase patches with quilt and simplyfy conditionals applying
  patches.
* Fri Mar 14 2025 mgorse@suse.com
- Drop use of sle_version in favor of is_opensuse and suse_version.
  Sle_version is no longer used in SLE 16.
* Wed Mar  5 2025 bjorn.lie@gmail.com
- Update to version 48.rc:
  + Support presentation-time version 2
  + Honor wl_surface.offset on cursor surfaces
  + Allow to activate the overview with either Super key
  + Implement dynamic triple buffering
  + Implement the cursor_shape_v1 protocol
  + Improve window placement when centering new windows
  + Fix sharable surfaces with nvidia as primary
  + Default to sticky drag lock
  + Implement a11y keyboard monitoring support
  + Support wp_color_management_v1 protocol
  + Fix dma-bufs support for headless sessions
  + Allow to mark monitors for lease via gdctl
  + Fixed confused IM focus state after closing some windows
  + Center new windows by default
  + Add output luminance settings
  + Do not use triple buffering when update time fits into refresh
    interval
  + Fixed crashes
  + Misc. bug fixes and cleanups
  + Updated translations.
* Wed Mar  5 2025 bjorn.lie@gmail.com
- Update to version 48.beta:
  + Update cursors via the frame clock in virtual monitors
  + Synchronize device enabled state when adding device
  + Do not use modifiers if surface should be sharable
  + Add accessible state tracking in Clutter
  + Introduce GNOME Display Control (gdctl) utility
  + Fix notifying shell about modifier-only keyboard layout
    switches
  + Configure HDR via DisplayConfig D-Bus API
  + Fixed crashes
  + Misc. bug fixes and cleanups
- Add pkgconfig(bash-completion), python3-argcomplete and
  python3-docutils BuildRequires, new dependencies.
* Wed Mar  5 2025 bjorn.lie@gmail.com
- Update to version 48.alpha:
  + gwakeup: Reduce wake-ups to only first item in queue
  + x11: Reduce chances XPending does recvmsg() syscall
  + Fix grabbing tablet devices
  + Improve color-management support
  + Fix misplaced windows and random resizes on scaled monitors
  + Improve detecting preferred primary devices
  + Merge CoglPango into Clutter
  + Always depend on libdisplay-info for EDID parsing
  + Fix explicit sync with virtual monitors w/o pipewire streams
  + Introspect `event` parameter in MetaKeyHandlerFunc
  + Allow to configure monitors as for-lease
  + Add support for system bell protocol
  + Add `configure` signal to allow tweaking original window
    configuration
  + Default to high thread instead of realtime priority for KMS
    thread
  + Add built-in renderdoc support
  + Fix maximized X11 when using native Xwayland scaling
  + Implement xdg-toplevel-drag-v1 protocol
  + Fix blank screen in remote headless sessions
  + Query screen cast format modifiers via CoglRenderer
  + Also request high priority secondary EGL context
  + Fix Xwayland DND coordinates when using fractional scaling
  + Remove ClutterImage
  + Fix applying initial _NET_WM_WINDOW_OPACITY on Xwayland
  + Implement wp_viewport support for cursor surfaces
  + Improve input → output latency of cursor movements
  + Make font-rendering support optional
  + Improve frame rate on monitors attached to secondary GPUs in
    copy mode
  + Add support for commit-timing-v1 and fifo-v1 protocols
  + Use BT709 coefficients and limited range for YUV conversion by
    default
  + Send preferred scales to all surface roles
  + Fixed crashes
  + Misc. bug fixes and cleanups
- Stop passing libdisplay_info=true to meson setup, no longer
  needed nor recognized.
- Rebase patches.
- Disable patches needing rebase:
  + 0001-Revert-clutter-actor-Cache-stage-relative-instead-of.patch
  + mutter-implement-text-input-v1.patch
- Bump api_major to 16 following upstream changes.
* Tue Mar  4 2025 bjorn.lie@gmail.com
- Update to version 47.6:
  + Support presentation-time version 2
  + Honor wl_surface.offset on cursor surfaces
  + Fix sharable surfaces with nvidia as primary
  + Fixed crash
* Wed Feb  5 2025 bjorn.lie@gmail.com
- Update to version 47.5:
  + Synchronize device enabled state when adding device
  + Do not use modifiers if surface should be sharable
  + Fix notifying shell about modifier-only keyboard layout
    switches
  + Fixed crashes
  + Misc. bug fixes and cleanups
* Mon Jan 13 2025 bjorn.lie@gmail.com
- Update to version 47.4:
  + Use BT709 coefficients and limited range for YUV conversion by
    defaults
  + Also request high priority secondary EGL context
  + Fix Xwayland DND coordinates when using fractional scaling
  + Fix applying initial _NET_WM_WINDOW_OPACITY on Xwayland
  + Implement wp_viewport support for cursor surfaces
  + Improve input → output latency of cursor movements
  + Improve frame rate on monitors attached to secondary GPUs in
    copy mode
  + Send preferred scales to all surface roles
  + Misc. bug fixes and cleanups
  + Updated translations.
* Fri Dec  6 2024 bjorn.lie@gmail.com
- Update to version 47.3:
  + Fix maximized X11 when using native xwayland scaling
  + Fix blank screen in remote headless sessions
  + Fix touch-triggered popups being cancelled too early
  + Fix pointer cursor during compositor grabs
  + Fixed crash
* Mon Nov 25 2024 bjorn.lie@gmail.com
- Update to version 47.2:
  + Fix warping pointer after releasing pointer constraints
  + Default to high thread instead of realtime priority for KMS
    thread
  + Avoid CPU stalls with NVIDIA secondary GPUs with
    directly-attached monitors
  + Fix updating cursor immediately when starting window drag
  + Add pipeline hooks to user program pipelines
  + Prefer GPUs with built-in panels connected as primary GPU
  + Fix cursor glitches when using virtual monitors
  + Ensure frame events are sent for cursor surfaces
  + Allow BGRX8888 format on big endian
  + Fix touchscreen drag-and-drop on wayland
  + Fixed crashes
  + Misc. bug fixes and cleanups
* Tue Oct 29 2024 bjorn.lie@gmail.com
- Update to version 47.1+3:
  * wayland/pointer-constraints: Warp pointer after destroying
    resource
  * Updated translations.
* Sat Oct 19 2024 bjorn.lie@gmail.com
- Update to version 47.1:
  + gwakeup: Reduce wake-ups to only first item in queue
  + x11: Reduce chances XPending does recvmsg() syscall
  + Fix grabbing tablet devices
  + Fix misplaced windows and random resizes on scaled monitors
  + Fix explicit sync with virtual monitors w/o pipewire streams
  + Improve detecting preferred primary devices
  + Fixed crashes
  + Misc. bug fixes and cleanups
  + Updated translations.
* Thu Oct 17 2024 bjorn.lie@gmail.com
- Update to version 47.0+24:
  * stage-impl: Ensure that a sync object is created in headless mode
  * backends/x11: Avoid potential crash in pad_switch_mode
  * display: Do not crash attempting to display OSD for unknown
    Wacom device
  * wayland/drm-lease: Do not add connector twice on lease
    disappeared
  * wayland/drm-lease: Hold device fd when listing leases
* Thu Sep 26 2024 bjorn.lie@gmail.com
- Update to version 47.0+19:
  * Revert "window/wayland: Use scale for configured rect in
    configuration"
  * cogl/gles: Don't initialize glGetStringi
  * cogl/gl: Don't initialize potentially unused/unsupported
    functions
  * cogl: Don't _cogl_context_get_gl_extensions before
    check_gl_version
  * cogl/egl: Restore support for EGL 1.4
  * wayland/tablet-tool: Fix grabbing tablet devices
  * cogl/gles: Use unsized internal formats for RGB8, RGBA8 in GLES
    2.0
  * wayland/color-management: Fix SIGSEGV on dispose
  * x11: Reduce chances XPending does recvmsg() syscall
  * gwakeup: Reduce wake-ups to only first item in queue
  * window/x11: Use g_autoslist (MetaStrut) in
    meta_window_x11_update_struts
  * Updated translations.
* Mon Sep 16 2024 bjorn.lie@gmail.com
- Update to version 47.0:
  + Fix resizing of electron windows
  + Fix using modifiers on multi-GPU setups
  + Don't override externally set tablet calibration
  + Add experimental support for xdg-session-manager-v1 protocol
  + Fixed crashes
  + Misc. bug fixes and cleanups
  + Updated translations.
- Add gvdb submodule and add as source.
* Mon Sep 16 2024 dimstar@opensuse.org
- Update to version 47.rc+40:
  + window/xwayland: Handle arithmetics close to the int limits.
* Mon Sep 16 2024 mgorse@suse.com
- Update version requirements to correspond with the source.
* Mon Sep 16 2024 bjorn.lie@gmail.com
- Update to version 47.rc (bsc#1223393):
  + Add experimental color management protocol support
  + Merge Cally into Clutter
  + Fix drag and drop between X11 and wayland clients
  + Fix drag and drop from grabbing popups
  + Fix EGLDevice support
  + Improve cursor smoothness under load
  + Fix frozen cursor on some hybrid machines
  + Fix touch window dragging with pointer lock enabled
  + Store the layout mode in monitor config
  + Fix keys sometimes getting stuck after using global shortcut
  + Fix propagating tablet device removals to clients
  + Fix tablet input in maximized windows
  + Reduce damage on window movement
  + Install mutter tests
  + Use libadwaita for server-side decorations on GNOME
  + Fix frozen cursor after suspend
  + Let scaling-aware Xwayland clients scale themselves
  + Add initial PipeWire explicit sync support
  + Trace damage reason in sysprof
  + Expose new backlight API to gnome-settings-daemon
  + Fixed crashes
  + Plugged leaks
  + Misc. bug fixes and cleanups
  + Updated translations.
* Mon Sep 16 2024 bjorn.lie@gmail.com
- Update to version 47.beta:
  + Fix visibility of Xwayland windows
  + Add plumbing for transforming color state
  + Build and publish GNOME OS systemd-sysext extensions
  + Implement support for tablet tool keybindings and actions
  + Add support for tablet tool pressure ranges
  + Improve sticky behavior with transient dialogs
  + Improve placement and focus logic with always-on-top windows
  + Expose Orientationmanager to introspection
  + Recover from secondary GPU update failures
  + Plugged leaks
  + Misc. bug fixes and cleanups.
- Rebase patches with quilt.
- Bump api_major to 15 following upstream changes.
* Sun Sep 15 2024 bjorn.lie@gmail.com
- Update to version 45.5:
  + Fix drag and drop between X11 and wayland clients
  + Fix drag and drop from grabbing popups
  + Fix EGLDevice support
  + Fix frozen cursor on some hybrid machines
  + Fix touch window dragging with pointer lock enabled
  + Fix propagating tablet device removals to clients
  + Fix tablet input in maximized windows
  + Reduce damage on window movement
  + Fix frozen cursor after suspend
  + Fix using modifiers on multi-GPU setups
  + Fixed crashes
  + Misc. bug fixes and cleanups
  + Updated translations.
* Fri Aug  9 2024 mgorse@suse.com
- Fix build if sle_version is defined: Patch3 no longer exists, and
  add back Patch4 for SLE builds that was mistakenly removed in
  last change.
* Mon Aug  5 2024 dimstar@opensuse.org
- Update to version 46.4:
  + Fix nested popovers on wayland.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Drop mutter-fix-x11-restart.patch: fixed upstream.
* Tue Jul 30 2024 mgorse@suse.com
- Rebase mutter-SLE-relax-some-constraints-on-CSD-windows.patch.
* Thu Jul  4 2024 bjorn.lie@gmail.com
- Update to version 46.3.1:
  + Fix visibility of Xwayland windows
  + Misc. bug fixes
* Sun Jun 30 2024 bjorn.lie@gmail.com
- Update to version 46.3:
  + Fix performance issues with second virtual monitor
  + Fix missing unmap animation of some windows
  + Fix placement/resizing regression
  + Fix possible out of sync primary selections and clipboard
  + Fix ibus support in popups
  + Fix hardware accelerated rendering when headless
  + Add back support for legacy X11 cursor themes
  + Fix preedit offsets
  + Use character offsets to specify surrounding text
  + Don't force titlebar on screen on all interactive resizes
  + Fixed crashes
  + Misc. bug fixes and cleanups
  + Updated translations.
- Rebase patches with quilt.
* Mon May 27 2024 dimstar@opensuse.org
- Update to version 46.2:
  + Fix hardware cursor with non-atomic KMS drivers.
  + Fix night light state getting stuck on monitor changes.
  + Fix sending preferred buffer transform.
  + Fix key press events with immediate release being ignored.
  + Fix unsetting clipboard on screen lock.
  + Fix wrong input region of undecorated X11 windows.
  + Fix windows potentially shrinking unexpectedly on configure.
  + Fix popup menus sometimes closing immediately.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
  + Updated transltions.
* Fri May 17 2024 alynx.zhou@suse.com
- Add mutter-implement-text-input-v1.patch: This allows input
  method to work in Chromium/Electron-based apps with Wayland Ozone
  platform, which only has text-input-v1 support
  (glgo#GNOME/mutter!3751, bsc#1219505).
* Wed May  1 2024 dimstar@opensuse.org
- Update to version 46.1:
  + Implement linux-drm-syncobj-v1 (bsc#1219718).
  + Fix input lag on X11 nvidia.
  + Fix scanout on secondary GPUs.
  + Don't apply max-render-time to secondary GPUs.
  + Fix reusing single-pixel buffers.
  + Improve scanout candidate check.
  + Always use logical pixels for.
  + Fix modifiers getting stuck during grabs.
  + Fix night-light on displays without EDID.
  + Fix secondary GPU acceleration with nvidia driver.
  + Fix some XWayland clients being partially click-through.
  + Fix initial suspended state.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Drop mutter-fix-front-buffer-lock.patch and
  0001-Revert-clutter-stage-Avoid-queueing-stage-updates-wh.patch:
  fixed upstream.
* Sun Apr 28 2024 xiaoguang.wang@suse.com
- Add 0001-Revert-clutter-stage-Avoid-queueing-stage-updates-wh.patch:
  Reverting commit 261f516a to fix black screen on Xorg when logging
  in or logging out (glgo#GNOME/mutter#3452 bsc#1222612).
* Mon Apr  8 2024 alynx.zhou@suse.com
- Add mutter-fix-front-buffer-lock.patch: Fix front buffer lock
  error by an unnecessary ensure_fb_id call
  (glgo#gnome/mutter!3674, bsc#1222409).
* Tue Mar 19 2024 dimstar@opensuse.org
- Update to version 46.0:
  + Fix duplicate scroll events over libei.
  + Fix window menu with mouse button modifier.
  + Fix caret offset in accessible event.
  + Fix handling of scroll events for mice.
  + Use timerfd for clock timing.
  + Advertise support for BGRA for all screencast types.
  + Add support for preferred_buffer_scale/transform.
  + Use memfd to store selection data.
  + Fix globally active input focus.
  + Call malloc_trim() after loading background image.
  + Fix dynamic max render time sometimes getting stuck on constant
    framerate.
  + Introduce base of new gesture framework.
  + Work around windows missing work area changes.
  + Fix black screen with some drivers.
  + Improve login screen <-> session transition.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Mon Mar 18 2024 dimstar@opensuse.org
- Update to version 46.rc:
  + screencast: Renegotiate when DMABUF allocation fails.
  + Unify wayland pointer- and keyboard grab mechanisms.
  + Add modifier-aware screencasting support.
  + Fix synchronization issue on Xorg.
  + Send fractional_scale event immediately on window creation.
  + wayland/client: Add make_dock() method.
  + Fix gray area on top of some X11 fullscreen windows.
  + Stick dragged windows to the right anchor point.
  + cally/text: Fix emission of `text_caret_moved` signal.
  + clutter/text: Fix minimum height calculation.
  + Add experimental support for variable refresh rate.
  + Expose the minimum refresh rate of monitors through D-Bus.
  + Use "default" cursor for moving windows.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Rebase mutter-window-actor-Special-case-shaped-Java-windows.patch
  (resync with Fedora).
* Sun Mar 17 2024 dimstar@opensuse.org
- Update to version 46.beta:
  + Implement mouse cursor hotspots for KMS atomic.
  + Improve project and development documentation.
  + Refactor wayland focus management.
  + Remove experimental rt-scheduler feature.
  + Remove ClutterCanvas.
  + Consider reduced blanking with lower pixelclock.
  + Fix centering non-modal transients over parent.
  + Allow XKB model to be configured.
  + Enable KMS deadline timer after a VT switch if it was
    inhibited.
  + Prepare for variable refresh rate support.
  + Restore IM state flushing before handling key events.
  + Swap stylus buttons to match traditional order.
  + Fix handling of pad ring wrap arounds.
  + Support Broadcast RGB/RGB range KMS property.
  + Ensure all planes support EGL config format.
  + Handle Alt modifier in pad actions.
  + Store eraser and stylus tools separately.
  + Disambiguate output mapped to tablet with connector name.
  + Fix lost keyboard focus after dismissing popups.
  + Implement direct scanout for cropped and scaled surfaces.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
* Sat Mar 16 2024 dimstar@opensuse.org
- Update to version 46.alpha:
  + wayland: Send keyboard modifiers after the enter event.
  + wayland/client: Add make_desktop() method.
  + Add a target workspace to raise_and_make_recent().
  + clutter: Drop cairo helpers.
  + cogl: Port away from CoglObject.
  + mtk: Add a Region type.
  + Propagate focus appearance to all ancestors.
  + Ignore locked modifiers in keybinding machinery.
  + Fix disabling check-alive timeout.
  + Drop ClutterContainer interface.
  + Improve sloppy and mouse focus modes.
  + Sync geometry only when window is mapped.
  + Improve repick due to transform changes.
  + Fix tablets on X11 having the wrong device.
  + Disable HW cursor when inhibited by backend.
  + screencast: Bring back blitting.
  + backends/native: Try 10 bpc formats.
  + Fix forcing EGLStream with NVIDIA proprietary driver.
  + screencast: Add ability to stop streams.
  + Use standard cursor names from CSS specification.
  + Avoids over-synchronization due to client reads.
  + Add more profiling instrumentation.
  + Allow specifyig the layout manager for an actor type.
  + Fix handling of relative mode for tablets.
  + Dynamically assign hardware planes during configuration.
  + Simplify X11 focus management.
  + background: Fix background color around image.
  + text-input: Use correct offsets in delete_surrounding_text.
  + Add wayland shm YCbCr support.
  + Set a minimum guessed scale.
  + Fix building without native backend.
  + Fix occasional artifacts at top of X11 fullscreen windows.
  + Add documentation for building, running and debugging.
  + Improve tablet pressure curve calculation.
  + Fixed crashes.
  + Plugged leaks.
  + Updated translations.
- Bump api_major to 14 following upstream changes.
- Add pkgconfig(pixman-1) BuildRequires: new dependency.
- Drop pkgconfig(json-glib-1.0) BuildRequires: no longer needed.
- Drop mutter-fix-text-input-delete-surrounding.patch: fixed
  upstream.
* Fri Mar 15 2024 alynx.zhou@suse.com
- Add 0001-Revert-clutter-actor-Cache-stage-relative-instead-of.patch:
  This leads into partial update while switching VT (from TTY to
  GNOME) on X11 session with fbdev driver used (
  glgo#GNOME/mutter#3302, bsc#1219546).
* Thu Feb  1 2024 alynx.zhou@suse.com
- Drop mutter-SLE-bsc984738-grab-display.patch: It blocks non-CSD
  apps with GNOME 45, and the latest LTS Oracle Installer works
  fine without it, the original bug is not a problem (bsc#1218935).
* Wed Jan 24 2024 eugenio.paolantonio@suse.com
- mutter-SLE-bsc984738-grab-display.patch:
  * Temporary disable this SLE-only patch as it makes mutter
    45 lock-up on non-CSD apps (bsc#1218935)
* Tue Jan 23 2024 eugenio.paolantonio@suse.com
- Rebase mutter-disable-cvt-s390x.patch for mutter 45.x.
* Wed Jan 10 2024 dimstar@opensuse.org
- Update to version 45.3:
  + Fix handling of relative mode for tablets.
  + Fix forcing EGLStream with NVIDIA proprietary driver.
  + Sync geometry only when window is mapped.
  + Improve repick due to transform changes.
  + wayland/client: Add make_desktop() method.
  + Fix occasional artifacts at top of X11 fullscreen windows.
  + background: Fix background color around image.
  + Fixed crashes.
  + Plugged leaks.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Thu Dec 21 2023 alynx.zhou@suse.com
- Add mutter-fix-text-input-delete-surrounding.patch: text-input-v3
  requrires byte based offset but Clutter uses char based offset
  for delete_surrounding_text, fix it by converting before passing
  arguments (glgo#GNOME/mutter#2146, glgo#GNOME/mutter!2712).
* Mon Dec 18 2023 alynx.zhou@suse.com
- Add mutter-fix-x11-restart.patch: glgo#GNOME/mutter!2445 breaks
  restarting under x11 accidentally because it redirects subwindows
  after redirecting windows, this patch fix it by redirecting
  subwindows first (glgo#GNOME/gnome-shell#7050,
  glgo#GNOME/mutter!3329).
* Thu Dec  7 2023 dimstar@opensuse.org
- Update to version 45.2:
  + Disable HW cursor when inhibited by backend.
  + Fix disabling check-alive timeout.
  + Propagate focus appearance to all ancestors.
  + Fix tablets on X11 having the wrong device.
  + Fixed crash.
  + Updated translations.
* Sun Dec  3 2023 yfjiang@suse.com
- Rebase mutter-SLE-bsc984738-grab-display.patch.
* Tue Nov 28 2023 dimstar@opensuse.org
- Use %%patch -p N instead of deprecated %%patchN.
* Wed Nov  1 2023 bjorn.lie@gmail.com
- Update to version 45.1:
  + Fix filtering keybinding events in presence of grabs
  + Fix direct scanout support when using integer scaling
  + Fix capitalization of some keys when caps lock is on
  + Fix vsync regression
  + Fix visibility of software cursors when using direct scanout
  + Fix artifacts at the bottom of some surfaces
  + Discard monitor configs with fractional scale when unusable
  + Apply track point settings
  + xwayland: Enable XDG portal only when not nested
  + Inhibit real-time scheduling when mode setting
  + Don't delay frame updates after idle period
  + Fix running Xwayland in headless setup with nvidia driver
  + wayland: Send keyboard modifiers after the enter event
  + Fixed crashes
  + Misc. bug fixes and cleanups
  + Updated translations.
* Thu Oct 26 2023 bjorn.lie@gmail.com
- Update to version 45.0+61:
  + backend:
  - Introduce helpers for turning from/to clutter/evdev buttons
  - Use helper to translate from/to clutter/evdev button codes
  + clutter/frame-clock:
  - Simplify next_presentation_time_us calculation
  - Start next update ASAP after idle period
  + cogl/onscreen: Add missing error untrap calls
  + input-capture:
  - Check barriers don't extend into nonexisting monitors
  - Fix off-by-one for barrier validation
  + renderer/native:
  - Add a new has_addfb2 property
  - Send modifiers even without AddFb2
  + screen-cast/stream-src:
  - Assert that dmabuf handle lookup succeeds
  - Calculate stride after adding handle to hash table
  + tests/clutter/event-delivery: Avoid race with stage update
  + tests/clutter/frame-clock*: Use
    clutter_frame_get_target_presentation_time
  + wayland/dma-buf: Advertise INVALID modifier without AddFb2
  + wayland: Send keyboard modifiers after the enter event
  + input-capture: Add more barrier tests, mostly for invalid
    barriers
* Fri Oct 13 2023 bjorn.lie@gmail.com
- Update to version 45.0+45:
  + kms/impl-device/atomic:
  - Fix blob size
  - Fix stack overflow
  + kms/impl-device: Inhibit real-time scheduling when mode setting
  + monitor-manager/native: Update assignments on empty-config too
  + renderer/native:
  - Clear old pending mode sets when unsetting all modes
  - Fold mode unsetting into renamed unset_modes()
  + tests/dbusmock-templates/rtkit: Add MakeThreadHighPriority
  + tests/kms/render: Add test for setting empty config
  + thread:
  - Allow turning off rt scheduling for running thread
  - For consistency, s/real_time/realtime/
  + Updated translations.
* Mon Oct  9 2023 bjorn.lie@gmail.com
- Drop mutter-crash-meta_context_terminate.patch: Closed upstream
  via https://gitlab.gnome.org/GNOME/mutter/-/merge_requests/2609
* Sat Sep 16 2023 bjorn.lie@gmail.com
- Update to version 45.0:
  + Fix focus-follows-mouse mode
  + Optimize applying relative transformation matrix
  + Add support for P010 YCbCr format
  + Fix hardware cursor stuttering on Raspberry Pi
  + Fix input in multi-monitor remote desktop sessions with libei
  + Fixed crashes
  + Misc. bug fixes and cleanups
  + Updated translations.
- Drop mutter-trap-dpms-errors.patch: Fixed upstream.
- Change compression of tarball in service and spec to zst from xz.
- Add pkgconfig(libdisplay-info) BuildRequires and pass
  libdisplay_info=true to meson setup: New optional dependency,
  build libdisplay-info support.
* Thu Sep 14 2023 alynx.zhou@suse.com
- Add mutter-trap-dpms-errors.patch: Apparently DPMSForceLevel()
  can fail if DPMS is not enabled, so trap errors of DPMS because
  they are not critical and should not block user session.
  (bsc#1215273, glgo#GNOME/mutter!3160)
* Thu Sep  7 2023 luc14n0@opensuse.org
- Replace sysprof-4 with sysprof-6 pkgconfig() BuildRequires to
  follow up the upstream change. And build without the profiler
  feature (using bcond_with profiler), as it's not meant for
  general use.
* Wed Sep  6 2023 bjorn.lie@gmail.com
- Update to version 45.rc:
  + Fix possible redraw freeze in fullscreen windows
  + Fix restoring focus when leaving the overview
  + Support alpha-composited window screencasts
  + Fix some XWayland windows not getting mapped
  + Fix cursor movement on rotated screens
  + Avoid global lock in stage signals
  + Implemented suspended xdg_toplevel state
  + Support idle_inhibit protocol
  + Do not trigger repick during relayout
  + Fix redraw issue when buffer age is unavailable
  + Add Meta Toolkit (MTK) library
  + Fix possible window freeze during resize operations
  + Fixes to tablet cursor visibility on Wayland
  + Improve support for input capture and emulated input
  + Use headless mode when seat ID is unset
  + Fix unresponsive touchscreen after titlebar drag
  + Fix absolute pointer events on virtual monitor streams
  + Fix disabling CRTCs in disable-only mode updates
  + Cache multi-texture shader snippets
  + Fixed crashes
  + Plugged leaks
  + Misc. bug fixes and cleanups
  + Updated translations.
- Drop mutter-fix-clipped-redraw.patch: Fixed upstream.
* Mon Sep  4 2023 bjorn.lie@gmail.com
- Update to version 45.beta.1:
  + Fix blitting from premultiplied to opaque formats
  + Fix Super key not going to overview in GNOME Shell
  + Use ClutterEvent in ClutterActor class event vmethod signatures
  + Misc. bug fixes and cleanups
  + Updated translations.
* Mon Sep  4 2023 bjorn.lie@gmail.com
- Update to version 45.beta:
  + Support input capture and emulated input with libei
  + Add KMS thread
  + Fix touch move operations on subsurfaces
  + Fix unexpected cursor changes over non-resizable windows
  + Improve render time estimates
  + Fix flickering when DRI driver isn't available
  + Fix restoring maximized state of SSD windows
  + Add support for YUV formats
  + Fix xwayland-allow-byte-swapped-clients setting
  + Misc. bug fixes and cleanups
  + Updated translations.
- Add pkgconfig(libeis-1.0) BuildRequires: New dependency.
* Mon Sep  4 2023 bjorn.lie@gmail.com
- Update to version 45.alpha:
  + Fix DND in some server-side decorated windows
  + Optionally use libdisplay-info for EDID parsing
  + Optimize partial surface updates
  + Fix redrawing regression in non-DMA remote sessions
  + Avoid race condition in xwayland-on-demand
  + Do not unminimize windows with initial IconicState
  + Implement physical pixel rounding of wayland surfaces
  + Fix mispositioning of some X11 fullscreen windows
  + Fix legacy fullscreen windows appearing on all monitors
  + Improve support for display-attached tablets
  + Fix stuck cursor in some clients
  + Avoid unexpected orientation changes around suspend/resume
  + Fix oversized input region around Xwayland windows
  + Re-enable client modifiers with amdgpu driver
  + Fix sysprof tracing in non-main threads
  + Fix X11 client input region issues
  + Optimize finish-layout step during stage updating
  + Fix profiling repeatedly
  + Ensure preferred monitor mode is always included
  + Fully initialize input device state during init
  + Forward modifiers to IM alongside regular key events
  + Fix window focus unexpectedly moving to secondary monitor when
    changing workspaces
  + Avoid rapidly toggling dynamic max render time
  + Fix dynamic max render time blocking with direct scanout
  + Mirror window placement in RTL locales
  + Fix screencast with fractionally scaled surfaces
  + Reipmlement strict focus mode policy
  + Fixed crashes
  + Plugged leaks
  + Misc. bug fixes and cleanups
  + Updated translations.
- Bump api_major to 13 following upstream changes.
* Mon Sep  4 2023 bjorn.lie@gmail.com
- Update to version 44.4:
  + Fix xwayland-allow-byte-swapped-clients setting.
  + Fix restoring focus when leaving the overview.
  + Fix touch move operations on subsurfaces.
  + Fix flickering when DRI driver isn't available.
  + Fix unexpected cursor changes over non-resizable windows.
  + Fix restoring maximized state of SSD windows.
  + Fix window focus unexpectedly moving to secondary monitor when
    changing workspaces.
  + Fixed crash.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Tue Aug 29 2023 alynx.zhou@suse.com
- Add mutter-fix-clipped-redraw.patch: Previous refactor forget
  to check has_buffer_age, which leads into force full redraw and
  causes redraw issue with xterm on qemu. This patch fixes it.
  (bsc#1210744, glgo#GNOME/mutter!3221)
- Drop mutter-revert-window_draw_issues.patch: Proper fix is added.
* Tue Aug 22 2023 dimstar@opensuse.org
- Add mutter-revert-window_draw_issues.patch: Revert commit
  43cee4b6:  Do clipped redraws when drawing offscreen
  (boo#1210744, glgo#GNOME/mutter#2771).
* Thu Aug 17 2023 yfjiang@suse.com
- Disable %%autopatch on SLE which has not the macro ready.
- Rebase mutter-SLE-bsc984738-grab-display.patch.
- Drop mutter-Lower-HIDPI_LIMIT-to-144.patch (fate#326682,
  bsc#112546). The upstream has reworked the logic of scale factor
  selection based on actual screen size, see:
  https://gitlab.gnome.org/GNOME/mutter/-/commit/2f1dd049bfbbb60e0b3c2351e9ba1d014205551f
* Thu Jul  6 2023 bjorn.lie@gmail.com
- Update to version 44.3:
  + Ensure preferred monitor mode is always included.
  + Avoid rapidly toggling dynamic max render time.
  + Fix dynamic max render time blocking with direct scanout.
  + Misc. bug fixes.
  + Updated translations.
* Mon Jun  5 2023 bjorn.lie@gmail.com
- Update to version 44.2:
  + Fix DND in some server-side decorated windows
  + Fix redrawing regression in non-DMA remote sessions
  + Avoid race condition in xwayland-on-demand
  + Do not unminimize windows with initial IconicState
  + Fix mispositioning of some X11 fullscreen windows
  + Fix legacy fullscreen windows appearing on all monitors
  + Improve support for display-attached tablets
  + Fix stuck cursor in some clients
  + Avoid unexpected orientation changes around suspend/resume
  + Fix oversized input region around Xwayland windows
  + Fix X11 client input region issues
  + Plugged leak
  + Fixed crashes
  + Misc. bug fixes and cleanups
  + Updated translations.
- Drop patches fixed upstream:
  + mutter-do-not-unminimize-windows-with-initial-iconic.patch
  + mutter-fix-wacom-tablet-crash.patch
* Tue May 23 2023 alynx.zhou@suse.com
- Add mutter-do-not-unminimize-windows-with-initial-iconic.patch:
  mutter used to unminimize windows with initial IconicState, which
  is a workaround for some old wine games, it breaks apps like
  xterm starts with -iconic, this patch revert it (bsc#1193190,
  glgo#GNOME/mutter!3001).
* Wed May 17 2023 alynx.zhou@suse.com
- Add mutter-fix-wacom-tablet-crash.patch: Use clutter error trap
  to fix x11 error of some input device configuration like wacom
  tablet (bsc#1211413, glgo#GNOME/mutter#2796).
* Tue May  9 2023 bjorn.lie@gmail.com
- Update to version 44.1+2:
  + screen-cast/src: Never dequeue pw_buffer's we refuse to record
    to.
  + frames: Disable XDND support on the frame window.
* Tue Apr 25 2023 bjorn.lie@gmail.com
- Update to version 44.1:
  + Fall back to the default, not the unknown color space.
  + Fix resizing windows via keyboard.
  + Fix possible screen freeze after resume with multiple monitors.
  + Fix anchor position when dragging window.
  + Fix applying XSettings to decorations on X11.
  + Allow clipped redraws for headless backend.
  + Improve screencast support.
  + Fix focus-on-click for server-side decorated windows.
  + Fix initial fullscreen state of server-side decorated windows.
  + Fix feedback loop triggering bursts of excessive CPU load.
  + Enable modifiers by default on non-native backend.
  + Check EDID for supported sink Colorimetry.
  + Fix artifacts in titlebars on some hardware.
  + Fix map transitions for X11 windows on wayland.
  + Fixed crashes.
  + Plugged leaks.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Drop 2963.patch: Fixed upstream.
* Sun Apr 16 2023 bjorn.lie@gmail.com
- Update to version 44.0+54:
  + backends/stage: Pass ClutterFrame to MetaStageWatchFunc
  + clutter/paint-context: Allow assigning a ClutterFrame
  + clutter/stage: Assign frames to paint context
  + core:
  - Create passive button grab on topmost Window
  - Minor refactor
  - Pass MetaWindow on passive button grab machinery
  + cursor-tracker: Enhance the documentation and increase
    annotation coverage
  + dnd: Clear Wayland drag source when cancelled from stage grab
    context
  + frames/content: Use gtk_widget_compute_point()
  + frames: Forward _NET_WM_STATE during frame initialization
  + output-xrandr:
  - Consistently return -1 on error
  - Don't treat 0 as invalid backlight value
  + screen-cast/monitor-src:
  - Record DMA-BUF frames immediately
  - Record frames with presentation time
  + screen-cast/src:
  - Add frame recording variant with timestamp
  - Clean up DMA-BUF only error paths
  + screen-cast-stream-src:
  - Shuffle a variable around
  - Export damaged video regions
  - Minor adjustment
  + stage-impl: Do clipped redraws when drawing offscreen
  + wayland/data-device: Clear data source when cancelling drag
    with ESC
  + wayland:
  - Don't leak XDnD mime type strings
  - Set compositor when creating MetaWaylandDataSourceXWayland
  + wayland/xdg-shell:
  - Dismiss instead of destroy invalid popup
  - Ignore reposition if popup was dismissed
  + workspace: Only consider windows that should be showing as
    focusable
  + x11:
  - Fix remaining leaks from switch to XGetAtomName()
  - Remove unused member variables from
    MetaX11SelectionInputStream
  - Use Atoms when constructing a new
    MetaX11SelectionOutputStream
  + xdg-shell: Early out of apply if dismissed
- Add 2963.patch: xdg-shell: Always handle frame callbacks in
  popup_apply_state(). Fixes a crash in mutter.
- Use auto(setup|patch) macros.
* Tue Apr 11 2023 luc14n0@opensuse.org
- Update to version 44.0+24:
  + x11: Wrap X call with error traps. And pass Atom directly. This
    should make Mutter more resilient and avoid a type of crash on
    gnome-shell.
  + frames/window-tracker: Select StructureNotifyMask X11 events.
  + Updated translations.
* Fri Mar 31 2023 bjorn.lie@gmail.com
- Update to version 44.0+18:
  + backends: Use meta_gamma_lut_new_sized() in a few more places
  + compositor:
  - Drop anchor_window_pos field from MetaWindowDrag
  - Use relative anchor coordinates for window drags
  - Avoid use of variable during resize
  + onscreen/native: Avoid freezing the frame clock on failed
    cursor commits
  + window-actor-x11: Check array bounds before accessing array
  + build: Don't disable checks in release builds
  + tests: Use a more interoperable path to bash
  + backend/nested: Ignore setting pointer constraint
  + Updated translations.
- Clean up spec, drop old disabled and unneeded pkgconfig(gtk+-3.0)
  BuildRequires and move disabled patches to SLE.
* Tue Mar 21 2023 bjorn.lie@gmail.com
- Update to version 44.0+8:
  + clutter: Safely transform paths to strings and vice versa
  + Export meta_window_has_pointer ()
  + compositor/window-drag: Fix keyboard resize
  + backends: Fall back to the default and not the unknown color
    space
  + wayland/buffer: Avoid spamming the log when a buffer is not
    scanoutable
  + kms/device: Avoid leaking some fields
  + kms/impl-device: Fix result listener list leak
  + kms/impl-device/simple: Avoid destroying a NULL hash table
* Sun Mar 19 2023 bjorn.lie@gmail.com
- Update to version 44.0:
  + Fix state confusion and delay on startup.
  + Fix night light regression.
  + Fix fullscreen regression with many SDL apps.
  + Fixed crashes.
  + Updated translations.
* Wed Mar 15 2023 bjorn.lie@gmail.com
- Drop patch needed for mutter-43.x, not needed in GNOME:Next where
  we have mutter-44.rc:
  + mutter-prevent-newly-focused-windows-to-steal-focus-from-shell.patch
* Mon Mar 13 2023 alynx.zhou@suse.com
- Add mutter-prevent-newly-focused-windows-to-steal-focus-from-shell.patch:
  Revert wrong commit and try a third approach to fix focus
  (bsc#1208494).
* Mon Mar  6 2023 bjorn.lie@gmail.com
- Update to version 44.rc:
  + Do not overwrite previously set offsets on attach
  + Fix Xwayland focus regressions
  + Stop parsing unused EDID parameters
  + Fix partial updates on offscreen rotated screens
  + Improve Xwayland RandR emulation compatibility
  + Fix touch window dragging on rotated monitors
  + Remove legacy OpenGL driver support
  + Improve default scale factor selection
  + Handle all X11 window title fallbacks
  + Fix handling of keyboard-driven window resize
  + Fix recording windows on non-active workspaces
  + Manage KMS updates more asynchronously
  + Fix headless startup
  + Remove support for window shading
  + Move away from GTK3
  + Restore zero-copy fast path for Xwayland fullscreen windows
  + Prevent clients from locking the compositor with cursor updates
  + Add experimental development tool for HDR modes
  + Account for linear sampling when calculating actor damage
  + wayland: Implement fractional_scale protocol
  + Fixed crashes
  + Memory handling fixes
  + Misc. bug fixes and cleanups
  + Updated translations.
- Disable mutter-Lower-HIDPI_LIMIT-to-144.patch: Needs rebase.
- Rebase mutter-disable-cvt-s390x.patch with quilt.
- Replace pkgconfig(gnome-desktop-3.0) with
  pkgconfig(gnome-desktop-4) BuildRequires, following upstream
  changes.
* Fri Feb 24 2023 bjorn.lie@gmail.com
- Update to version 44.beta:
  + Don't disable KMS modifiers on newer i915 systems
  + Set LOD bias for sharper mipmaps
  + Fix edge resistance and window snapping regression
  + Avoid high-level udev queries for input caps and properties
  + Implement wl_output v3 and v4
  + Fix recalculating viewport after window resize
  + Fix opaque cursors and LoDPI cursor on HiDPI screens
  + Process device removing events immediately
  + Handle stage view updates without allocation more gracefully
  + Fix window screenshots being cut off at the bottom right
  + wayland/subsurface: Avoid using buffers with unfinished client
    work
  + Move X11 window decorations to a separate client
  + Fix cursor position in window screencasts
  + Skip resize effects for tiled windows during user grabs
  + Fix pointer constrains with subsurfaces
  + Disable direct scanout during drag-n-drop operations
  + Ignore unmapped subsurfaces in direct scanout check
  + Fix cursor disappearing over windows during grabs
  + Make wl_output mode independent of the orientation
  + Improve focus handling on workspace switches
  + Fix initialization of keyboard accessibility
  + Refactor API to use well-defined ownership instead of
    singletons
  + Add support for xdg-foreign-v2
  + Add higher bit depth offscreen framebuffers support
  + Overhaul dynamic max render time calculation
  + Do not require a physical device to update pointer visibility
  + Allow building without xwayland support
  + Add Xwayland byte-swapped clients support
  + Fix freeze when crossing monitors under some conditions
  + Don't allow window activation to break global grabs
  + Integrate window grab operations with new ClutterGrab API
  + Support selecting an acceleration profile for touchpad devices
  + Enforce compliant surface buffer sizes
  + Keep proportional position when moving window between rects
  + Introduce implicit grabbing in Clutter
  + Fix unexpected window focus changes after global grabs
  + Fix sloppy/mouse focus mode on wayland
  + Add service channel Wayland clients
  + Fixed crashes
  + Plugged leaks
  + Misc. bug fixes and cleanups
  + Updated translations.
- Rebase patches with quilt.
- Bump api_major define to 12 following upstream changes.
* Mon Feb 20 2023 dimstar@opensuse.org
- Update to version 43.3+2:
  + wayland: Don't overwrite surface offsets.
  + x11: Avoid updating focus on wayland compositor (boo#1208494).
* Tue Feb 14 2023 bjorn.lie@gmail.com
- Update to version 43.3:
  + Skip resize effects for tiled windows during user grabs
  + Disable direct scanout during drag-n-drop operations
  + Ignore unmapped subsurfaces in direct scanout check
  + Fix cursor disappearing over windows during grabs
  + Fix pointer constrains with subsurfaces
  + Make wl_output mode independent of the orientation
  + Improve focus handling on workspace switches
  + Fix cursor position in window screencasts
  + Do not require a physical device to update pointer visibility
  + Fix initialization of keyboard accessibility
  + Fix freeze when crossing monitors under some conditions
  + Don't allow window activation to break global grabs
  + Fixed crashes
  + Plugged leak
  + Misc. bug fixes and cleanups
  + Updated translations.
* Sat Dec 10 2022 bjorn.lie@gmail.com
- Update to version 43.2:
  + Fix edge resistance and window snapping regression.
  + Handle stage view updates without allocation more gracefully.
  + Fix window screenshots being cut off at the bottom right.
  + Implement wl_output v3 and v4.
  + Fix recalculating viewport after window resize.
  + Set LOD bias for sharper mipmaps.
  + Don't disable KMS modifiers on newer i915 systems.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Drop clutter-actor-Show-on-all-stage-views-when-actors-ha.patch:
  Fixed upstream.
* Thu Nov 24 2022 mwilck@suse.com
- Fix window freezes when maximized on Xorg (boo#1205714,
  glgo#GNOME/mutter!2694, glgo#GNOME/gnome-shell#6054)
  * add clutter-actor-Show-on-all-stage-views-when-actors-ha.patch
* Fri Nov  4 2022 bjorn.lie@gmail.com
- Update to version 43.1:
  + Add quirk to work around issue with Mali GPUs.
  + Notify changes to night-light support over D-Bus.
  + Fix always-on-top windows unexpectedly taking focus.
  + Fix accidental direct scanout.
  + Disable client modifiers with amdgpu driver.
  + Cancel pointer gesture on wl_pointer.leave.
  + Add black padding to fixed-size wayland fullscreen windows.
  + Stop sending frame callbacks to minimized clients.
  + Fix scrolling in clients with no hi-res scroll support in RDP.
  + Fix skipped low-res scroll events with some high-res mice.
  + Throttle interactive move and resize updates.
  + wayland-keyboard: Send pressed keys on enter.
  + Fix some X11 windows getting unredirected erroneously.
  + Fix Flatpak applications bypassing X11 permission.
  + Fix always visible cursor in virtual streams.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Drop b81429ac.patch: Fixed upstream.
* Sun Sep 18 2022 bjorn.lie@gmail.com
- Update to version 43.0:
  + Fix stuttering in Xorg session.
  + Make MetaBarrier type derivable again.
  + Fixes crash.
  + Updated translations.
* Wed Sep 14 2022 bjorn.lie@gmail.com
- Fix night-light-support: Add b81429ac.patch: meta-monitor: Keep
  the dbus night-light-supported property in sync.
* Mon Sep  5 2022 bjorn.lie@gmail.com
- Update to version 43.rc:
  + Remember monitor scale when switching configurations
  + Embed wayland output name into screencast streams
  + Limit precision of stored refresh rates
  + Add support for the "max bpc" connector property
  + Fix focus-tracking corner case
  + Add detail to ::event signal
  + Improve heuristics for adding fallback monitor modes
  + Take over color management from gnome-settings-daemon
  + Allow scanout for offscreen rotated views
  + Fix hot corner regression on X11
  + Fix losing IM focus in some circumstances
  + Avoid swapping redundant portions of buffers onscreen
  + Animate windows moving between monitors
  + Make NVIDIA + gbm use atomic mode setting
  + Fixed crashes
  + Plugged memory leak
  + Misc. bug fixes and cleanups
  + Updated translations.
- Add pkgconfig(colord) and pkgconfig(lcms2) BuildRequires: New
  dependencies.
- Pass tests=false to meson, disable build of all tests.
* Fri Aug 12 2022 bjorn.lie@gmail.com
- Update to version 43.beta:
  + Add basic color-scheme support for server-side decorations
  + Add single pixel buffer support
  + Add support for multi-monitor direct scanout
  + Add tool to pretty print display configuration
  + Always send modifiers to clients if supported
  + Better integrate cogl tests with existing infrastructure
  + Continue gi-docgen migration
  + Defer and accumulate redraw-clip on scanout
  + Don't skip frames after skipped KMS updates
  + Don't skip vblank sync on missing presentation timestamp
  + Fall back to ARGB if XRGB is not supported
  + Fix cursor showing on Xilinx
  + Fix cursor visibility on X11 with only tablets as input
  + Fix glitches in apps using subsurfaces
  + Fix registering as X11 window manager if GDK_BACKEND is set
  + Highlight actors becoming reactive under the pointer
  + High-resolution scroll wheel support
  + Notify about privacy screen changes via predictions
  + Reduce client work when entering overview
  + Remove mipmap framerate limiting
  + Replace MetaTextureTower with native GL mipmapping
  + Report actual monitor transform
  + screencast:
  - Set correct stride when using dmabufs
  - Use flag to signal failed recording
  + Support direct scanout on GPUs without modifiers support
  + Plugged leaks
  + Fixed crashes
  + Misc. bug fixes and cleanups
  + Updated translations.
- Drop zenity BuildRequires/Requires: The dependency was removed in
  alpha release.
* Fri Aug 12 2022 dimstar@opensuse.org
- Update to version 43.alpha:
  + Drop zenity dependency.
  + Fix initialization of privacy mode in displays that support it.
  + Add NightLightSupported property to DisplayConfig.
  + Don't use direct scanout for transparent windows.
  + Improve picking a window for direct scanout.
  + Drop support for obsolete wayland protocols.
  + Fix --replace again.
  + Do not allow windows to steal focus when the shell has a grab.
  + Fix night light without GAMM_LUT property.
  + Expose Cogl's Snippet API to introspection.
  + wayland: Fix rotation transform.
  + Build and deploy API documentation.
  + Attach color state information to actors.
  + Fix pointer confinement on HiDPI setups.
  + Fix dma-bufu screencast regression.
  + Fix monitor mirroring in some cases.
  + Parse HDR and Colorimetry CTA-861 EDID extension blocks.
  + Fix cursor tracking during screencasts on X11.
  + Fixed crashes.
  + Plugged leaks.
  + Misc. bug fixes and cleanups.
- Bump api_major to 11, following upstream.
* Thu Aug 11 2022 bjorn.lie@gmail.com
- Update to version 42.4:
  + screencast: Set correct stride when using dmabufs
  + Fix glitches in apps using subsurfaces
  + Reduce client work when entering overview
  + Highlight actors becoming reactive under the pointer
  + Fall back to ARGB if XRGB is not supported
  + Support direct scanout on GPUs without modifiers support
  + Fix registering as X11 window manager if GDK_BACKEND is set
  + Fixed crash
  + Plugged leak
  + Misc. bug fixes and cleanups.
* Wed Jul  6 2022 dimstar@opensuse.org
- Update to version 42.3:
  + wayland: Fix rotation transform.
  + Fix dma-buf screencast regression.
  + Fix monitor mirroring in some cases.
  + Fixed crash.
  + Plugged leak.
* Mon May 30 2022 dimstar@opensuse.org
- Update to version 42.2:
  + Don't use direct scanout for transparent windows.
  + Fix initialization of privacy mode in displays that support it.
  + Fix --replace again.
  + Improve picking a window for direct scanout.
  + Do not allow windows to steal focus when the shell has a grab.
  + Fix night light without GAMMA_LUT property.
  + Fixed crash.
  + Misc. bug fixes.
* Fri May 13 2022 xiaoguang.wang@suse.com
- Add mutter-crash-meta_context_terminate.patch: Fix SIGSEGV in
  meta_context_terminate (bsc#1199382 glgo#GNOME/mutter#2267).
* Fri May  6 2022 fcrozat@suse.com
- Update to version 42.1:
  + Send correct LEAVE events when entering windows.
  + Be more forgiving with wrongly sized clients.
  + Add ClutterInputCapabilities enum and device property.
  + Fall back if COPY_MODE_SECONDARY_GPU fails to init.
  + Fix missing root window properties after XWayland start.
  + wayland/shm: Add support for ABGR8888 and XBGR8888 formats.
  + Keep actors dirty if a redraw was queued up during paint().
  + Fix overview painting of shaped texture with layer snippets.
  + Survive missing GAMMA_LUT KMS property.
  + Record current event when going through event filters.
  + Pass events to pointer a11y before going through filters.
  + Update cursor when scaled or transformed.
  + Fix screen cast when DMA buffer fails or can't be used.
  + Repick when pointer actor goes unmapped.
  + Improve IM support.
  + Allow using dumb buffers for cursor sprites.
  + wayland/dma-buf: Only advertise supported formats.
  + Fix screen cast cursor metadata with unthrottled input.
  + Fixed crashes.
  + Plugged memory leak.
- Drop mutter-bail-out-on-reentry-into-map-unmap.patch and
  mutter-42.0-fix-top-bar-elements-hovering-effect.patch (merged
  upstream).
* Sun Mar 27 2022 luc14n0@opensuse.org
- Add mutter-42.0-fix-top-bar-elements-hovering-effect.patch based
  on commits: 0280b0aaa563db65bf79a3643f6a9e8e76bfe458 and
  2aad56b949b86b4f1d0eab6d3d3b0d5491e8515b. A fix for elements in
  the top bar not losing the cursor-hovering effect if the cursor
  immediately enters an app window (glgo#GNOME/gnome-shell#203).
* Thu Mar 24 2022 alynx.zhou@suse.com
- Add mutter-bail-out-on-reentry-into-map-unmap.patch: This fixes
  gnome-shell crash when dragging close button in overview by
  bailing out on reentry into map/unmap() (bsc#1197350,
  glgo#GNOME/mutter!2299).
* Sun Mar 13 2022 bjorn.lie@gmail.com
- Update to version 42.0:
  + Updated translations.
* Mon Mar  7 2022 bjorn.lie@gmail.com
- Update to version 42.rc:
  + Fix X11 → wayland drops ending up in the wrong wayland client.
  + Make xdg-activation interoperate with other startup sequences.
  + Fix stuck grab feedback actor during compositor grabs.
  + Make gnome-desktop dependency optional.
  + Provide better profiling information.
  + Drop ClutterEvent "source" field.
  + Add support for xdg_toplevel.configure_bounds().
  + Add support for wl_surface.offset.
  + Fix resizing of virtual monitors.
  + Include size in configure events of maximized clients.
  + Only allow direct scanouts for surfaces that aren't cropped,
    scaled or rotated.
  + Fix pipewire screencasts.
  + Plugged memory leak.
  + Fixed crash.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Drop mutter-ci-catchsegv.patch: No longer needed.
* Thu Feb 24 2022 bjorn.lie@gmail.com
- Update to version 42.beta+11:
  * meson: Enable -Wall by default
  * core: Initialize g_autofree with NULL
  * ci:
  - Rebuild image with newer dependencies
  - Install xwayland from tag directly
  * wayland/keyboard: Remove unnused define
  * Updated translations.
- Switch to using source service again.
- Flip profiler bcond to without, build profiling/sysprof support
  again.
* Tue Feb 15 2022 bjorn.lie@gmail.com
- Update to version 42.beta:
  + Implement a new Clutter grab API
  + Support KMS testing via QEMU
  + Generate API references with gi-docgen
  + Improve support for running from toolbx
  + Add support for privacy screen
  + Allow changing monitor configuration policy
  + Add support for XFixes ClientDisconnectMode
  + Fix possible missed clicks on menus
  + Place popups on the same monitor as the anchor rect
  + Announce DMA-BUF support via pipewire
  + Raise the file descriptor limit of the wayland compositor
  + Fix resetting idle time on lid open
  + Don't limit DMA buffer screen casting only to Intel
  + Keep a single cursor sprite visible with tablets
  + Sync keyboard LEDs after layout changes
  + Honor window input area in picking
  + Handle mixture of keycombo/no action in pad rings/strips
  + Fixed crashes
  + Misc. bug fixes and cleanups
  + Updated translations.
* Tue Feb 15 2022 bjorn.lie@gmail.com
- Drop 0002-Drop-CI-test-setup-that-needs-catchsegv.patch: Use the
  mutter-ci-catchsegv.patch, as this applies for 42.alpha.
* Tue Feb 15 2022 bjorn.lie@gmail.com
- Update to version 41.4:
  + Fix DND between X11 and wayland clients.
  + Fix resetting idle time on lid open.
  + wayland/gtk: Only perform allowed titlebar gestures.
  + Place popups on the same monitor as the anchor rect.
  + Fix wrong resizes of some clients on focus changes.
  + Misc. bug fixes.
  + Fixed crashes.
  + Updated translations.
* Tue Feb  8 2022 bjorn.lie@gmail.com
- Add 0002-Drop-CI-test-setup-that-needs-catchsegv.patch: Fix build
  with glibc 2.35 and newer.
* Sat Feb  5 2022 mgorse@suse.com
- Add mutter-ci-catchsegv.patch: drop CI test setup that needs
  catchsegv, which is removed in glibc 2.35
  (glgo#GNOME/mutter#2120).
* Wed Jan 12 2022 dimstar@opensuse.org
- Update to version 42.alpha:
  + Fix monitor screencast scanouts.
  + wayland: Allow clients to maximize windows regardless of
    constraints.
  + Handle hotplug events without relevant changes more
    effectively.
  + Improve error reporting when startup fails.
  + Fix X11 middle button emulation setting.
  + Include server-side shadows in window screenshots.
  + Don't change workspaces of unmanaged windows.
  + Fix videos in Firefox stuttering in overview.
  + Improve on-screen keyboard on X11.
  + Fix erratic scrolling in GTK apps.
  + Use rtkit to get realtime priority.
  + Sanitize event handling at gestures.
  + Fix mapping tablet input to correct monitor.
  + Fix key repeat of on-screen keyboard for 2nd-level keysyms.
  + Fix window size after returning from fullscreen.
  + Fix blank screen when unplugging docking station.
  + Improve anti-aliasing of background corners.
  + Fix DND between X11 and wayland clients.
  + Allow adding more streams to a screen cast session.
  + Fix mixed up refresh rates in multi-monitor setups.
  + Improve KMS fallback modes.
  + Fix workspace switch animation in default plugin.
  + Fixed crashes.
  + Plugged leaks.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Bump api_major to 10, following upstream changes.
* Tue Jan 11 2022 bjorn.lie@gmail.com
- Update to version 41.3:
  + Check keyboard serials for activation
  + Fix mixed up refresh rates in multi-monitor setups
  + Allow disabling HW cursors
  + Improve damage handling
  + Consider xrandr flags for advertised modes
  + Ensure constraints after client resize
  + window-group: Disable culling when rendinging clone to
    offscreen buffer
  + Fix workspace switch animation in default plugin
  + Fix unfullscreening of window that were mapped fullscreen
  + Fix DMA-BUF screencasts with unredirected fullscreen windows
  + Fix orientation changes on devices with 90°
  + Fixed crashes
  + Plugged leaks
  + Misc. bug fixes and cleanups.
- Drop patches fixed upstream:
  + mutter-allow-disable-hardware-cursors.patch
  + mutter-initialize-saved_rect_fullscreen.patch
- Renumber patches yet again.
* Mon Jan 10 2022 alynx.zhou@suse.com
- Add mutter-initialize-saved_rect_fullscreen.patch: Some
  applications that starts in fullscreen disappear when switching
  back to normal size mode, because mutter forget to initialize
  saved_rect_fullscreen which is used for unfullscreen, this patch
  fixes it (glgo#GNOME/mutter!2210, bsc#1185444).
* Fri Dec 17 2021 bjorn.lie@gmail.com
- Rebase patches with quilt and renumber them.
- Add mutter-window-actor-Special-case-shaped-Java-windows.patch:
  window-actor: Special-case shaped Java windows.
  OpenJDK wrongly assumes that shaping a window implies no shadows.
  They got lucky until commit b975676c changed the fallback case,
  but now their compliance tests are broken. Make them happy again
  by special-casing shaped Java windows. Patch from fedora:
  https://src.fedoraproject.org/rpms/mutter/raw/rawhide/f/0001-window-actor-Special-case-shaped-Java-windows.patch
* Fri Dec 17 2021 alynx.zhou@suse.com
- Add mutter-allow-disable-hardware-cursors.patch: Add a debug
  environment variable MUTTER_DEBUG_DISABLE_HW_CURSORS to disable
  hardware cursors and force using software cursors to avoid some
  driver or hardware bug (glgo#GNOME/mutter#2045,
  glgo#GNOME/mutter!2150).
* Mon Dec 13 2021 bjorn.lie@gmail.com
- Update to version 41.2:
  + Fix blank screen when unplugging docking station.
  + Prefer GBM over EGLStream where possible.
  + Fix unredirected Xwayland windows not getting updated.
  + Improve anti-aliasing of background corners.
  + Copy damage rectangles to secondary GPU
  + Improve Wacom tablet mapping.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Switch to git checkout of released tag via source service.
* Tue Nov 23 2021 alynx.zhou@suse.com
- Enable wayland-eglstream dependency on Leap/SLE (jsc#SLE-19964).
* Fri Nov 19 2021 alynx.zhou@suse.com
- Enable eglstream on Leap/SLE (jsc#SLE-19964).
* Fri Nov  5 2021 bjorn.lie@gmail.com
- Update to version 41.1:
  + Fix monitor screencast scanouts
  + dma-buf: Use alpha-less pixel formats where appropriate
  + wayland: Allow clients to maximize windows regardless of
    constraints
  + Handle hotplug events without relevant changes more effectively
  + Improve error reporting when startup fails
  + dma-buf: Add support for ABGR and XBGR formats
  + Fix X11 middle button emulation setting
  + Include server-side shadows in window screenshots
  + Don't change workspaces of unmanaged windows
  + Reset idletime when unplugging the power cable
  + xwayland: Avoid unnecessary _NET_WM_STATE events
  + Fix videos in Firefox stuttering in overview
  + Don't use atomic mode setting for virtio_gpu driver
  + Improve on-screen keyboard on X11
  + Fix text glitches after size changes
  + Fix reporting output rotation to xwayland
  + wayland: Accept final preference of drop destination
  + Fix erratic scrolling in GTK apps
  + Fix tilt direction of pen/tablet inputs
  + Use b/w unicode for tablet mode OSD
  + Fix negative paint volume offscreen effect
  + Only add paint volumes of mapped actors to stage clip
  + Fix mapping tablet input to correct monitor
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Drop clutter-only_reset_preedit_text_if_set.patch: Fixed upstream
* Tue Nov  2 2021 dimstar@opensuse.org
- BuildRequire libxcvt when building against xorg-x11-server > 21,
  unless when building for s390x: libxcvt was split out and lives
  in an own package now.
* Thu Oct 21 2021 packaging@sp1rit.anonaddy.me
- Added clutter-only_reset_preedit_text_if_set.patch
  + fixes "scrollback" issue of GtkTextView
    (see lists.opensuse.org/archives/list/factory@lists.opensuse.org/thread/WYSUDJFTZIEEJS3QBBBUNLD3XBXULABU/)
* Wed Oct 20 2021 yfjiang@suse.com
- Rebase mutter-SLE-bsc984738-grab-display.patch.
* Wed Sep 22 2021 mgorse@suse.com
- Update to version 41.0:
  + Avoid race in wl_seat capabilities.
  + Expose option groups/entries to introspection.
  + Updated translations.
* Wed Sep 22 2021 bjorn.lie@gmail.com
- Add pkgconfig(xwayland) and drop xorg-x11-server-wayland
  BuildRequires: use standalone xwayland during build and runtime.
- Add explicit gnome-settings-daemon Requires and pass initfd=auto
  to meson now that we are using the new standalone xwayland.
* Wed Sep 22 2021 dimstar@opensuse.org
- Update to version 41.rc:
  + Add clutter_stage_paint_to_content().
  + Add meta_cursor_tracker_get_scale().
  + wayland: Make each wl_output correspond to one monitor.
  + Expose 'inactive-since' timestamp to uresourced.
  + Pass dirty rects to secondary GPU.
  + Support commiting preedit string on focus loss.
  + Improve auto-rotation support.
  + Add meta_window_actor_paint_to_content().
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Add xvfb-run BuildRequires: new dependency for the test suite.
* Wed Sep 22 2021 dimstar@opensuse.org
- Update to version 41.beta:
  + Manage idle monitors via MetaIdleManager.
  + Fix VKMS detection.
  + Fix swipe cancellation.
  + Fix mapping tablet to monitor.
  + Fix area screencasts when window is unredirected.
  + Don't require a newly attached buffer to apply state.
  + Close unused mode setting and rendering devices.
  + Only support super+scroll on wayland.
  + Implement the xdg-activation protocol.
  + Reduce input latency by computing max render time
    heuristically.
  + Apply dithering to dispatch time when needed.
  + x11: Compute monitor scale per output.
  + Shrink and optimize the rounded-background-clip shader.
  + remote-desktop: Handle non-responding selection owners .
  + Improve sysprof support.
  + Allow clients to delegate titlebar gestures to the compositor.
  + Fix upside-down Xshape surface with EGLstream.
  + Fix 'kms-modifiers' experimental setting.
  + Make default focus window on each workspace appear focused.
  + Plugged memory leaks.
  + Fixed crashes crash.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Tue Sep 21 2021 bjorn.lie@gmail.com
- Update to version 40.5:
  + Fix monitor screencast scanouts.
  + Fix middle-click emulation support on X11.
  + Fixed crashes.
  + Updated translations.
* Thu Sep 16 2021 sbrabec@suse.com
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Wed Aug 18 2021 bjorn.lie@gmail.com
- Update to version 40.4:
  + Don't require a newly attached buffer to apply state.
  + Fix upside-down Xshape surface with EGLstream.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Thu Jul 29 2021 yfjiang@suse.com
- Synchronize changelog between SLE, Leap and Factory.
* Thu Jul 29 2021 yfjiang@suse.com
- Disable eglstream on Leap/SLE by now since it is under review.
* Wed Jul 28 2021 yfjiang@suse.com
- Add versioned BuildRequires to pkgconfig(libinput):
  https://gitlab.gnome.org/GNOME/mutter/-/blob/gnome-40/meson.build#L47
* Tue Jul 13 2021 bjorn.lie@gmail.com
- Update to version 40.3:
  + Fix area screencasts when window is unredirected.
  + Fix mapping tablet to monitor.
  + Fixed crash.
  + Misc. bug fixes.
  + Updated translations.
- Drop mutter-Gracefully-handle-page-flipping.patch: Fixed
  upstream.
* Tue Jul  6 2021 bjorn.lie@gmail.com
- Build wayland eglstream support: Pass wayland_eglstream=true to
  meson and add pkgconfig(wayland-eglstream) BuildRequires.
  Gnome-shell Wayland session with nvidia binary driver is now
  possible when enabled manually, users must first comment out the
  disabling of Wayland when using the proprietary nvidia driver in
  /usr/lib/udev/rules.d/61-gdm.rules, then boot with passing
  nvidia-drm.modeset=1 to the kernel. We do NOT recommend that
  users try this, as it buggy and unstable at the moment.
- Add mutter-Gracefully-handle-page-flipping.patch kms: Gracefully
  handle page flipping direct scanouts failing. Fix a crash.
* Thu Jun 17 2021 bjorn.lie@gmail.com
- Rebase mutter-disable-cvt-s390x.patch and
  mutter-Lower-HIDPI_LIMIT-to-144.patch, and enable
  mutter-disable-cvt-s390x.patch again now that it is rebased.
* Wed Jun 16 2021 bjorn.lie@gmail.com
- Update to version 40.2.1:
  + Fixed crash glgo#GNOME/mutter!1895.
* Fri Jun 11 2021 bjorn.lie@gmail.com
- Update to version 40.2:
  + Fix mouse position in remote desktop with fractional scaling.
  + Fix fd leak.
  + Disable KMS modifiers on radeon driver.
  + Fix adding virtual monitor to physical session.
  + Unbreak press-drag-release to pop up and select right click
    menus.
  + Fix VKMS detection.
  + Misc. bug fixes.
  + Updated translations.
- Changes from version 40.1:
  + Prevent clients from pasting old selection data.
  + Fix forward_key IM functionality on wayland.
  + Ensure valid window texture size after viewport changes.
  + Only update cached paint volumes when necessary.
  + Only disable KMS modifiers for drivers with known problems.
  + Fix X11 client resize during moves.
  + Fix performance drop during night light transition with Nvidia.
  + kms: Don't add common modes that exceed the max bandwidth.
  + Create virtual input devices on demand.
  + Fix wrong night light gamma when leaving power saving.
  + Fix picking edge case.
  + Properly tear down things when shutting down.
  + Fix monitor screencasting with fractional scaling.
  + Fixed crash.
  + Plugged memory leak.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Disable mutter-disable-cvt-s390x.patch: Needs rebase.
* Fri Apr 23 2021 alynx.zhou@suse.com
- Rebase mutter-SLE-bsc984738-grab-display.patch and
  mutter-SLE-bell.patch.
* Sat Apr 17 2021 dimstar@opensuse.org
- Fold libmutter-8-0 and mutter-data into the main package:
  + SLPP does, despite the devel package, not make much sense.
    Mutter is the GNOME Window Manager and parallel installation of
    the library only gave a false sense of possibility, and often
    resulted in upgrade issues (e.g. zypper not updating mutter).
  + The -data package was hard-requiring the same mutter version,
    which essentially means the split makes no sense.
* Sat Mar 20 2021 dimstar@opensuse.org
- Update to version 40.0:
  + xwayland: Check permissions on /tmp/.X11-unix.
* Wed Mar 17 2021 dimstar@opensuse.org
- Update to version 40.rc:
  + Fix keyboard input from remote desktop in Xorg session.
  + Fix restoring focus to windows using globally active input.
  + Expose unaccalerated touchpad gesture deltas.
  + Avoid relayout on text attribute changes when possible.
  + Add remote desktop caps- and num-lock state properties.
  + Improve refresh rate calculation.
  + Implement presentation-time protocol.
  + Disable double-buffered shadow buffering.
  + Fix missing cursor on tablet devices.
  + Fix frame timings causing X11 clients to get stuck.
  + Fix applying input settings on X11.
  + Add headless native backend.
  + Fix high latency and stalls with proprietary nvidia driver.
  + Fix maximized windows not reacting to strut changes.
  + Only start XWayland on demand when running under systemd.
  + Sync LEDs when a new input device is added.
  + Fix order in which subsurface placement operations are handled.
  + Fixed crashes.
  + Plugged leaks.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Tue Feb 23 2021 dimstar@opensuse.org
- Update to version 40.beta:
  + Consider clients without mapped windows for xwayland
    auto-shutdown.
  + Let compositor to handle super+scroll events.
  + Default to starting Xwayland on demand.
  + xwayland: Restore abstract socket support.
  + Add support for atomic mode setting.
  + Fix clip region glitches when using fractional scaling.
  + Default to horizontal workspace layout.
  + Do not ping unmanaging windows.
  + Handle monitor changes during screencasts.
  + Fix unexpected jumps after restoring misbehaving clients.
  + Fix newly opened X11 windows being invisible in overview.
  + Fix viewport of offscreen effects.
  + Fix drag cancel animation when using geometry scaling.
  + Improve touch-mode heuristics.
  + Integrate clipboard with remote desktop sessions.
  + Fix stuck icon in DND operation between X11 and wayland.
  + Automatically synchronize pointer position after modal grabs.
  + Reimplement support for CLUTTER_SHOW_FPS.
  + Only pick on events that may move the pointer.
  + Emit discrete scroll events for accumulated smooth events in
    virtual X11 devices.
  + Add support for rounded clipping when drawing background.
  + Plugged memory leaks.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Fri Jan 15 2021 dimstar@opensuse.org
- Update to version 40.alpha.1.1:
  + Adapt to settings moving to gsettings-desktop-schemas.
  + Misc. bug fixes and cleanups.
- Changes from version 40.alpha.1:
  + Base ClutterEffects on ClutterPaintNodes.
  + xwayland: Set xrandr primary output.
  + Add paint node based blur support.
  + Disable CRTCs if there is no monitor.
  + Fix updates of mipmapped animated backgrounds.
  + Allow remote desktop clients to specify scroll source.
  + Support the color transform matrix RandR property on X11.
  + Plugged memory leaks.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
* Fri Jan 15 2021 dimstar@opensuse.org
- Update to version 40.alpha:
  + Replace CoglMatrix with graphene_matrix.
  + Allow to specify debug topics in MUTTER_DEBUG.
- Bump api_major to 8, following upstream changes.
* Thu Jan 14 2021 dimstar@opensuse.org
- Update to version 3.38.3:
  + xwayland: Set xrandr primary output,
  + Disable CRTCs if there is no monitor,
  + Fixed crashes,
  + Misc. bug fixes,
  + Updated translations.
* Thu Dec  3 2020 dimstar@opensuse.org
- Update to version 3.38.2:
  + Fix unwanted position changes on window resize.
  + Fix _NET_WM_FRAME_DRAWN timestamps.
  + Fix missed redraws of newly-mapped actors.
  + (Temporarily) make Xwayland listen on abstract namespace socket
    again.
  + Fix tiling to the correct monitor.
  + Fix background artifacts in magnifier.
  + Fix monitor tiling support on X11.
  + Fix device configuration not being picked up on X11.
  + Improve compatibility with Qt's wayland support.
  + Support tagging devices as primary GPU via udev.
  + Fix size hints with CSD.
  + Do not disable the X Security extension by default.
  + Fix unresponsive input after screen blank.
  + Improve tablet-mode-switch support.
  + Plugged memory leaks.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Thu Oct  8 2020 dimstar@opensuse.org
- Update to version 3.38.1:
  + Fix Night Light updates after DPMS.
  + Fix button scrolling on X11.
  + Always use correct font-dpi setting on X11.
  + Improve handling of scanout failures.
  + Fix middle/right button mixup in scroll button assignment.
  + Fix resizing of attached modal dialogs on wayland.
  + Enable KMS modifiers on devices that need them.
  + Fix IM handling on X11.
  + Fix glitches in "undefined" screencast areas.
  + Fix visual glitches on background with fractional scaling.
  + Fix using correct refresh rate.
  + Misc. bug fixes and cleanups.
  + Plugged memory leaks.
  + Updated translations.
- Add pkgconfig(udev) BuildRequires: new verified dependency.
* Thu Oct  8 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + screencast: Only use DMA buffers for i915.
  + Updated translations.
* Thu Oct  8 2020 dimstar@opensuse.org
- Update to version 3.37.92:
  + Fix stale cursor positions in remote desktop sessions.
  + xwayland: Add a setting to disable selected X extensions.
  + Fix screencasting when using QXL.
  + Cull actors that don't intersect with the redraw clip.
  + Optimize painting of backgrounds when culling is unavailable.
  + Improve support for Hangul input method.
  + Support debug paint overlay for opaque regions.
  + Fix launching flatpak applications when autostarting Xwayland.
  + Add support for capture scanouts in screencasts.
  + Allow integrated tablet devices to cycle outputs.
  + Improve mapping input devices to the most relevant output.
  + Only enable auto-rotation in touch mode.
  + Updated translations.
* Thu Oct  8 2020 dimstar@opensuse.org
- Update to version 3.37.91:
  + Fix initial state of display mode OSD.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
- Changes from version 3.37.90:
  + Fix using NEAREST filter for backgrounds on scaled monitors.
  + Screencast fixes and improvements.
  + Support tap-button-map and tap-drag-lock touchpad settings.
  + Fix wine copy & paste.
  + Fix shadows of server-side decorated XWayland windows.
  + Replace some loaded terms with more descriptive ones.
  + Add API to launch trusted wayland clients.
  + Skip displays with 'non-desktop' property set.
  + Invalidate offscreen effect cache on video memory purge.
  + Add wl_shm support for 10 bpc and 16 bpc half float formats.
- Changes from version 3.37.3:
  + Support custom keyboard layouts in $XDG_CONFIG_HOME/xkb.
  + Optimize resource scale computation.
  + Allow animating ClutterActor's content property.
  + Implement backgrounds as ClutterContent.
  + Add ClutterAlignContraint:pivot-point property.
  + Fix crash on area screenshots with fractional scaling.
  + Do not paint textures of fully obscured windows.
  + Use a more appropriate combine function on opaque areas.
  + Fix remote desktop being broken without screencast session.
  + Remove more long-deprecated Clutter APIs.
  + Drive each monitor by its own frame clock.
  + Fix copy/paste failures on X11.
  + Mipmap background texture rendering.
  + Plugged memory leaks.
- Changes from version 3.37.2:
  + Fix move-to-center keybinding with multiple monitors.
  + Fix stuck buttons when a virtual device is destroyed.
  + Use workarea when centering new windows.
  + Limit mipmap levels when rendering background.
  + Broadcast clipboard/primary offers.
  + Support primary-selection protocol from wayland-protocols.
  + Fix monitor screen cast on X11.
  + Support a "blank" cursor type.
  + Improve stage view damage tracking>
  + Implement touch-mode detecation for the X11 backend.
  + Drop external keyboard detection from touch-mode heuristics.
  + Optimize actor allocations.
- Changes from version 3.37.1:
  + Fix screencasting non-maximized windows.
  + Make window-aliveness checks less aggressive.
  + Fix stylus coordinates when using screen rotation.
  + Preserve keyboard state on VT switch.
  + Remove Clutter's drag and drop actions.
  + Cancel clicks/gestures actions on disable.
  + Fix various clipboard issues.
  + Fix trackball button scrolling.
  + Fix tiled monitor support.
  + Support unredirecting fullscreen wayland surfaces.
  + Support area screencasts.
  + Synchronize shadows to server-side decorations.
  + Allow inhibiting remote access.
  + Fix overview key on X11 when using multiple keyboard layouts.
  + Updated translations.
- Drop mutter-meson_options-Use-libGLESv2.so.2-for-COGL_DRIVER-gle.patch:
  fixed upstream.
- Drop mutter-fix-wine-copy-and-paste.patch:
  fixed upstream.
* Wed Oct  7 2020 bjorn.lie@gmail.com
- Update to version 3.36.7:
  + Fix Night Light updates after DPMS
  + Fix IM handling on X11
  + Fix resizing of attached modal dialogs on wayland
  + Fix jumps when resizing windows using discrete steps.
  + Fixed crashes.
  + Plugged Memory leaks.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Tue Sep  8 2020 bjorn.lie@gmail.com
- Update to version 3.36.6+2:
  + kms/crtc:
  - Always consider gamma state valid.
  - Read initial gamma state.
  + Fix stale cursor positions in remote desktop sessions.
  + Limit mipmap levels when rendering background.
  + Improve support for Hangul input method.
  + Fixed crashes.
  + Plugged memory leaks.
  + Misc. bug fixes and cleanups.
- Drop patch fixed upstream:
  + mutter-meson_options-Use-libGLESv2.so.2-for-COGL_DRIVER-gle.patch
* Fri Aug 21 2020 alynx.zhou@suse.com
- Added mutter-fix-wine-copy-and-paste.patch: sometimes copy and
  paste will fail in wine applications, this upstream patch fixed
  it (boo#1175532, glgo#GNOME/mutter!1369).
* Thu Aug 20 2020 fcrozat@suse.com
- Add mutter-meson_options-Use-libGLESv2.so.2-for-COGL_DRIVER-gle.patch:
  don't use libGLESv2.so but libGLESv2.so.2 for COGL driver
  (boo#1175559 glgo#GNOME/mutter!1282).
* Wed Aug 12 2020 bjorn.lie@gmail.com
- Update to version 3.36.5:
  + Screencast fixes and improvements.
  + Fix glitches when subsurfaces extend outside the toplevel.
  + Mipmap background texture rendering.
  + Fix wine copy & paste.
  + Plugged memory leaks.
  + Updated translations.
* Thu Jul 16 2020 bjorn.lie@gmail.com
- Update to version 3.36.4+9:
  + Various screen cast fixes.
* Wed Jul  8 2020 bjorn.lie@gmail.com
- Update to version 3.36.4:
  + Fix crash on area screenshots with fractional scaling.
  + Do not paint textures of fully obscured windows.
  + Turn off CRTCs as well when enabling DPMS.
  + Improve selection support.
  + Use a more appropriate combine function on opaque areas.
  + Fix remote desktop being broken without screencast session.
  + Fix popovers disappearing on wayland and HiDPI.
  + Fixed crashes.
  + Plugged memory leaks.
  + Misc. bug fixes and cleanups.
* Thu Jun  4 2020 bjorn.lie@gmail.com
- Update to version 3.36.3+1:
  + Broadcast clipboard/primary offers.
  + Fix monitor screen cast on X11.
  + Implement touch-mode detecation for the X11 backend.
  + Drop external keyboard detection from touch-mode heuristics.
  + Fix leaked DMA buffers in screencasts.
  + Fixed various crashes.
  + Renderer-native: Don't leak DMA buffer CoglFramebuffer.
* Wed May 13 2020 mgorse@suse.com
- Update to version 3.34.6:
  + Fix various clipboard issues.
  + Fix locate-pointer feature interfering with keybindings.
  + Fix overview key on X11 when using multiple keyboard layouts.
  + Preserve keyboard state on VT switch.
  + Fixed crashes.
  + Plugged memory leaks.
  + Misc. bug fixes and cleanups.
* Fri May  1 2020 mgorse@suse.com
- Enable SLE patches on leap (jsc#SLE-11897).
* Thu Apr 30 2020 bjorn.lie@gmail.com
- Update to version 3.36.2:
  + Sync timelines to hardware vsync.
  + Fix screencasting non-maximized windows.
  + Make window-aliveness checks less aggressive.
  + Fix stylus coordinates when using screen rotation.
  + Preserve keyboard state on VT switch.
  + Fix trackball button scrolling.
  + Fix tiled monitor support.
  + Fix various clipboard issues.
  + Synchronize shadows to server-side decorations.
  + Fix overview key on X11 when using multiple keyboard layouts.
  + Fix capturing with multiple stage views.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Fri Apr 17 2020 bjorn.lie@gmail.com
- Update to version 3.36.1:
  + Fix hardware cursor on GPU hotplug.
  + Fix black areas around XWayland windows when resizing.
  + Fix applying wrong scale to monitors on X11.
  + Fix moving/resizing windows via keyboard on wayland.
  + Fix locate-pointer feature interfering with keybindings.
  + Add support for middle-click emulation.
  + Fix freeze when moving cursor between scaled monitors.
  + Fix popup misplacement with focus-follows-mouse.
  + Fix misplaced cursor in preedit strings.
  + Support mirroring with proprietary Nvidia driver.
  + Support tablets with multiple mode switch buttons in a group.
  + Ignore foreground color for color glyphs (emojis).
  + Allow pad mode switches while showing OSD.
  + Fix positioning of OSD for display-attached tablets.
  + Respect configured RANDR panning on X11.
  + Use correct texture filtering with scaled displays.
  + Fix cursor hotspots in virtual machines.
  + Fix build with GLES and no GL.
  + Work around Firefox bug when copying images on wayland.
  + Fix wrong cursor rotation on rotated displays.
  + Fix glitches in window screencasts.
  + Fix IM support for deleting surrounding text.
  + Fix map animation of maximized windows.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Stop passing %%%%define _lto_cflags %%%%{nil}: No longer needed.
- Drop mutter-wayland-fix-keyboard-move-resize-window.patch: Fixed
  upstream.
* Fri Apr 17 2020 bjorn.lie@gmail.com
- Update to version 3.36.0:
  + Fix placement of popup windows in multi-monitor setups.
  + Fix invisible mouse cursor on some hardware.
  + Updated translations.
* Fri Apr 17 2020 dimstar@opensuse.org
- Update to version 3.35.92:
  + Fix visibility of initially hidden windows.
  + Avoid flicker when (un)redirecting windows.
  + Let BindConstraints update the preferred size.
  + Learn about GLES3.
  + Ping windows on every window focus.
  + Remove overhead from hot code paths.
  + Allow remote desktop services to inhibit animations.
  + Update screen-cast code to PipeWire 0.3 API.
  + Make check-alive timeouts configurable.
  + Make each stage view correspond to a single CRTC.
  + Implement scaled/transformed hardware cursors.
  + Use DMA buffers for screencasting if possible.
  + Make Xwayland startup asynchronous.
  + Fix clipping glitches in long text entries.
  + Add side channel for starting required X11 services.
  + Support synchronized wayland popup moving.
  + Fixed crashes.
  + Plugged memory leaks.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Pass -Dxwayland_initfd=disabled to meson, we are not ready for
  this feature yet in openSUSE, and leaving it to auto breaks
  wayland sessions.
* Fri Apr 17 2020 dimstar@opensuse.org
- Update to version 3.35.91+37:
  + clutter/actor: Add CLUTTER_OFFSCREEN_REDIRECT_ON_IDLE
  + screen-cast: Update to PipeWire 0.3 API
  + window-actor: Make culling of opaque windows X11 only
  + renderer-native: Use hardware acceleration check in generic
    layer
  + remote-access-handle: Expose disable-animations property
  + screen-cast-session: Add 'disable-animations' property
  + wayland: DND and Metawindow fixes.
  + clutter: Make clutter_contraint_update_preferred_size() public
  + bind-constraint: Update the preferred size
  + surface-actor-x11: Avoid flicker when (un)redirecting windows
  + window-actor: Don't show actor until meta_window_actor_show()
  + settings: Improve logging of enabled experimental features
  + Updated translations.
- Drop 0001-Update-to-PipeWire-0.3-API.patch: Fixed upstream.
* Fri Apr 17 2020 dimstar@opensuse.org
- Update to version 3.35.91:
  + Honor accelerometer orientation on monitor config changes.
  + Enable culling for integer-scaled actors.
  + Add ClutterSeat::touch-mode property.
  + Fix mis-scaling when streaming windows.
  + Make the cursor renderer use the transactional KMS API.
  + Advertise MetaMonitor as wl_output.
  + Fix culling of XWayland windows.
  + Only consider enabled effects when disabling culling.
  + Misc. bug fixes and cleanups.
* Fri Apr 17 2020 dimstar@opensuse.org
- Update to version 3.35.90:
  + Cull out clip region.
  + Always enable tap-to-click/drag on opaque Wacom tablets.
  + Fix visual glitches with offscreen effects applied.
  + Fix "sticky corner" in multi-head setups.
  + Fix black shadows around XWayland windows during resizes.
  + Zero-copy path for GPU-less secondary GPUs.
  + Cancel DND on Esc.
  + Sync XWayland window shadows to frame during resizes.
  + Add support for per-monitor workareas.
  + Ensure newly mapped wayland windows receive ENTER event.
  + Add ClutterSeat object.
  + Honour CLUTTER_ACTOR_NO_LAYOUT flag more efficiently.
  + Fix interoperation with wl_data_device_manager v1.
  + Favor text over images in clipboard manager.
  + Apply monitor scale after background texture creation.
  + Plugged memory leaks.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
- Changes from version 3.35.3:
  + backends/native: Correct dy value in pinch gesture event.
  + Upload clipping rectangles in parallel.
  + More cogl API cleanups.
  + Fix window recording on HiDPI.
  + Fix top-left pixel being insensitive to clicks.
  + Misc. bug fixes and cleanups.
- Changes from version 3.35.1:
  + Fix immediate screen blank after releaseing inhibitor.
  + Respond to frame callbacks regardless of damage.
  + Fix Night Light on wayland.
  + Fix various copy+paste/DND regressions.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Drop mutter-fix-mesa20.patch: fixed upstream.
- Add pkgconfig(graphene-gobject-1.0) BuildRequires: new
  dependency.
- Drop cmake BuildRequires: mutter uses meson. No need for a 2nd
  build system.
- Bump api_major to 6, following upstream changes.
* Wed Apr  1 2020 bjorn.lie@gmail.com
- Update to version 3.34.5:
  + Fix visibility of initially hidden windows.
  + Fix hardware cursor on GPU hotplug.
  + Fix pasting images from wayland.
  + Fixed crashes.
  + Updated translations.
- Switch to using explicit released tag in _service.
* Fri Mar 13 2020 alynx.zhou@suse.com
- Add mutter-wayland-fix-keyboard-move-resize-window.patch:
  move some common code out of X11 only code blocks to fix it
  (bsc#1159976, glgo#GNOME/mutter!997).
* Mon Mar  2 2020 alarrosa@suse.com
- Build with pipewire 0.3.0:
  * Add 0001-Update-to-PipeWire-0.3-API.patch
* Tue Feb 25 2020 dimstar@opensuse.org
- Rework mutter-fix-mesa20.patch: base it on mutter upstream commit
  a444a4c.
* Mon Feb 24 2020 sndirsch@suse.com
- Add mutter-fix-mesa20.patch: fixes build against Mesa 20
  (boo#1164688).
* Sun Feb 16 2020 bjorn.lie@gmail.com
- Update to version 3.34.4:
  + Handle mode set race conditions more gracefully.
  + Fix fallback to GLES2.
  + Fix interoperation with wl_data_device_manager v1.
  + Fix visual glitches with offscreen effects applied.
  + Favor text over images in clipboard manager.
  + Fixes crashes.
  + Plugged memory leaks.
  + Misc. bug fixes.
  + Updated translations.
* Sat Jan 25 2020 dimstar@opensuse.org
- No longer recommend -lang: supplements are in use
* Sun Jan  5 2020 bjorn.lie@gmail.com
- Update to version 3.34.3+0:
  * Bump version to 3.34.3
* Wed Jan  1 2020 bjorn.lie@gmail.com
- Update to version 3.34.2+2:
  * clutter/stage: Fix picking of rectangles with negative
    positions.
* Tue Dec 24 2019 dimstar@opensuse.org
- Update to version 3.34.2+1:
  * screen-cast: Fix window recording on HiDPI
* Fri Dec 13 2019 dead_mozay@opensuse.org
- Update to version 3.34.2+0:
  * Update British English translation
  * backends/native: Fix double free of error
  * kms-impl/simple: Fix meta_set_fallback_feedback_idle
  * kms: Process impl idle callbacks before pre dispatch flush
* Tue Dec 10 2019 bjorn.lie@gmail.com
- Add explicit pkgconfig(fribidi) and pkgconfig(glib-2.0)
  BuildRequires: meson checks for it.
* Mon Dec  2 2019 fcrozat@suse.com
- Add mutter-disable-cvt-s390x.patch: do not search cvt on s390x,
  it doesn't exist there (bsc#1158128).
* Mon Dec  2 2019 dimstar@opensuse.org
- Update to version 3.34.1+66:
  * stack: Allow promoting transient windows to their parent's layer
  * shaped-texture: Do not invalidate content on set_cogl_texture()
  * cursor-tracker: Add API to keep the wayland pointer focus while hidden
  * device-manager-x11: Ignore events if no source device is set
  * clutter/cally-root: Use g_clear_signal_handler and fix a signal leak
  * wayland: Move "ownership" of the DnD selection source to the data device
  * wayland: Do not cancel data source on offer destruction
  * wayland: Avoid redundant cancel() call
  * wayland: Drop unused wl_signal structs
* Tue Nov 19 2019 dimstar@opensuse.org
- Update to version 3.34.1+57:
  * cursor-renderer/native: Fix cursor drawing in combination with panel_orientation_transform
  * output-kms: Fix "panel orientation" kms-prop being ignored on native outputs
  * compositor: Plug cairo_region_t leak
  * backends: Plug MetaKmsPageFlipData leak
  * input-settings/x11: Add missing clutter_x11_trap_x_errors around XIGetProperty
  * plugin-manager: Kill window effects on destroy
  * plugins/default: Handle skipped animations
  * wayland/surface: Don't double scale when getting absolute coordinates
  * window-props: Don't set override redirect windows as top-level parent
  * window-props: Don't look for parent multiple times
  * window: Assert we only set a NULL workspace when unmanaging
  * window: Warn if O-R window workspace state is used
  * wayland/actor-surface: Always store away frame callbacks on commit
  * ci: Fix checking out gnome-shell on stable branches
  * x11-display: Don't unset the X11 focused window after setting one
  * tests/monitor-unit-tests: Add another tiling window hot plug test
  * window: Reset tile monitor number when untiling
  * tests/monitor-unit-tests: Add window tiling hot plug test
  * tests/runner: Move window shown synchronization to helper
  * tests/monitor-unit-tests: Move test client sanity check into helper
  * window: Always update tile monitor number on hot plug
  * plugins/default: Clean up tile preview when closing display
  * plugin/default: Init quark before using
  * display: Add 'closing' signal
  * renderer-native: Separate offscreen and shadowfb
  * clutter/stage-view: Separate offscreen and shadowfb
* Wed Oct 30 2019 dimstar@opensuse.org
- Update to version 3.34.1+31:
  * wayland: Check stylus serials on meta_wayland_seat_can_popup()
  * x11: Limit touch replay pointer events to when replaying
  * display: Move finishing of touch sequence to the backend
  * x11: Update X11 focus before updating MetaDisplay focus
* Wed Oct 23 2019 bjorn.lie@gmail.com
- Update to version 3.34.1+27:
  + wayland/surface: Reset buffer_destroy_handler_id.
  + window-actor: Add a missing NULL-check.
  + monitor-manager: check for underscan setting validity upfront.
  + clutter/stage: Actually set key focus to an actor on key focus.
  + clutter/actor: Save key-focus state and unset it before
    destruction.
  + dbus-session-watcher: Chain up to parent finalize().
* Thu Oct 17 2019 alynx.zhou@suse.com
- Rebase patches:
  + Update mutter-SLE-bell.patch
  + Disable mutter-SLE-bsc984738-grab-display.patch
* Sun Oct 13 2019 bjorn.lie@gmail.com
- Update to version 3.34.1+21:
  + x11: Map mimetypes back to selection atoms
  + wayland:
  - Figure out better the right selection source for a
    wl_data_offer
  - Set dummy selection source on .set_selection(null)
  - Simplify MetaSelectionSourceWayland
  - Check resource before emitting cancelled event
  - Emit wl/primary offer after changing selection
  - Chain up to the right finalize on
    MetaWaylandDataSourceWayland
  - Drop field from MetaWaylandDataSourcePrimary
  - Plug MetaSelectionSourceWayland leaks
  + clutter/shader-effect: Initialize shader-type properly
  + ci: Change the without-native-backend to not build with Wayland
    too
  + main: Warn instead of error in meta_test_init()
- Switch to the now available 3-34 stable branch in service.
* Thu Oct 10 2019 bjorn.lie@gmail.com
- Update to version 3.34.1+9:
  + kms/crtc: Read gamma state when prediction failed.
  + kms: Always predict state after processing update.
  + clutter-backend-x11: Don't push keymap events to clutter.
  + event-x11: Use CLUTTER prefix for X11 filter docs.
  + x11: Translate well known selection atoms to mimetypes.
  + wayland/actor-surface: Queue redraw for frame callback.
  + wayland/surface: Some minor coding style clean up.
  + cogl-pango/meson.build: Remove extraneous quoting.
  + backends: Update inhibited state for the monitor and respect
    that state.
* Wed Oct  9 2019 bjorn.lie@gmail.com
- Update to version 3.34.1:
  + Fix startup of X11 session services on wayland.
  + Fix _NET_ACTIVE_WINDOW emission.
  + Fix initial view perspective.
  + Fix screenshots and window animations when scaled.
  + Re-enable coredumps when capabilities are set.
  + Fix scaling of DND surface actors.
  + Optimize blitting of untransformed offscreen stage views.
  + Fix freeze of pointer event delivery on X11.
  + Fix scaling of stylus input coordinates with HiDPI.
  + Fix memory leak when using implicit animations.
  + Fix numlock state for native backend.
  + Fixed crashes.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Thu Oct  3 2019 fcrozat@suse.com
- Disable sysprof support until it get security team approval.
* Sat Sep 21 2019 bjorn.lie@gmail.com
- Update to version 3.34.0+30:
  + window-actor: Use surface coordinates for the fast path in
    get_image()
  + shaped-texture: Use surface coordinates in get_image()
  + shaped-texture: Declare that we inherit from GObject
  + window/surface-actor: Add docstrings
  + shaped-texture: Mark set the clip and return value nullable
  + clutter/actor: Cancel delayed timelines on removal
  + clutter/timeline: Don't emit ::paused signal on delayed
    timelines
  + clutter/timeline: Use a function to cancel the delay timeout
  + wayland/dma-buf: Handle zero modifiers from
    eglQueryDmaBufModifiersEXT
  + stage: Compute view perspective when parameters changed
  + build: Compile with `-ffloat-store` on x86 (32 bit)
  + kms-impl-device: Use portable formatting for 64-bit integers
  + output-kms: Use portable formatting for 64-bit integers
  + input-settings: Use portable formatting for 64-bit integers
  + clutter/stage-cogl: Use portable formatting for 64-bit integers
  + clutter/paint-node: Convert safely from pointer to integer
* Tue Sep 17 2019 bjorn.lie@gmail.com
- Update to version 3.34.0+14:
  + idle-monitor: Reset timeout before firing watch
  + idle-monitor: Remove redundant type cast
  + idle-monitor: Make helper function static
  + kms-device: Free path when finalizing
  + kms-device: Handle impl device creation failure
  + x11: Minor refactor of input focus handling code
  + x11: Use the currently focused X window for _NET_ACTIVE_WINDOW
* Fri Sep 13 2019 bjorn.lie@gmail.com
- Update to version 3.34.0+7:
  + cogl/egl: Just notify about failure to create high priority
    context
  + clutter/actor:
  - Remove unused private function
  - Fix a wrong comment
  + Fix a few tracing typos
  + core: Split x11-display initialization in 2 signals
  + plugins/default: Get default keymap from localed
  + Updated translations.
- Switch to checkout from master, we need the fixes for stability.
* Mon Sep  9 2019 mgorse@suse.com
- Update to version 3.34.0:
  + Fix xdg-output v3 support.
  + Fix crash when changing decoration state.
  + Add and remove connectors on hot-plug.
* Sat Sep  7 2019 bjorn.lie@gmail.com
- Fixup _service to follow our standards.
* Thu Sep  5 2019 luke@ljones.dev
- Update to version 3.33.92:
  + Turn MetaShapedTexture into a ClutterContent implementation.
  + Restore inhibit shortcut for overlay key.
  + Misc. pointer a11y improvements.
  + Fix position of drag surfaces.
  + Implement subsurface.place_below() for parents.
  + Add meta_window_actor_get_image().
  + Revert faulty optimization from !719.
  + Add additional sysprof trace points.
  + Remove GLX "threaded swap wait" used on Nvidia.
  + Implement geometric picking.
  + Fix lost keyboard focus after DND.
  + Misc. bug fixes and cleanups.
- Drop
  mutter-iconcache-Support-RGB16_565-format-for-16-bit-color-.patch
* Thu Aug 29 2019 luke@ljones.dev
- Remove mutter-xwayland-create-xauthority.patch, upstreamed.
  Autostart of xwayland is enabled, and also sets xauthority.
* Wed Aug 28 2019 luke@ljones.dev
- Update to version 3.33.91
  + Fix primary selection copy and paste between X11 and wayland.
  + Improve monitor hotplug support.
  + Remove a source of frame skips.
  + Fix windows being lowered after unmaximizing with double click.
  + Remove Clutter API for global grabs.
  + Improve processing of incompressible events.
  + Add xdg-output v3 support.
  + Misc. bug fixes and cleanups.
- Changes from version 3.33.90
  + Fix visibility of clones with hidden source.
  + Reduce freezes when opening some popup windows.
  + Be more thorough when excluding obscured areas from painting.
  + Make it possible to start Xwayland on demand.
  + clutter: Expose layout_manager to transitions.
  + Misc. bug fixes and cleanups.
- Changes from version 3.33.4
  + Discard page flip retries on hotplug.
  + Add xdg-output v2 support.
  + Restore DRM format fallbacks.
  + Don't emit ::size-changed when only position changed.
  + Expose workspace layout properties.
  + Don't use grab modifiers when shortcuts are inhibited.
  + Fix stuttering due to unchanged power save mode notifications.
  + Add API to reorder workspaces.
  + Make picking a new focus window more reliable.
  + Defer actor allocation till shown.
  + Try to use primary GPU for copy instead of glReadPixels.
  + Unset pointer focus when the cursor is hidden.
  + Fix modifier-drag on wayland subsurfaces.
  + Fix background corruption on Nvidia after resuming from suspend.
  + Only grab the locate-pointer key when necessary.
  + Misc. bug fixes and cleanups.
- Changes from version 3.33.3
  + Prepare for running Xwayland on demand.
  + Fix text selection color rendering.
  + Fix black shadows when using fractional scaling.
  + Honor startup sequence workspace on wayland.
  + Only emit 'grab-op-end` signal after dropping grabs.
  + Add a Sysprof-based profiler.
  + Relax "xwayland-allow-grabs" setting.
  + Implement locate-pointer accessibility feature.
  + Implement mouse accessibility.
  + Consolidate frame throttling.
  + Fix setting blank cursor under wayland.
  + Pixel-align OpenGL cursors.
  + Handle returning from fullscreen/maximization better.
  + Improve screencast support on multi-monitor systems.
  + Fix running X11 applications with sudo under wayland.
  + Implement toggle-keys notification.
  + Add initial KMS transactional support.
  + Improve finding new focus window when the old one is closed.
  + Misc. bug fixes and cleanups.
- Changes from version 3.33.2
  + Fix rendering lag on Xorg.
  + Misc. bug fixes and cleanups.
- Changes from version 3.33.1
  + Remove unused APIs and outdated driver support
  + Enable EGL_IMG_context_priority.
  + Disable mouse keys with Numlock on.
  + Fix crash when restarting on X11.
  + Implement clipboard manager.
  + Fix spurious idle signals that prevent session unblank.
  + Fix mapping of touchscreens that don't report dimensions.
  + Fix propagating fractional scaling factor.
  + Add experimental RT scheduling support.
  + Misc. bug fixes and cleanups.
* Wed Jul 24 2019 bjorn.lie@gmail.com
- Update to version 3.32.2+43:
  + metatest: Dispatch the destruction instead of sleeping after it
  + window-x11: Remove double definition of MetaStack
  + window-x11: Focus a window in the active workspace as
    take-focus fallback
  + meson: Bump meson requirement to 0.50.0
  + window-x11: Use any focusable window as fallback delayed focus
    window
  + tests: Add "accept_take_focus" command
  + test-client: Add x11 events GSource handler
  + stack: Add a function to get a sorted list of focus candidates
  + window-x11: Accept any focusable window as fallback focus
  + window-x11: Don't double-check for unmanaging windows
- Switch to git checkout via source service, upstream is lacking in
  stable releases. In the future we will use a stable tag when
  possible, but when upstream slacks off, we will use a checkout of
  the stable branch.
* Wed May 29 2019 bjorn.lie@gmail.com
- Drop unneeded and unused libtool BuildRequires.
* Sun May 26 2019 bjorn.lie@gmail.com
- Update to version 3.32.2:
  + Disable mouse keys with Numlock on.
  + Fix crash when restarting on X11.
  + Fix mapping of touchscreens that don't report dimensions.
  + Fix spurious idle signals that prevent session unblank.
  + Misc. bug fixes and cleanups.
* Fri May 24 2019 yfjiang@suse.com
- Update spec to reflect the rebase of
  mutter-xwayland-create-xauthority.patch (bsc#1084737).
* Fri May 24 2019 xwang@suse.com
- Update mutter-xwayland-create-xauthority.patch (bsc#1084737).
* Wed Apr 24 2019 mliska@suse.cz
- Disable LTO (boo#1133121).
* Thu Apr 18 2019 dimstar@opensuse.org
- Update to version 3.32.1:
  + Fix fallback app menu on wayland (glgo#GNOME/mutter#493).
  + Fix elogind support (glgo#GNOME/mutter!491).
  + Fix startup notifications not timing out
  + (glgo#GNOME/mutter#501).
  + Fix keyboard accessibility toggle from keys
  + (glgo#GNOME/mutter!501, glgo#GNOME/mutter#529,
  + glgo#GNOME/mutter!531).
  + Fix touchscreen input on rotated displays
  + (glgo#GNOME/mutter#514).
  + Work around hangul text input bug (glgo#GNOME/mutter#1365).
  + Fix blurry wallpaper scaling (glgo#GNOME/mutter!505).
  + Fix placement of window menu when using fractional scaling
  + (glgo#GNOME/mutter#527).
  + Fix repaint issues of offscreen effects on secondary monitors
  + (glgo#GNOME/mutter!511).
  + Fix windows not getting focus after launch
  + (glgo#GNOME/mutter#505).
  + Properly advertise support for 'underscan' property
  + (glgo#GNOME/mutter!507).
  + Improve power-saving handling (glgo#GNOME/mutter!506).
  + Fix moving windows by super+touch [Jonas D.; !495]
  + Misc. bug fixes and cleanups: glgo#GNOME/mutter!478,
    glgo#GNOME/mutter!475, glgo#GNOME/mutter!480,
    glgo#GNOME/mutter!482, glgo#GNOME/mutter#490,
    glgo#GNOME/mutter!488, glgo#GNOME/mutter#491,
    glgo#GNOME/mutter#480, glgo#GNOME/mutter!477,
    glgo#GNOME/mutter!496, glgo#GNOME/mutter!492,
    glgo#GNOME/mutter!485, glgo#GNOME/mutter!515,
    glgo#GNOME/mutter!519, glgo#GNOME/mutter!521,
    glgo#GNOME/mutter!216, glgo#GNOME/mutter!538,
    glgo#GNOME/mutter#541, glgo#GNOME/mutter#523.
  + Updated translations.
- Drop mutter-fix-meson50-build.patch: fixed upstream.
- Rebase
  mutter-iconcache-Support-RGB16_565-format-for-16-bit-color-.patch.
* Tue Mar 12 2019 bjorn.lie@gmail.com
- Update to version 3.32.0:
  + Fix deadlock when cancelling a theme sound.
  + Stop swizzling BGRA buffers (bye-bye inverted colors in
    screenshots and animations).
- Add mutter-fix-meson50-build.patch: Fix build with meson >= 0.50
* Tue Mar  5 2019 bjorn.lie@gmail.com
- Update to version 3.31.92:
  + Fix flicker of apps that use multiple SHM buffers.
  + Don't disable page flips after temporary failures.
  + Improve redraw performance.
  + Add cursor-mode support to window screencasting.
  + Add back support for system-wide monitor configurations.
  + Add fractional scaling support.
  + Consider remapped keys when guessing keycode from keysym.
  + Stop turning on-screen-keyboard off on focus changes.
  + Fix crashes.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Pass cogl_tests=false, clutter_tests=false and tests=false to
  meson, we can now disable tests fully.
* Fri Feb 22 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + Fix infinite loop in EDID matching.
  + wayland:
  - Don't reset in text-input state prematurely.
  - Don't maximize windows if minimum size is too big.
  + Fix crash when using "restore shortcuts" without focus window.
  + Add flag parameter to grab accelerator API.
  + Reuse old CRTC if possible to avoid flicker on hotplug.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Drop patches fixed upstream:
  + mutter-Avoid_double-free_crash.patch: cogl-auto-texture: Avoid
    a double-free crash.
  + mutter-clutter-offscreen-effect-fix.patch:
    clutter-offscreen-effect: Disable if no texture.
  + mutter-clutter-Avoid-rounding-compensation.patch: clutter:
    Avoid rounding compensation when invalidating 2D actors.
  + mutter-Fix-monitor-recording-on-HiDPI.patch: screen-cast: Fix
    monitor recording on HiDPI.
  + mutter-monitor-manager-Dont-use_switch-config.patch:
    monitor-manager: Don't use switch-config when ensuring
    configuration.
* Thu Feb 21 2019 bjorn.lie@gmail.com
- Add bug fix patches from upstream stable branch:
  + mutter-Avoid_double-free_crash.patch: cogl-auto-texture: Avoid
    a double-free crash.
  + mutter-clutter-offscreen-effect-fix.patch:
    clutter-offscreen-effect: Disable if no texture.
  + mutter-clutter-Avoid-rounding-compensation.patch: clutter:
    Avoid rounding compensation when invalidating 2D actors.
  + mutter-Fix-monitor-recording-on-HiDPI.patch: screen-cast: Fix
    monitor recording on HiDPI.
  + mutter-monitor-manager-Dont-use_switch-config.patch:
    monitor-manager: Don't use switch-config when ensuring
    configuration.
* Thu Feb 21 2019 qkzhu@suse.com
- Add mutter-Lower-HIDPI_LIMIT-to-144.patch: mutter will set
  scaling factor to 2 when the monitor's dpi is greater than 144
  (96*1.5) to keep GNOME's behavior consistent with YaST Installer
  (fate#326682, bsc#1125467).
* Wed Feb 13 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Fix support of extended characters in on-screen keyboard.
  + Improve selection of the primary GPU.
  + Screen-cast cursor updates as PipeWire stream metadata.
  + Fix rendering glitches in magnifier.
  + Fix monitor recording on HiDPI.
  + Honour secondary GPU supported pixel formats.
  + Fall back to CPU copy path when using a software renderer.
  + Remove fallback app menu.
  + wayland: Add support for viewporter protocol.
  + Misc. bug fixes and cleanups.
  + Updated translations.
- Disable
  mutter-iconcache-Support-RGB16_565-format-for-16-bit-color-.patch
- Set api_minor define to 0.
* Wed Feb  6 2019 bjorn.lie@gmail.com
- Fix translation-update-upstream call, needed after update of
  translation-update-upstream in distro.
* Fri Jan 11 2019 bjorn.lie@gmail.com
- Update to version 3.31.4:
  +  keybindings: Limit corner move to current monitor.
  + xdg-output: Report rotated physical dimensions.
  + Add continuous integration pipeline.
  + Improve performance on secondary GPUs.
  + Use the actual hardware refresh rate.
  + Remove hide-titlebar-when-maximized support.
  + wayland: Implement buffer transforms.
  + Remove ability to externally set sync-to-vblank.
  + Turn off touchscreens together with DPMS.
  + Mipmap the wallpaper when shrinking.
  + Implement RecordWindow method for screen-casts.
  + Fix EGLStream texture downloading.
  + Split out display-server-specific code from MetaWindowActor.
  + Improve render performance on some KMS devices with software
    GL.
  + Fix damage area of transformed surfaces.
  + Remove autotools support.
  + Misc. bug fixes and cleanups: bgo#790207, bgo#765011,
    bgo#786663 bgo#782344, bgo#781034, glgo#GNOME/mutter!309,
    glgo#GNOME/mutter#272, glgo#GNOME/mutter#393,
    glgo#GNOME/mutter#276, glgo#GNOME/mutter#404,
    glgo#GNOME/mutter#104, glgo#GNOME/mutter!343,
    glgo#GNOME/mutter#342, glgo#GNOME/mutter!356,
    glgo#GNOME/mutter#414, glgo#GNOME/mutter#423,
    glgo#GNOME/mutter!374, glgo#GNOME/mutter!382,
    glgo#GNOME/mutter!383.
- Drop patches fixed upstream mutter-fix-startup.patch and
  mutter-monitor-manager-Don-t-use-switch-config-when-ensurin.patch
- Bump api_major to 4 following upstreams changes.
- Pass -Degl_device=true to meson, ensure we build egl support.
- Pass -Dinstalled_tests=false to meson, running tests during build
  are something we will look into later in the cycle.
* Sat Jan  5 2019 bjorn.lie@gmail.com
- Update to version 3.31.2:
  + Fix handling of non-UTF8 encodings.
  + Fix memory leaks introduced in 3.30.1.
  + Fix regression when overriding workspace layout.
  + Fix crash when restarting window manager.
  + Add meson build support.
  + Freeze clock when headless.
  + Fix crash on monitor hotplug.
  + Misc. bug fixes.
- Drop
  mutter-wayland-text-input-Ignore-text-input-state-commit-wh.patch
  Fixed upstream.
- Disable mutter-xwayland-create-xauthority.patch: Needs rebase.
- Switch to meson buildsystem, add meson BuildRequires and macros.
- Add xorg-x11-server, xorg-x11-server-wayland and
  pkgconfig(gnome-settings-daemon) BuildRequires: New dependencies.
- Set api_minor define to 0_0_0.
* Tue Dec 18 2018 bjorn.lie@gmail.com
- Add two patches from fedora that have not been applied to the
  stable branch:
  + mutter-monitor-manager-Don-t-use-switch-config-when-ensurin.patch:
    monitor-manager: Don't use switch-config when ensuring
    configuration.
  + mutter-wayland-text-input-Ignore-text-input-state-commit-wh.patch:
    wayland/text-input: Ignore text-input state commit when not
    focused.
* Wed Nov 14 2018 bjorn.lie@gmail.com
- Update to version 3.30.2:
  + Fix handling of non-UTF8 encodings.
  + Fix memory leaks introduced in 3.30.1.
  + Work around hangul text input bug.
  + Fix crash when restarting window manager.
  + Fix crash on monitor hotplug.
  + Updated translations.
* Tue Oct  9 2018 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + Improve trackball detection (glgo#GNOME/mutter#258).
  + Fix clipping of scaled surfaces (glgo#GNOME/mutter#300).
  + Improve tracking of monitor switch configuration
    (glgo#GNOME/mutter!213).
  + Fix parent-relative positioning of constrained windows
    (glgo#GNOME/mutter#332).
  + Add clutter_input_method_forward_key() method
    (glgo#GNOME/gnome-shell#531).
  + Various crash fixes (glgo#GNOME/mutter#194,
    glgo#GNOME/mutter#336).
  + Misc. bug fixes: glgo#GNOME/gnome-shell#540,
    glgo#GNOME/mutter#294, glgo#GNOME/mutter#221,
    glgo#GNOME/mutter!229, glgo#GNOME/mutter#30 and
    glgo#GNOME/mutter#331.
  + Updated translations.
* Thu Sep  6 2018 luc14n0@linuxmail.org
- Update to version 3.30.0:
  + Updated translations.
* Sat Sep  1 2018 luc14n0@linuxmail.org
- Update to version 3.29.92:
  + Avoid crash when a cursor is not found (glgo#GNOME/mutter#254).
  + Fix screen rotation regression (glgo#GNOME/mutter#216).
  + Handle requests to unmanaged windows gracefully
    (glgo#GNOME/mutter#240).
  + Move popups together with their parent (glgo#GNOME/mutter#274).
  + Fix non-lowercase letters on virtual key devices
    (glgo#GNOME/gnome-shell#135).
  + Misc. bug fixes: glgo#GNOME/mutter#223, glgo#GNOME/mutter#192,
    glgo#GNOME/mutter#279.
  + Updated translations.
- Drop mutter-left-right-rotation-fix.patch: fixed upstream.
* Tue Aug 21 2018 dimstar@opensuse.org
- Update to version 3.29.91:
  + Various crash fixes (glgo#GNOME/mutter#255,
    glgo#GNOME/mutter#223).
  + Fix lock up with some DRI drivers (glgo#GNOME/mutter#127).
  + Send correct button codes from virtual evdev devices.
  + Improve grab-device clock updates on X11.
  + Fix popups closing immediately on key down.
  + Prevent clients from modifying the shared keymap (bgo#784206).
  + Updated translations.
- Drop mutter-pipewire-fix.patch: fixed upstream.
* Sat Aug 18 2018 badshah400@gmail.com
- Add mutter-left-right-rotation-fix.patch to fix blank screen
  when rotating it left/right (boo#1105268,
  glgo#gnome/mutter#216); patch taken from upstream bug report.
* Fri Aug  3 2018 bjorn.lie@gmail.com
- Update to version 3.29.90:
  + Don't expose resolutions that are below the minimum
    (bgo#793223).
  + Remove support for preference overrides (bgo#786496).
  + Various crash fixes: glgo#GNOME/mutter#189,
    glgo#GNOME/mutter#70, glgo#GNOME/mutter#194,
    glgo#GNOME/mutter#15, glgo#GNOME/mutter#130.
  + Misc. bug fixes and cleanups: glgo#GNOME/mutter#131,
    glgo#GNOME/mutter#245, glgo#GNOME/mutter!176.
  + Updated translations.
- Add mutter-pipewire-fix.patch, replace pkgconfig(libpipewire-0.1)
  with pkgconfig(libpipewire-0.2) BuildRequires. Also add libtool
  BuildRequires and pass autoreconf call.
* Wed Jul 25 2018 luc14n0@linuxmail.org
- Update to version 3.29.4:
  + Fix crash with parent-less modal dialogs
    (glgo#GNOME/mutter#174).
  + Preserve paint volumes where possible to optimize CPU usage
    (bgo#782344).
  + Updated translations.
- Changes from version 3.29.3:
  + Fix Korean Hangul support on wayland (glgo#GNOME/mutter#152).
  + Improve support for proprietary Nvidia driver (bgo#790316).
  + Only upload HW cursor sprite to the GPU that will display them
    (glgo#GNOME/mutter#77).
  + Improve EGLstream support (glgo#GNOME/mutter#2, bgo#782575).
  + Misc. bug fixes: glgo#GNOME/mutter#160, bgo#786929, bgo#788834.
  + Updated translations.
- Rebase mutter-xwayland-create-xauthority.patch.
* Tue Jul 24 2018 bjorn.lie@gmail.com
- Refresh openSUSE patches with quilt.
* Mon Jul 23 2018 bjorn.lie@gmail.com
- Update to version 3.28.3+20180719.62660bbd1:
  + gpu-kms: Don't crash if drmModeGetResources returns NULL.
  + Bump version to 3.28.3.
  + monitor-manager: Add back warning messages.
  + screen-cast-src: Allow negotiating the framerate.
  + contraints: Do not constrain modals without parent.
  + backends:
  - Add logical monitor -> monitor -> output -> crtc ref chain.
  - Move MetaOutput::crtc field into private struct.
  + renderer-native: Don't crash if the FB surface can't be locked.
  + device-manager-evdev:
  - Add main seat to seats by default.
  - Free the main seat on finalize.
  - Set and unset the stage for the main seat too.
  + clutter-device-evdev: Get devices from main seat if no real
    seat is set.
  + clutter-seat-evdev: Add function to get device by id.
* Fri Jul  6 2018 bjorn.lie@gmail.com
- Add pkgconfig(libpipewire-0.1) BuildRequires and pass
  enable-remote-desktop to configure, build remote-desktop support,
  now that pipewire is available.
* Fri Jun 22 2018 luc14n0@linuxmail.org
- Update to version 3.29.2:
  + Fix size change animations on wayland (bgo#780292).
  + Handle touch events on server-side titlebars (bgo#770185).
  + Misc. bug fixes: glgo#GNOME/mutter#134, glgo#GNOME/mutter#124,
    glgo#GNOME/mutter#138, glgo#GNOME/mutter#781471,
    glgo#GNOME/mutter#150.
* Sun Jun  3 2018 luc14n0@linuxmail.org
- Update to version 3.29.1 (bsc#1093541):
  + Fix various input-method regressions glgo#GNOME/mutter#65,
    glgo#GNOME/mutter#74, glgo#GNOME/mutter#66,
    glgo#GNOME/mutter#112).
  + Take inhibitors into account for monitoring idle (bgo#705942).
  + Misc. bug fixes: glgo#GNOME/mutter#83, glgo#GNOME/mutter#104,
    glgo#GNOME/mutter#157, glgo#GNOME/mutter#130,
    glgo#GNOME/mutter#21.
  + Updated translations.
- Drop:
  + libtool BuildRequires, autogen execution and source service,
    and use upstream tarball once more: the situation has been
    normalized.
  + intltool BuildRequires to follow upstream migration to Gettext.
* Mon May 28 2018 bjorn.lie@gmail.com
- Update to version 3.28.2+20180526.abc7ad8e9:
  + wayland: Don't reset input focus on text commit.
  + frames: Allow for unknown mouse buttons.
  + wayland: update enter/leave output after effects.
  + window-actor: add new signal "effects-completed".
  + wayland: Compare geometries after chaining up.
  + frames: Handle touch events.
  + frames: Make 1st button/motion handlers take generic events.
  + clutter/evdev: Don't ignore CAPS lock as modifier.
  + clutter/evdev: ignore injected events from IM.
  + wayland: Use cursor position in logical monitor.
* Thu May 17 2018 hpj@suse.com
- Enable remote desktop support:
  + Add pkgconfig(libpipewire-1.0) BuildRequires.
  + Pass --enable-remote-desktop to configure.
* Wed May  9 2018 bjorn.lie@gmail.com
- Update to version 3.28.2+20180507.41303bc01:
  + Bump version to 3.28.2
  + build: Adjust to filename changes
  + build: Introspect some more types
  + window-group: Remove undefined function declaration
  + clutter: Don't reference invalid pc in gir
  + screen-cast: Handle PipeWire errors more gracefully
  + wayland/xdg-foreign: Fix child surface validation check
  + wayland/xdg-foreign: Send immediate destroy event to correct
    resource
  + build: Don't fail immediately when logind is missing
  + wayland: Check if state and size changed before calling
    move_resize()
  + wayland: Add function to query if window needs move or resize
  + window: Let implementations finish state changes
  + wayland: avoid a crash in is_effectively_synchronized()
  + native: Restore previous EGL state after blitting onto
    secondary GPU
  + cogl: Do not unref a NULL object
  + monitor-manager: Find active monitor when deriving global scale
  + wayland: Let IM events go through
  + backend: Don't center the pointers on monitor changes
  + backends: Don't center the pointer on initialization
  + xwayland: Don't abort if Xwayland crashes
  + xwayland: use g_autoptr for GError in xserver_died
  + theme, frames: Use surface device scale instead of cairo_scale
  + wayland: Do not reset frame list when merging pending state
  + clutter: Set slave=master in IM forwarded key events
* Wed Apr 18 2018 bjorn.lie@gmail.com
- Update to version 3.28.1+20180416.d3d5eb8e1:
  + idle-monitor: Add ResetIdletime API, for testing purposes
  + backend: Reset idle when lid is opened or resuming from suspend
  + idle-monitor: Take idle inhibition into account
  + x11: Allow XTest and core events to reset idletime
  + backends: Remove X11 idle-monitor backend
  + wayland: Plug surface pending state contents leak
  + monitor-manager: fix output ids returned by GetResources
  + native: Disable the use of KMS modifiers by default
  + Updated translations.
- Switch back to using git-checkout via source-service, upstream
  seems unable to produce tarballs.
- Following the above, add libtool BuildRequires and pass
  autogen.sh to bootstrap.
* Thu Apr  5 2018 bjorn.lie@gmail.com
- Pass --enable-gles2=yes to configure, build gles2 support in
  cogl, disabled by default from upstream. We already had the
  needed pkgconfig(glesv2) BuildRequires in place.
* Thu Mar 22 2018 hpj@suse.com
- Retire mutter-xwayland-use-gdm-auth-file.patch in favor of
  mutter-xwayland-create-xauthority.patch (bsc#1084737). We now
  create the cookie in mutter itself.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Wed Mar 14 2018 hpj@suse.com
- Add mutter-xwayland-use-gdm-auth-file.patch (bsc#1084737): If
  an Xauthority file was created for us by the display manager,
  pass it to Xwayland -auth.
* Mon Mar 12 2018 bjorn.lie@gmail.com
- Update to version 3.28.0:
  + Fix xdg-foreign regression (glgo#mutter#63).
  + Updated translations.
* Mon Mar 12 2018 dimstar@opensuse.org
- Obsolete libmutter-1-0 by libmutter-2-0: Needed in order to make
  upgrades work reliably. As libmutter is so closely tied to mutter
  itself, we should probably consider in the future to fold it back
  into the main package.
* Fri Mar  9 2018 bjorn.lie@gmail.com
- Add mutter_major and mutter_minor define, and set them to 2 and
  0 respectively, make future sover bumps less painfull to
  package.
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 3.27.92:
  + Fix use of modifiers with multi-GPU systems.
  + Add xdg-shell stable support (bgo#791938).
  + Fix scaling of icons in titlebar buttons
    (glgo#GNOME/mutter#23).
  + Implement missing wacom functionality on X11
    (glgo#GNOME/mutter#48).
  + Force 8-bit RGB config (glgo#GNOME/mutter#2).
  + Misc. bug fixes: glgo#GNOME/mutter#6, glgo#GNOME/mutter#27,
    bgo#792203.
  + Updated translations.
- Drop mutter-force-rgb8.patch: fixed upstream.
- Rename libmutter-1-0 subpackage to libmutter-2-0, following
  upstreams sover bump.
* Thu Mar  1 2018 dimstar@opensuse.org
- Update to version 3.27.91 (bsc#1133445):
  + Fix handling of trackball settings on wayland (bgo#787804).
  + Apply font settings on wayland (bgo645433).
  + Fix keybindings getting mixed up with some layouts
    (bgo#789300).
  + Fix bluetooth mouse cursor disappearing after idle
    (bgo#761067).
  + Support platforms that export EGL_KHR_platform_gbm
    (bgo#780668).
  + Add keyboard accessibility support on wayland (bgo#788564).
  + Fix missing cursor when using screen magnifier (bsc#1120290
    bgo#754806).
  + Fix external monitor shutting off on wayland when lid closes
    (bgo#788915).
  + Add xdg-output support (bgo#787363).
  + Add Xwayland grab keyboard support (bgo#783342).
  + Allow shortcut inhibition of the super key (bsc#1120372
    bgo#790627).
  + Take "panel orientation" drm_connector property into account
    (bgo#782294).
  + Fix focus window ending up below other windows on wayland
    (bgo#780820).
  + Fix maximized windows restoring to a tiny size on wayland
    (bgo#783901).
  + Fix tap-and-drag setting on X11 (bgo#775755).
  + Fix handling of single-touch devices on wayland
    (bgo#792005).
  + Support tiled/compressed buffers (bgo#785779).
  + Port screencast support to pipewire 0.1.8 (bgo#792854).
  + Add support for third stylus button on newer tablets
    (bgo#790033).
  + Fix background corruption regression on nvidia (bgo#739178).
  + Misc. bug fixes: bgo#789153, bgo#788493, bgo#784314,
    bgo#789227, bgo#789223, bgo#789277, bgo#782344, bgo#789552,
    bgo#789553, bgo#788695, bgo#789984, bgo#788764, bgo#789386,
    bgo#784545, bgo#790336, bgo#790358, bgo#791022, bgo#791006,
    bgo#789070, bgo#772218, bgo#791383, bgo#791809, bgo#776220,
    bgo#791916, bgo#792281, bgo#790309, bgo#791371, bgo#792527,
    bgo#792599, bgo#788834, bgo#792765, bgo#792062, bgo#645460,
    bgo#792853, bgo#792818, bgo#789501, bgo#789961,
    glgo#GNOME/mutter#2, glgo#GNOME/mutter#8, glgo#GNOME/mutter#12,
    glgo#GNOME/mutter#10, glgo#GNOME/mutter#13,
    glgo#GNOME/mutter#1, glgo#GNOME/mutter#26,
    glgo#GNOME/mutter#28, glgo#GNOME/mutter#35,
    glgo#GNOME/mutter#36, glgo#GNOME/mutter#38.
- Rebase mutter-force-rgb8.patch.
* Thu Mar  1 2018 badshah400@gmail.com
- Update to version 3.27.1:
  + Support hybrid GPU systems (bgo#785381).
  + Fix monitor-manager not chaining up to the parent after new
    implementation addition (bgo#788921).
- Add BuildRequires: Mesa-libGLESv3-devel, new upstream
  dependency; this is actually not detected by the configure
  script, so builds end up failing at the make stage when the
  headers are not installed (bgo#789192).
- Stop using git-checkout via source service, return to upstream
  released tarballs.
- Following the above, drop libtool BuildRequires and stop passing
  autogen.sh, no longer needed.
* Wed Feb 28 2018 fcrozat@suse.com
- Add mutter-force-rgb8.patch: force 8-bit RGB EGL config,
  to prevent slowness when using Wayland with 10-bit display
  (bsc#1081931 glgo#GNOME/mutter#2).
* Sun Feb 18 2018 bjorn.lie@gmail.com
- Update to version 3.26.2+20180207.4b2d21ff0:
  + renderer/x11: Enable GPU memory purge error extension if
    available (bgo#739178).
  + cogl/x11/renderer: Silence introspection warning (bgo#739178).
  + backends/x11: Preserve XI1 XDevice throughout
    ClutterInputDevice lifetime (glgo#mutter#7).
* Wed Jan 31 2018 bjorn.lie@gmail.com
- Update to version 3.26.2+20180127.d32d358a6:
  + monitor: Set MINIMUM_LOGICAL_HEIGHT to 480.
  + Don't attempt to get monitor geometry on non-existent monitors.
  + wayland:
  - Shortcuts inhibitor requires a window.
  - Ensure wl_shell_surfaces are set reactive.
  - Only send full sequences of touch events to clients.
  + input-settings/x11: Fix tap-and-drag libinput property name
  + clutter/evdev: Ignore unknown touch points
  + Revert "window: Raise and lower tile match in tandem"
  + Updated translations.
- Update _service url to new gitlab home.
* Thu Jan  4 2018 zaitor@opensuse.org
- Update to version 3.26.2+20171231.0bd1d7cf0:
  + Revert "window: Raise and lower tile match in tandem".
  + wayland: Only send full sequences of touch events to clients.
  + stage: Push framebuffer before setting up viewport.
  + keybindings: Only add multiple keycodes from the same level.
  + wayland-outputs: Delay wl_output destruction.
  + monitor-manager-kms:
  - Fix recently introduced build issue.
  - poll() on KMS fd on EAGAIN.
  + compositor: reset top_window_actor and remove it from windows
    when destroyed.
  + monitor-manager: Compare keys when checking whether a config is
    complete.
  + Updated translations.
- Switch to git-checkout via source services.
- Following the above, add intltool and libtool BuildRequires and
  pass autogen.sh to bootstrap the generated tarball.
- Pkgconfigy the BuildRequires, replace:
  gobject-introspection-devel, libSM-devel, libX11-devel and
  libXinerama-devel with pkgconfig(gobject-introspection-1.0),
  pkgconfig(sm), pkgconfig(x11) and pkgconfig(xinerama).
- Drop update-desktop-files BuildRequires and stop using
  suse_update_desktop_file macro, no longer needed.
- Drop pkgconfig(gbm) BuildRequires listed twice.
- Run spec-cleaner, modernize spec, use make_build macro.
* Sat Nov  4 2017 luc14n0@linuxmail.org
- Update to version 3.26.2:
  + Work with clients that require older linux_dmabuf protocol
    (bgo#788558).
  + Prevent crash when closing maximized windows (bgo#788666).
  + Use the correct monitor for HiDPI scaling of shell chrome
    (bgo#788820).
  + Enable XWayland core dumps (bgo#789086).
  + Fixes:
  - Unredirection of fullscreen windows (bgo#788493).
  - List of supported monitor scales on X11 (bgo#788901).
  - Handling of trackball settings on wayland (bgo#787804).
  - Miscellaneous:
    . Multi-monitor regressions and crashes (bgo#788607,
    bgo#788860, bgo#789153, bgo#786929, bgo#789501).
    . Bug fixes: bgo#788572, bgo#788569, bgo#784314, bgo#789227,
    bgo#789223, bgo#782344, bgo#789552, bgo#789553, bgo#789300.
  + Updated translations.
- Drop fixed upstream patches:
  mutter-wayland-dma-buf-modifiers-fix.patch,
  mutter-x11-Protect-XChangeProperty-call.patch,
  mutter-handle-no-to-no-monitor.patch and
  mutter-preferred-mode.patch.
- Drop %%glib2_gsettings_schema_requires macro: the functionality is
  covered by file triggers now.
- Point fdupes to the /usr directory instead of the build root,
  which is a practice that must be avoided.
* Thu Oct 19 2017 mgorse@suse.com
- Add mutter-handle-no-to-no-monitor.patch: fix possible crash when
  turning monitor off and on while logged in (bgo#788607).
- Add mutter-preferred-mode.patch: fix a crash on some ATI (radeon)
  configurations (bgo#789153).
* Tue Oct 10 2017 zaitor@opensuse.org
- Add mutter-wayland-dma-buf-modifiers-fix.patch: Don't send
  modifiers to old clients (bgo#788558).
- Add  mutter-x11-Protect-XChangeProperty-call.patch: Protect
  XChangeProperty call with error traps (bgo#788666).
* Wed Oct  4 2017 zaitor@opensuse.org
- Update to version 3.26.1:
  + Fix crash when respawning shortcut inhibitor dialog
    (bgo#787568).
  + Fix crash during monitor configuration migration (bgo#787668).
  + Fix multihead regressions in X11 session (bgo#787477).
  + Fix screen rotation regressions (bgo#787836).
  + Fix keybindings not being resolved with non-latin layouts
    (bgo#787016).
  + Support snap packages for sandboxed app IDs (bgo#788217).
  + Fix crash when reconnecting tablet device (bgo#787649).
  + Support running headless (bgo#730551, bgo#787637).
  + Support _NET_RESTACK_WINDOW and ConfigureRequest siblings
    (bgo#786365).
  + Fix monitor layout not being remembered across sessions
    (bgo#787629).
  + Make sure to export _NET_NUMBER_OF_DESKTOPS (bgo#760651).
  + Allow resizing of tiled windows (bgo#645153).
  + Export tiling information to clients (bgo#751857).
  + Misc. bug fixes: bgo#787570, bgo#787715, bgo#787953,
    bgo#788049, bgo#788199, bgo#788292, bgo#788197.
  + Updated translations.
- Drop upstream fixed patches:
  + mutter-wayland-fixes.patch.
  + mutter-monitor-refresh-rate.patch.
  + mutter-fix-kinetic-scrolling.patch.
  + mutter-monitor-config-manager-rotation-fix.patch.
  + mutter-fix-hidpi-scaling-x11.patch.
  + mutter-bsc1052058-NET_RESTACK_WINDOW-Respect-sibling.patch.
* Mon Oct  2 2017 vliaskovitis@suse.com
- Add mutter-bsc1052058-NET_RESTACK_WINDOW-Respect-sibling.patch:
  Implement _NET_RESTACK_WINDOW and respect sibling field of
  XConfigureRequestEvent. This way X11 window stack operations work
  as expected.
  (bsc#1052058, bgo#786363, bgo#786365)
* Mon Sep 25 2017 zaitor@opensuse.org
- Add mutter-fix-hidpi-scaling-x11.patch: Fix hidpi scaling
  regression when using X11 (bgo#788049).
* Mon Sep 25 2017 badshah400@gmail.com
- Add mutter-monitor-config-manager-rotation-fix.patch: Fix
  transformation when rotating screen so that rotation by 90/270
  deg don't show a black screen; patch taken from upstream git
  (bgo#787836).
* Fri Sep 15 2017 zaitor@opensuse.org
- Add mutter-wayland-fixes.patch: Three bugfix commits from
  upstream for wayland (bgo#787570, bgo#787568).
- Add mutter-monitor-refresh-rate.patch: Fix refresh rate for some
  users (bgo#787668).
- Add mutter-fix-kinetic-scrolling.patch: Fix kinetic scrolling.
* Thu Sep 14 2017 fezhang@suse.com
- Drop SLE12 / Leap42 conditionals and build with wayland
  unconditionally.
* Tue Sep 12 2017 zaitor@opensuse.org
- Add disabled pkgconfig(libpipewire-0.1) BuildRequires and
  - -enable-remote-desktop configure flag, enable support for
  remote desktop and screen cast when the dependency is available
  in openSUSE.
* Tue Sep 12 2017 luc14n0@linuxmail.org
- Update to version 3.26.0:
  + Updated translations.
- Changes from version 3.25.92:
  + Add screencast and remote desktop support (bgo#784199).
  + Support running with no attached monitors (bgo#730551).
  + Add a vertical gradient effect to background actor (bgo#786618).
  + Misc. bug fixes: bgo#786619, bgo#786677, bgo#772218, bgo#786918,
    bgo#760670.
  + Updated translations.
- Drop mutter-no-mandatory-eglGetPlatformDisplayEXT.patch and
  mutter-new-libgudev.patch, fixed upstream.
* Thu Sep  7 2017 zaitor@opensuse.org
- Add mutter-new-libgudev.patch: Fix build with new libgudev
  (bgo#760670).
* Thu Aug 24 2017 zaitor@opensuse.org
- Add mutter-no-mandatory-eglGetPlatformDisplayEXT.patch: egl:
  Don't require eglGetPlatformDisplayEXT. Trying to unilaterally
  require eglGetPlatformDisplayEXT causes problems in scenarios
  where this method is not available. Besides, this should only be
  required on Wayland, so we can stop requiring it always and
  simply let the eglGetPlatformDisplay() function error accordingly
  when needed (bgo#786619).
* Tue Aug 22 2017 zaitor@opensuse.org
- Update to version 3.25.91:
  + Reduce memory use of suspended instances (bgo#786299).
  + Make supported scales determination saner (bgo#786474).
  + Fix crash on inhibit-shortcuts dialog reponse (bgo#786385).
  + Support libinput's tag-and-drag setting (bgo#775755).
  + Avoid overlapping keybindings with multiple layouts
    (bgo#786408).
  + Fix non-transformed cursor on rotated monitors (bgo#786023).
  + Avoid unnecessary work during background painting (bgo#783512).
  + Misc. bug fixes: bgo#691611, bgo#786300, bgo#777732,
    bgo#786568.
  + Updated translations.
* Mon Aug 21 2017 dimstar@opensuse.org
- Update to version 3.25.90:
  + Add zwp_linux_dmabuf_v1 support (bgo#785262).
  + Add (x)wayland shortcut inhibitor support (bgo#783342).
  + Misc. bug fixes: bgo#785263, bgo#785347, bgo#767805.
  + Updated translations.
- Rename libmutter-0-0 subpackage to libmutter-1-0, following
  upstreams soname change.
* Tue Aug  8 2017 coolo@suse.com
- libinput is needed also without wayland, so buildrequire
  it unconditionally
* Thu Jul 20 2017 zaitor@opensuse.org
- Update to version 3.25.4:
  + Do not throttle motion events on tablet tools (bgo#783535).
  + Handle left-handed mode on pen/eraser devices (bgo#782027).
  + Add wl_surface.damage_buffer() support (bgo#784080).
  + Fix crash when moving across on-adjacent monitors (bgo#783630).
  + Fix window moving/resizing via tablet tools (bgo#777333).
  + Support fractional monitor scaling (bgo#765011).
  + Keep override-redirect windows stacked on top (bgo#780485).
  + Implement tablet rings/strips configuration (bgo#782033).
  + Support tablet wheel events on wayland (bgo#783716).
  + Move g-s-d xrandr functionality into mutter (bgo#781906).
  + Misc. bug fixes: bgo#783502, bgo#784009, bgo#784223,
    bgo#784272, bgo#784402, bgo#784881, bgo#762083, bgo#784867,
    bgo#781723.
- Drop desktop_database_post(un) and
  glib2_gsettings_schema_post(un) from post(un), no longer needed
  as we have file-triggers to take care of this for us now.
* Thu Jul 20 2017 dimstar@opensuse.org
- Update to version 3.25.3:
  + Ignore hotplug-mode-update value on startup (bgo#783073).
  + Implement configurable monitor scales on X11 (bgo#777732).
  + Fix handling of tiled monitors (bgo#781723).
  + Handle multiple keycodes for keysym (bgo#781223).
  + Consider subsurfaces when grabbing (bgo#781811).
  + Fix logic for HiPDPI scaling of TV outputs (bgo#777347).
  + Fix handling of left-handed mode on pen/eraser devices
    (bgo#782027).
  + Fix output cycling in non-display-attached tablets (bgo#782032).
  + Fix wacom cursor offset on wayland (bgo#784009).
  + Handle EXIF orientation of backgrounds (bgo#783125).
  + Misc. bug fixes: bgo#772218, bgo#783161, bgo#780407,
    bgo#783113, bgo#783293, bgo#783505, bgo#781703.
  + Updated translations.
* Thu Jul 20 2017 zaitor@opensuse.org
- Move SLE only patches to patch number 1000 and above.
- Rename mutter-bell.patch to mutter-SLE-bell.patch,
  mutter-bsc984738-grab-display.patch to
  mutter-SLE-bsc984738-grab-display.patch and
  relax-some-constraints-on-CSD-windows-in-sle-classic.patch to
  mutter-SLE-relax-some-constraints-on-CSD-windows.patch.
* Thu Jul 20 2017 zaitor@opensuse.org
- Update to version 3.25.2:
  + Fix frame updates on hide-titlebar-when-maximized changes
    (bgo#781862).
  + Fix accessible screen coordinates on X11 (bgo#781902).
  + Use less CPU when rendering fast-updating windows (bgo#782344).
  + Compute geometry of clients that don't set one explicitly
    (bgo#782213).
  + Fix copy+paste of UTF8 strings between X11 and wayland
    (bgo#782472).
  + Fix non-wayland builds (bgo#780533).
  + Add plugin vfunc to implement a custom force-quit dialog
    (bgo#711619).
  + Fix swapped red and blue channels in CoglTexture data
    (bgo#779234).
  + Fix build where libtool's link_all_deplibs defaults to 'no'
    (bgo#782821).
  + Fix glitches when opening a window maximized (bgo#781353,
    bgo#782183).
  + Fix wrong cursor after window underneath the pointer changed
    (bgo#755164).
  + Implement support for disable-while-typing option (bgo#764852).
  + Emit size-change signal when tiling (bgo#782968).
  + Misc. bug fixes: bgo#759085, bgo#780215, bgo#782156,
    bgo#782152.
  + Updated translations.
- Drop mutter-monitor-fixes.patch and mutter-wayland-fixes.patch:
  Fixed upstream.
* Thu Jul 20 2017 zaitor@opensuse.org
- Update to version 3.25.1:
  + Always sync window geometry on state changes (bgo#780292).
  + Use EGL instead of GLX when drawing using GLES (bgo#771636).
  + Scale relative motion deltas with monitor scale (bgo#778119).
  + Use texture fallback when setting hardware cursor fails
    (bgo#770020).
  + Fix lock-up when using additional theme variants (bgo#780254).
  + Rework low-level monitor configuration (bgo#777732).
  + Fix building with GLES2 instead of GL (bgo#781398).
  + Misc. bug fixes: bgo#780304, bgo#772218, bgo#781242,
    bgo#781391.
  + Updated translations.
* Thu Jul 20 2017 zaitor@opensuse.org
- Update to version 3.24.4:
  + Fix wacom cursor offset on wayland (bgo#784009).
  + Do not throttle motion events on tablet tools (bgo#783535).
  + Handle left-handed mode on pen/eraser devices (bgo#782027).
  + Fix crash when decreasing number of workspaces (bgo#784223,
    boo#1045440).
  + Fix crash when moving across on-adjacent monitors (bgo#783630).
  + Fix window moving/resizing via tablet tools (bgo#777333).
  + Improve stability of tablet plugs/unplugs (bgo#784881).
  + Implement tablet rings/strips configuration (bgo#782033).
  + Support tablet wheel events on wayland (bgo#783716).
  + Misc. bug fixes: bgo#784402, bgo#784867, bgo#781723.
  + Updated translations.
- Add pkgconfig(libudev) BuildRequires: New explicit dependency.
* Thu Jul  6 2017 vliaskovitis@suse.com
- Add RGB16_565 format to support 16-bit color depth sessions
  (FATE#323412, bgo#781704, bsc#1024748)
  mutter-iconcache-Support-RGB16_565-format-for-16-bit-color-.patch
* Fri Jun 23 2017 zaitor@opensuse.org
- Update to version 3.24.3:
  + Fix handling of tiled monitors (bgo#781723).
  + Fix swapped red and blue channels in CoglTexture data
    (bgo#779234).
  + Fix glitches when opening a window maximized (bgo#781353,
    bgo#782183).
  + Implement support for disable-while-typing option (bgo#764852).
  + Consider subsurfaces when grabbing (bgo#781811).
  + Fix handling of left-handed mode on pen/eraser devices
    (bgo#782027).
  + Fix output cycling in non-display-attached tablets
    (bgo#782032).
  + Fix wacom cursor offset on wayland (bgo#784009).
  + Handle EXIF orientation of backgrounds (bgo#783125).
  + Misc. bug fixes: bgo#782156, bgo#780407, bgo#757661,
    bgo#783113, bgo#781703.
- Drop mutter-monitor-fixes.patch and mutter-wayland-fixes.patch,
  fixed upstream.
* Thu May 18 2017 zaitor@opensuse.org
- Add upstream patches: mutter-monitor-fixes.patch: Various monitor
  fixes from upstream stable git.
  and mutter-wayland-fixes.patch: Various wayland fixes from
  upstream stable git.
* Thu May 18 2017 zaitor@opensuse.org
- Add pkgconfig(libwacom) BuildRequires: Build advanced tablet
  support.
* Thu May 11 2017 zaitor@opensuse.org
- Update to version 3.24.2:
  + Don't crash when wayland clients commit to destroyed surfaces
    (bgo#781391).
  + Fix frame updates on hide-titlebar-when-maximized changes
    (bgo#781862).
  + Fix accessible screen coordinates on X11 (bgo#781902).
  + Fix copy+paste of UTF8 strings between X11 and wayland
    (bgo#782472).
  + Fix non-wayland builds (bgo#780533).
  + Misc. bug fixes: bgo#781242, bgo#780215, bgo#759085.
  + Updated translations.
* Sat Apr 15 2017 zaitor@opensuse.org
- Update to version 3.24.1:
  + Always sync window geometry on state changes (bgo#780292).
  + Use EGL instead of GLX when drawing using GLES (bgo#771636).
  + Fix HiDPI detection on vertical monitor layouts (bgo#777687).
  + Get double-click timing from desktop mouse settings
    (bgo#771576).
  + Scale relative motion deltas with monitor scale (bgo#778119).
  + Use texture fallback when setting hardware cursor fails
    (bgo#770020).
  + Fix lock-up when using additional theme variants (bgo#780254).
  + Updated translations.
* Thu Mar 23 2017 zaitor@opensuse.org
- Add libmutter0 Obsoletes: Ease updates from older versions of
  openSUSE (boo#1030759).
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Updated translations.
* Tue Mar 14 2017 dimstar@opensuse.org
- Update to version 3.23.92:
  + Properly handle EGLOutput acquire errors (bgo#779112).
  + Fix crash when a window closes during Alt+Tab (bgo#779483).
  + Implement DnD handling code in wayland (bgo#765003).
  + Fix fallout from pixel conversion optimization in 3.23.91
    (bgo#779234).
  + Fix mouse input stopping to work in applications (bgo#763246).
  + Fix DnD between QT5 and GTK3 applications on wayland
    (bgo#779757).
  + Make EDID reading less fragile (bgo#779837).
  + Add support for tablet grouping (bgo#779986).
  + Misc. bug fixes and cleanups: bgo#779436, bgo#779001,
    bgo#779745.
  + Updated translations.
* Fri Mar  3 2017 zaitor@opensuse.org
- Pass --enable-egl-device to configure, build egl support, we
  already have the needed BuildRequires.
* Wed Mar  1 2017 zaitor@opensuse.org
- Update to version 3.23.91:
  + Give libinput read-only access to /sys (bgo#778472).
  + Allow edge-scrolling without 2-finger-scroll capable devices
    (bgo#778554).
  + Fullscreen windows on the requested monitor on wayland
    (bgo#772525).
  + Implement threaded swap_event fallback for NVIDIA driver
    (bgo#779039).
  + Avoid pixel conversions when storing textures from cairo
    (bgo#779234).
  + Misc. bug fixes: bgo#772218, bgo#776919, bgo#778831,
    bgo#642652.
  + Updated translations.
* Sat Feb 18 2017 luke.nukem.jones@gmail.com
- Update to version 3.23.90:
  + Fix window menu placement with HiDPI (bgo#776055).
  + Improve EGLStream support (bgo#773629).
  + Start moving low-level monitor configuration into mutter
    (bgo#777732).
  + Fix erroneous key event repeats (bgo#774989).
  + Don't hardcode seat ID in ClutterDeviceManager (bgo#778092).
  + Fix "ghost" cursors in multi-monitor setups (bgo#771056).
  + Use eglGetPlatformDisplay (bgo#772422).
  + Fix erratic raise_or_lower behavior (bgo#705200).
  + Fix coordinate mapping of absolute devices (bgo#774115).
  + Show OSD on tablet mode switches (bgo#771098).
  + Make mutter libs parallel installable (bgo#777317).
  + Only apply keymap when not running nested (bgo#777800).
  + Set right scale for tablet tool cursors on HiDPI (bgo#778474).
  + Adjust server-side shadows to match Adwaita (bgo#744667).
  + Misc. bug fixes bgo#774891, bgo#777389, bgo#777691,
    bgo#778262, bgo#776543, bgo#778684, bgo#778699,
    bgo#744667.
- Rename sub-package libmutter0 to libmutter-0-0 to reflect
  upstream library name change, making it paralell installable.
- Remove
  %%global __provides_exclude_from ^%%{_libdir}/mutter/.*.typelib$:
  No longer needed as mutter is now paralell installable following
  upstream changes.
- Add explicit pkgconfig(gbm) BuildRequires that configure checks
  for.
* Thu Feb 16 2017 dimstar@opensuse.org
- Update to version 3.23.3:
  + Fix frequent freezes in multihead setups on wayland
    (bgo#774557).
  + Preserve root window mask on XSelectionRequest (bgo#776128).
  + Misc. bug fixes: bgo#775478, bgo#774891, bgo#775986,
    bgo#776036.
* Thu Feb 16 2017 dimstar@opensuse.org
- Update to version 3.23.2:
  + Stack docks below other windows on fullscreen monitors
    (bgo#772937).
  + Fix popup grabs blocking screen lock on wayland (bgo#771235).
  + Handle touchpad pinch gestures with more than two fingers
    (bgo#765937).
  + Implement drawing tablet support on X11 (bgo#773779).
  + Fix some Wine games starting minimized (bgo#774333).
  + Fix switching between two finger- and edge scrolling on wayland
    (bgo#771744).
  + Implement support for EGLStream/EGLDevice (bgo#773629).
  + Add size_changed vfunc to handle async client size changes
    (bgo#770345).
  + Change focus window on clicks with any modifiers (bgo#746642).
  + Misc. bug fixes and cleanups: bgo#771067, bgo#774330,
    bgo#774613, bgo#771297, bgo#774135, bgo#774827, bgo#774923.
  + Updated translations.
- Add pkgconfig(egl), pkgconfig(glesv2) and pkgconfig(xtst)
  BuildRequires: new dependencies.
- Drop meta-input-settings-x11.c: fixed upstream.
- Rebase mutter-bell.patch and
  relax-some-constraints-on-CSD-windows-in-sle-classic.patch.
* Thu Feb 16 2017 dimstar@opensuse.org
- Update to version 3.23.1:
  + Fix handling of Escape shortcut in force-quit dialog
    (bgo#737109).
  + Improve pointer constraints support (bgo#771859).
  + Really fix framebuffer capture origin offset (bgo#771502).
  + Fix session going into idle mode immediately on startup
    (bgo#772839).
  + Fix mirror mode with stage views (bgo#773115).
  + Fall back to X with connectors spread across multiple GPUs
    (bgo#771442).
  + Fix various crashes on wayland (bgo#771646, bgo#771858,
    bgo#772929).
  + Fix various placement issues on wayland (bgo#772729,
    bgo#768039, bgo#771841, bgo#771841, bgo#773141).
  + Misc. bug fixes: bgo#771019, bgo#773116, bgo#772914,
    bgo#773210.
  + Updated translations.
- Drop upstream fixed patches:
  + mutter-screeenshot-coords.patch.
  + mutter-scale-positioner-coordinates.patch.
* Thu Feb 16 2017 zaitor@opensuse.org
- Update to version 3.22.3:
  + Fix switching between two finger- and edge scrolling on wayland
    (bgo#771744).
  + Fix frequent freezes in multihead setups on wayland
    (bgo#774557).
  + Preserve root window mask on XSelectionRequest (bgo#776128).
  + Fix window menu placement with HiDPI (bgo#776055).
  + Fix HiDPI detection on vertical monitor layouts (bgo#777687).
  + Fix erroneous key event repeats (bgo#774989).
  + Fix "ghost" cursors in multi-monitor setups (bgo#771056).
  + Use eglGetPlatformDisplay (bgo#772422).
  + Fix erratic raise_or_lower behavior (bgo#705200).
  + Extend tablet device checks (bgo#773779).
  + Set right scale for tablet tool cursors on HiDPI (bgo#778474).
  + Allow edge-scrolling without 2fg-scroll capable devices
    (bgo#778554).
  + Misc. bug fixes: bgo#771297, bgo#774135, bgo#775986,
    bgo#777691, bgo#777470, bgo#778262, bgo#776919.
  + Updated translations.
- Drop mutter-x11-meta.patch: Fixed upstream.
* Thu Dec  1 2016 dimstar@opensuse.org
- Add mutter-x11-meta.patch: Don't try setting unavailable scroll
  methods; libinput acts really bad on it (bgo#775337, bgo#771744,
  boo#1011356).
* Fri Nov 11 2016 dimstar@opensuse.org
- Update to version 3.22.2:
  + Really fix framebuffer capture origin offset (bgo#771502).
  + Fix session going into idle mode immediately on startup
    (bgo#772839).
  + Fix mirror mode with stage views (bgo#773115).
  + Improve pointer constraints support (bgo#771859).
  + Stack docks below other windows on fullscreen monitors
    (bgo#772937).
  + Fix switching between two finger- and edge scrolling on wayland
    (bgo#771744).
  + Fix popup grabs blocking screen lock on wayland (bgo#771235).
  + Fix various crashes on wayland (bgo#771646, bgo#771858).
  + Fix various placement issues on wayland (bgo#768039,
    bgo#771841, bgo#773141, bgo#772729).
  + Misc. bug fixes: bgo#771019, bgo#773116, bgo#772914,
    bgo#773210.
  + Updated translations.
- Drop upstream fixed patches:
  + mutter-screeenshot-coords.patch
  + mutter-scale-positioner-coordinates.patch
* Fri Nov  4 2016 jengelh@inai.de
- Update descriptions
* Tue Nov  1 2016 zaitor@opensuse.org
- Add mutter-fix-startup.patch: Fix slow startup notification for
  some gtk3 apps when running on wayland (bgo#768531).
* Tue Oct 11 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Fix feedback loop between StClipboard and X11 bridge
    (bgo#760745).
  + Fall back gracefully if DRM plane rotation fails (bgo#772512).
  + Approximate native monitor backend behavior to X (bgo#772176).
  + Fix crash on VT switch on wayland (bgo#771646).
  + Expose Flatpak ID for application matching (bgo#772613,
    bgo#772614).
- Drop mutter-fix-string-format.patch: Fixed upstream.
* Sat Sep 24 2016 zaitor@opensuse.org
- Add mutter-fix-string-format.patch: Fix string format build
  error. Patch from upstream git.
* Fri Sep 23 2016 zaitor@opensuse.org
- Add more fixes to mutter-scale-positioner-coordinates.patch:
  Still more fixes comming out of upstreams bug.
* Fri Sep 23 2016 zaitor@opensuse.org
- Add mutter-scale-positioner-coordinates.patch: wayland/xdg-shell:
  Scale positioner coordinates, fix shrinking menus when on HiDPI
  and wayland (bgo#771841).
* Wed Sep 21 2016 dimstar@opensuse.org
- Add mutter-screeenshot-coords.patch: yet another fix to take
  screenshots of a specific area.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Fix wayland crashes (bgo#771305, bgo#771345, bgo#770940,
    bgo#771495).
  + Fix display rotation on wayland (bgo#770672).
  + Fix framebuffer capture origin offset (bgo#771502).
  + Misc. bug fixes (bgo#770937, bgo#771536, bgo#771628,
    bgo#771549).
  + Updated translations.
- Only apply mutter-bsc984738-grab-display.patch for SLE until it
  can be verified that it's needed for 3.22.x too.
* Tue Sep 13 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Fix absolute pointer motion events on wayland (bgo#770557).
  + Default to using stage views (bgo#770366).
  + Fix animated cursors on wayland (bgo#749913).
  + Fix various crashes on wayland (bgo#757568, bgo#770727,
    bgo#770992).
  + Fix screen capture for stage views not at (0, 0) (bgo#770127).
  + Compress motion events instead of discarding them (bgo#771049).
  + Fix XWayland pointer warp emulation (bgo#771050).
  + Add common monitor modes in KMS backend (bgo#744544).
  + Temporarily use g-s-d schemas for tablet configuration
    (bgo#771315).
  + Misc. bug fixes: bgo#770402, bgo#770647, bgo#770991,
    bgo#770994, bgo#770929.
  + Updated translations.
* Tue Aug 30 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Add support for xdg-foreign protocol (bgo#769786).
  + Support monitor rotation on wayland (bgo#745079).
  + Port xdg-shell implementation to unstable v6 (bgo#769936).
  + Handle unsupported buffer sizes more gracefully (bgo#770387).
  + Use the same output naming logic as the X server on wayland
    (bgo#770338).
  + Fix replies in gnome-shell's chat notifications on wayland
    (bgo#758167).
  + Misc. bug fixes and cleanups: bgo#769276, bgo#769636,
    bgo#770131, bgo#770324, bgo#769731.
  + Updated translations.
* Fri Aug 19 2016 zaitor@opensuse.org
- Update to version 3.21.90:
  + Consider XDG_SESSION_TYPE when determining session type
    (bgo#759388).
  + Re-add support for edge scrolling on some touchpads
    (bgo#768245).
  + Support mouse and trackball acceleration profile (bgo#769179).
  + Draw monitor contentn to individual framebuffer (bgo#768976).
  + Support virtual input devices (bgo#765009).
  + Set correct output scale on hotplug (bgo#769505).
  + Bugs fixed: bgo#769014, bgo#769024, bgo#769054, bgo#769070,
    bgo#769036, bgo#769305, bgo#769578, bgo#769800, bgo#769073.
- Drop mutter-32bit-cogl-gles2-conflict-def.patch: Fixed upstream.
- Drop intltool BuildRequires following upstream changes.
* Thu Aug 18 2016 zaitor@opensuse.org
- Obsolete typelib-1_0-Meta-3_0 to ease updates.
* Wed Aug 17 2016 dimstar@opensuse.org
- Filter out private typelib provides. Providing those only breaks
  other applications, as they won't be able to find our typelibs.
* Sun Aug  7 2016 zaitor@opensuse.org
- Drop typelib-1_0-Meta-3_0 subpackage, and package typelib in main
  package with the other private libs. Following this, drop
  typelib-1_0-Meta-3_0 Requires from devel package.
* Sat Jul 30 2016 badshah400@gmail.com
- Update to version 3.21.4:
  + Fix missing frame border around GTK+ dialogs (bgo#745060).
  + Improve X11 <-> wayland copy and paste interaction (bgo#768007).
  + Add support for NV_robustness_video_memory_purge extension
    (bgo#739178).
  + Fix restoring the old focused window on restart (bgo#766243).
  + Fix fullscreen windows on other monitors stealing focus after
    closing a window (bgo#768221).
  + Draw monitor content to individual framebuffer (bgo#768976).
  + Provide screen capture API (bgo#768978).
  + Bugs fixed: bgo#767969, bgo#768243, bgo#762407, bgo#767997,
    bgo#768039, bgo#768977, bgo#768977.
  + Updated translations.
- Fix build on i586 with patch
  mutter-32bit-cogl-gles2-conflict-def.patch taken from upstream
  git (bgo#769014).
* Sat Jul 30 2016 zaitor@opensuse.org
- Update to version 3.21.3:
  + Don't create invalid UTF-8 window description strings
    (bgo#765535).
  + Convert window titles and wm_class to UTF-8 (bgo#752788).
  + Communicate tiled state to GTK+ on wayland (bgo#766860).
  + Use kill() to force-quit unresponsive wayland clients
    (bgo#767464).
  + Fix window position when unmaximizing via DND on wayland
    (bgo#764180).
  + Avoid full window redraws when using extended frame sync
    (bgo#767798).
* Sat Jul 30 2016 zaitor@opensuse.org
- Update to version 3.21.2:
  + Clean up surface <-> shell interaction (bgo#763431).
  + Fix grabbing random keys for disabled shortcuts (bgo#766270).
  + Fix stacking of hidden windows on wayland (bgo#764844).
  + Misc. bug fixes: bgo#766306, bgo#766326, bgo#751847,
    bgo#763832, bgo#766528.
  + Updated translations.
* Sat Jul 30 2016 zaitor@opensuse.org
- Update to version 3.21.1:
  + Notify clients of pending modifier state changes (bgo#748526).
  + Add get_is_builtin_display_on() method (bgo#765267).
  + Fix 2-finger titlebar taps on wayland (bgo#764519).
  + Merge clutter and cogl forks into mutter (bgo#760439).
  + Misc. bug fixes: bgo#765058, bgo#765252, bgo#765062.
  + Updated translations.
- Drop pkgconfig(clutter-1.0), pkgconfig(cogl-1.0),
  pkgconfig(clutter-egl-1.0), pkgconfig(clutter-wayland-1.0),
  pkgconfig(clutter-wayland-compositor-1.0) BuildRequires:
  Following upstream merging of clutter and cogl into mutter.
- Add pkgconfig(json-glib-1.0) BuildRequires: New dependency.
- Drop an obsolete clean section.
- Remove mutter-tools Obsoletes: We dropped the package in version
  3.9.90, no support for updates from openSUSE versions that old.
* Sat Jul 30 2016 hpj@suse.com
- Add mutter-bsc984738-grab-display.patch (bsc#984738, bgo#769387).
* Wed Jun 29 2016 zaitor@opensuse.org
- Update to version 3.20.3:
  + Fix grabbing random keys for disabled shortcuts (bgo#766270).
  + Crash fixes (bgo#751847, bgo#767969).
  + Improve multi-monitor handling on wayland (bgo#766528).
  + Don't create invalid UTF-8 window description strings
    (bgo#765535).
  + Convert window titles and wm_class to UTF-8 (bgo#752788).
  + Use kill() to force-quit unresponsive wayland clients
    (bgo#767464).
  + Fix window position when unmaximizing via DND on wayland
    (bgo#764180).
  + Avoid full window redraws when using extended frame sync
    (bgo#767798).
  + Fix missing frame border around GTK+ dialogs (bgo#745060).
  + Improve X11 <-> wayland copy and paste interaction
    (bgo#768007).
  + Updated translations.
* Wed May 11 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Notify clients of pending modifier state changes (bgo#748526).
  + Add get_is_builtin_display_on() method (bgo#765267).
  + Fix 2-finger titlebar taps on wayland (bgo#764519).
  + Misc. bug fixes: bgo#765058, bgo#765252, bgo#765062.
  + Updated translations.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
* Mon May  2 2016 fcrozat@suse.com
- Drop mutter-grab-display.patch, it has been fixed by upstream
  differently.
* Wed Apr 13 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Constrain window move/resizes on wayland as on X11
    (bgo#748819).
  + Don't crash with invalid previous monitor configurations
    (bgo#764286).
  + Misc. bug fixes and cleanups: bgo#762828, bgo#764807.
  + Updated translations.
* Wed Apr 13 2016 idonmez@suse.com
- Update to GNOME 3.20  Fate#318572
- Remove upstream patches: mutter-bnc879109-no-monitors-crash.patch
- Refresh mutter-grab-display.patch, mutter-bell.patch,
  relax-some-constraints-on-CSD-windows-in-sle-classic.patch
* Wed Mar 23 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Fix crash when using visual bell (bgo#763858).
  + Updated translations.
* Thu Mar 17 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Add system bell support on wayland (bgo#763284).
  + Add gtk_surface.present to gtk-shell (bgo#763295).
  + Handle DND drops on the root window (bgo#762104).
  + Misc. bug fixes: bgo#762828, bgo#760745, bgo#763125,
    bgo#762763, bgo#762661, bgo#762639, bgo#763159.
  + Updated translations.
* Fri Mar  4 2016 fcrozat@suse.com
- BuildRequires pkgconfig(libdrm), pkgconfig(libinput),
  pkgconfig(libsystemd) are only needed when building native
  backend, which is useful only under wayland and when running as
  display server. Ensure they aren't pulled as BuildRequires when
  wayland support is disabled. Add --enable-native-backend when
  building wayland support.
* Thu Mar  3 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + Add --nested CLI argument to fix nested wayland session
    (bgo#758658).
  + Fix stack - scene graph stacking synchronization issues
    (bgo#755605).
  + Rate-limit last-device changes to fix freezes (bgo#753527).
  + Implement primary selection protocol (bgo#762560).
  + Misc. bug fixes: bgo#762878, bgo#762716.
  + Updated translations.
* Fri Feb 19 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + Release buffer after processing commit (bgo#761312,
    bgo#761613).
  + Implement pointer motion, locks and confinement on wayland
    (bgo#744104).
  + Add basic startup notification support on wayland (bgo#762268).
  + Misc. bug fixes: bgo#760670, bgo#761543, bgo#752794,
    bgo#761557.
* Fri Jan 22 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Fix updating stacking order when setting transient_for
    (bgo#755606).
  + Support screen rotation when supported by the driver
    (bgo#745079).
  + Protect against broken WM_CLASS property implementations
    (bgo#759658).
  + Handle wl_pointer v5 events on wayland (bgo#760637).
  + Implement DND actions on wayland (bgo#760805).
  + Misc. bug fixes: bgo#754711, bgo#756789, bgo#759297,
    bgo#758613, bgo#760330, bgo#760476, bgo#759222, bgo#760670.
  + Updated translations.
* Thu Dec 17 2015 dimstar@opensuse.org
- Update to version 3.19.3:
  + Correct refresh rate units on KMS/Wayland (bgo#758653).
  + Fix crash when initial cursor position is not on a monitor
    (bgo#756698).
  + Fix crash when more CRTs are enabled than outputs connected
    (bgo#751638).
  + Fix touch pointer emulation on wayland (bgo#756754).
  + Allow minimizing windows that don't advertise supporting it
    (bgo#758186).
  + Force 2-finger scroll by default if available (bgo#759304).
  + Fix crash during XWayland initialization (bgo#751845).
  + Ensure to send a ConfigureNotify to just mapped windows
    (bgo#759492).
  + Misc. bug fixes and cleanups: bgo#758239, bgo#758633,
    bgo#755503, bgo#759374.
  + Updated translations.
- Add pkgconfig(wayland-protocols) BuildRequires: new dependency.
* Wed Nov 25 2015 zaitor@opensuse.org
- Update to version 3.19.2:
  + Fix crash on monitor unplug (bgo#756796).
  + Exit cleanly on initialization errors (bgo#757311).
  + Allow to determine backend setting from session type
    (bgo#741666).
  + Fix DRM device detection for non-PCI devices (bgo#754911).
  + Don't force placement of windows without buffer on wayland
    (bgo#751887).
  + Fix initialization of bypass compositor hint (bgo#758544).
* Tue Nov 24 2015 zaitor@opensuse.org
- Update to version 3.19.1:
  + wayland: Allow to trigger popups through keyboard/touch
    (bgo#756296).
  + Fix modifiers-only input source switching on Ubuntu
    (bgo#756543).
  + Misc. bug fixes: bgo#756675, bgo#756660, bgo#746420,
    bgo#756548, bgo#756796, bgo#757101, bgo#757148.
  + Updated translations.
* Thu Nov 12 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Misc. crash fixes (bgo#756675, bgo#756660, bgo#757148,
    bgo#756796).
  + Fix modifiers-only input source switching on Ubuntu.
  + Exit cleanly on initialization errors (bgo#757311).
  + Updated translations.
* Thu Oct 15 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Improve HiDPI support on wayland (bgo#755097).
  + Fix doubly-scaled cursor on XWayland HiDPI (bgo#755099).
  + Stop hiding titlebar buttons in dialogs (bgo#641630).
  + Add support for fullscreen/unfullscreen animations
    (bgo#707248).
  + Misc. crash fixes: bgo#755096, bgo#754979, bgo#755490,
    bgo#754357, bgo#745785, bgo#756642.
  + Misc. bug fixes: bgo#743339, bgo#752047, bgo#756074,
    bgo#756649.
- Drop wayland-Dont-pre-multiply-root-cursor-sizes.patch and
  wayland-Dont-scale-XWayland-pointer-cursor-sprites.patch: Fixed
  upstream.
* Fri Oct  2 2015 zaitor@opensuse.org
- Add wayland-Dont-pre-multiply-root-cursor-sizes.patch and
  wayland-Dont-scale-XWayland-pointer-cursor-sprites.patch: taken
  from upstream git. Fixes for HiDPI under wayland (bgo#755099).
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Misc. fixes: bgo#753434.
  + Updated translations.
- Drop Revert-launcher-simplify-getting-session-dbus-proxy.patch:
  fixed upstream.
* Sat Sep 19 2015 zaitor@opensuse.org
- Add Revert-launcher-simplify-getting-session-dbus-proxy.patch:
  fix VT switching with wayland, patch from upstream git.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Don't omit the background color for backgrounds that don't fill
    the screen (bgo#754476).
  + Fix up key state on FocusIn when running nested (bgo#753948).
  + Find the right DRM device instead of hardcoding card0
    (bgo#753434).
  + Scale cursor on HiDPI screens (bgo#744932).
  + Misc. fixes and cleanups (bgo#754545, bgo#754215, bgo#754621,
    bgo#754715).
  + Updated translations.
* Thu Sep  3 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Send error on pointer-gesture protocol version mismatch
    (bgo#753855).
  + Misc. cleanups (bgo#744932).
  + Updated translations.
* Thu Aug 20 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Fix glitch with some fullscreen apps (bgo#753020).
  + Fix screen update issue with NVidia driver (bgo#728464).
  + Only call frame callbacks for surfaces that get drawn
    (bgo#739163).
  + Misc. bug fixes and cleanups: bgo#753222, bgo#752753,
    bgo#753237, bgo#753380, bgo#744104, bgo#744932.
  + Updated translations.
- Drop upstream fixed patches:
  + build_fix_return_value_in_meta-sync-ring.c.patch
  + compositor_add_support_for_GL_EXT_x11_sync_object.patch
  + compositor_fix_GL_EXT_x11_sync_object_race_condition.patch
  + compositor_handle_fences_in_the_frontend_X_connection.patch
* Thu Aug 13 2015 idonmez@suse.com
- Fix screen flickering on nvidia devices (bgo#728464).
  + Add the following commits from the 3.16 branch:
  - build_fix_return_value_in_meta-sync-ring.c.patch
  - compositor_add_support_for_GL_EXT_x11_sync_object.patch
  - compositor_fix_GL_EXT_x11_sync_object_race_condition.patch
  - compositor_handle_fences_in_the_frontend_X_connection.patch
- Added autoconf and automake BuildRequires and run autoreconf for
  the patches above.
* Thu Jul 23 2015 zaitor@opensuse.org
- Update to version 3.17.4:
  + nested: Allow basic configuration of dummy outputs
    (bgo#747089).
  + Send wl_surface.enter and wl_surface.leave on output changes
    (bgo#744453).
  + Improve HiDPI handling on wayland (bgo#745655, bgo#744934).
  + Implement compositor-side animated cursors (bgo#752342).
  + Bugs fixed: bgo#750816, bgo#751884, bgo#752248, bgo#752551,
    bgo#752552, bgo#752673, bgo#752674.
- Drop mutter-devel-doc sub-package, removed upstream.
* Mon Jul  6 2015 zaitor@opensuse.org
- Update to version 3.17.3:
  + Add X11/wayland clipboard interaction (bgo#738312).
  + Support VM monitor layout hints on wayland (bgo#750363).
  + Bugs fixed: bgo#749994, bgo#750256, bgo#749716, bgo#748705,
    bgo#750552, bgo#751036, bgo#750007, bgo#751136, bgo#750552,
    bgo#751471, bgo#751715, bgo#750680.
  + Updated translations.
  + Add pkgconfig(xrandr) BuildRequires: New optional dependency.
* Thu Jul  2 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Honor default value for click method setting (bgo#746290).
  + Add X11/wayland clipboard interoperation (bgo#738312).
  + Misc. bug fixes: bgo#749076, bgo#749711.
* Thu Jul  2 2015 zaitor@opensuse.org
- Update to version 3.17.1:
  + Add public method to get neighboring monitor (bgo#633994).
  + Apply the right settings to the right input devices
    (bgo#747886).
  + Fix scroll button setting (bgo#747967).
  + Add support for modal hint on wayland (bgo#745720).
  + Don't reset idle time for non-hardware events (bgo#748541).
  + Misc. bug fixes (bgo#748478).
* Thu Jul  2 2015 zaitor@opensuse.org
- Update to version 3.16.3:
  + Fix kill dialog not showing when first PING fails (bgo#749076).
  + wayland: Reset idle time appropriately (bgo#749711,
    bgo#749994).
  + Fix crash when trying to focus a hidden window (bgo#751715).
  + Updated translations.
* Thu May 14 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Fix scroll button setting (bgo#747967).
  + Don't reset idle time for non-hardware events (bgo#748541).
  + Honor default value for click method setting (bgo#746290).
  + Misc. bug fixes (bgo#748478).
* Wed Apr 15 2015 zaitor@opensuse.org
- Update to version 3.16.1.1:
  + Prevent a crash when switching VTs or adding input devices
    (bgo#747886).
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Add function to refresh all background instances (bgo#739178).
  + Fix swapped scroll methods on wayland (bgo#746870).
  + Manually activate stage to fix accessibility on wayland
    (bgo#746670).
  + Center pointer on primary monitor on startup (bgo#746896).
  + wayland: Reword synchronized state application semantics
    (bgo#743617).
  + Ensure input settings are applied on startup (bgo#747434).
  + Misc. bug fixes: bgo#744932, bgo#746509, bgo#746692,
    bgo#746510, bo#746545, bgo#747263.
  + Updated translations.
- Add pkgconfig(xrender) BuildRequires: new verified dependency.
- Drop mutter-nvidia-repaint-on-resume.patch: fixed upstream.
* Thu Mar 26 2015 dimstar@opensuse.org
- Change from simple %%defines to %%bcond_with/without, as this
  allows to be set in prjconf without the need to patch the .spec
  files.
  + build_wayland has been replaced with the equivalent
    %%bcond_with, resp. %%bcond_without, based on the value that was
    originally set, resulting in no change for the build.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + wayland: Don't skip notifying about initial maximized state
    (bgo#745303).
  + Updated translations.
- Add mutter-nvidia-repaint-on-resume.patch: Add a function to
  refresh all background instances (boo#914149, bgo#739178).
* Wed Mar 18 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Ensure pointer visibility on monitor changes (bgo#745121,
    bgo#745752).
  + Fix geometry of shaded windows (bgo#746145).
  + Take over cursor visibility handling from gsd (bgo#712775).
  + Fix touch interaction on window decorations (bgo#745335).
  + Add options for libinput_config_click_method (bgo#746290).
  + Scale window decorations on HiDPI displays (bgo#744354).
  + Misc. bug fixes: bgo#745163, bgo#746295, bgo#746098,
    bgo#745734.
  + Updated translations.
* Thu Mar  5 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + wayland: Fix nested compositor mode (bgo#745401).
  + wayland: Fix pointer constraining (bgo#727337).
  + wayland: Fix input region on HiDPI (bgo#744933).
  + Allow themes to style buttons differently based on function
    (bgo#745108).
  + Misc. bug fixes and cleanups: bgo#745141, bgo#745118,
    bgo#745476, bgo#745442.
  + Updated translations.
* Fri Feb 20 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Initialize MetaOutput even when we can't get the EDID
    (bgo#743412).
  + Expose MetaMonitorManager to introspection (bgo#743745).
  + Fix flash on unredirection (bgo#743858).
  + Update xdg-shell implementation to v5 (bgo#744452).
  + Do not try to use seat devices that aren't (yet) present
    (bgo#744640).
  + Add keybindings for switching to VT8-VT12 (bgo#744800).
  + Misc bug fixes: bgo#743678, bgo#744500.
* Fri Feb 20 2015 dimstar@opensuse.org
- Add pkgconfig(gudev-1.0) and pkgconfig(gbm) BuildRequires in case
  we're building with wayland support: Needed for the native (non
  nested support).
* Fri Jan 23 2015 zaitor@opensuse.org
- Update to version 3.15.4:
  + Use GTK+ theme for window decorations instead of metacity
    (bgo#741917).
  + Export the same EDID information on X11 and wayland
    (bgo#742882).
  + Apply input device configuration on wayland (bgo#739397).
  + Implement pointer barriers on wayland (bgo#706655).
  + Bugs fixed: bgo#741829, bgo#738630, bgo#737463, bgo#698995,
    bgo#727893, bgo#742825, bgo#742824, bgo#742841, bgo#743173,
    bgo#743189, bgo#743217, bgo#743254.
  + Updated translations.
* Fri Dec 19 2014 zaitor@opensuse.org
- Update to version 3.15.3:
  + Don't leave left-over frames queued (bgo#738686).
  + Set CRTC configuration even if it might be redundant
    (bgo#740838).
  + Updated translations.
* Fri Dec 19 2014 zaitor@opensuse.org
- Update to version 3.15.2:
  + Don't enable hiDPI on monitors with broken EDID (bgo##734839).
  + Prevent crash applying monitor config for a closed lid
    (bgo#739450).
  + Fix "flicker" during startup transition (bgo#740377).
  + Bugs fixed: bgo#731521, bgo#740133, bgo#738890.
* Fri Dec 19 2014 zaitor@opensuse.org
- Update to version 3.15.1:
  + Use GResources for theme loading (bgo#736936).
  + Fix headerbar drag getting stuck on xwayland (bgo#738411).
- Drop following patches: mutter-black-screen-during-login.patch,
  mutter-window-actor-unredirection-when-destroyed.patch,
  mutter-empty-input-shapes-windows.patch,
  mutter-left-over-queued-frames.patch,
  mutter-dont-overwrite-send_frame_messages_timer.patch, all fixed
  upstream.
* Fri Dec 19 2014 zaitor@opensuse.org
- Update to version 3.14.3:
  + Fix crash when trying to unredirect a destroyed window
    (bgo#740133).
  + Fix "flicker" during startup transition (bgo#740377).
  + Don't leave left-over frames queued (bgo#738686).
  + Set CRTC configuration even if it might be redundant
    (bgo#740838).
- Drop upstreamed patches:
  + mutter-black-screen-during-login.patch.
  + mutter-window-actor-unredirection-when-destroyed.patch.
  + mutter-empty-input-shapes-windows.patch.
  + mutter-left-over-queued-frames.patch.
  + mutter-dont-overwrite-send_frame_messages_timer.patch.
* Fri Dec 12 2014 fcrozat@suse.com
- Disable wayland on SLE12.
- Remove BuildRequires pkgconfig(gbm), not needed unless building
  native backend.
* Wed Dec  3 2014 badshah400@gmail.com
- Add post-release fixes from upstream:
  + mutter-black-screen-during-login.patch: Disable ugly black
    screen during login (bgo#740377).
  + mutter-window-actor-unredirection-when-destroyed.patch:
    window-actor: Do not request unredirection when destroyed
    (bgo#740133).
  + mutter-empty-input-shapes-windows.patch: window-x11: Fix
    windows that set empty input shapes.
  + mutter-left-over-queued-frames.patch: Fix problems resulting
    in left-over queued frames (bgo#738686).
  + mutter-dont-overwrite-send_frame_messages_timer.patch:
    MetaWindowActor: don't overwrite send_frame_messages_timer
    (bgo#738686).
* Wed Nov 12 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Prevent crash applying monitor config for a closed lid
    (bgo#739450).
  + Misc. fixes.
* Tue Nov 11 2014 zaitor@opensuse.org
- Update to version 3.14.1.5:
  + Fix wayland hiDPI regression (bgo#739161).
  + Updated translations.
* Wed Oct 15 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + Fix move-titlebar-onscreen function (bgo#736915).
  + Fix stacking of the guard window (bgo#737233).
  + Fix keycode lookup for non-default layouts (bgo#737134).
  + Fix workspaces-only-on-primary handling (bgo#737178).
  + Don't unstick sticky windows on workspace removal (bgo#737625).
  + Do not auto-minimize fullscreen windows (bgo#705177).
  + Upload keymap to newly added keyboard devices (bgo#737673).
  + Apply keyboard repeat settings (bgo#728055).
  + Don't send pressed keys on enter (bgo#727178).
  + Fix build without wayland/native (bgo#738225).
  + Send modifiers after the key event (bgo#738238).
  + Fix unredirect heuristic (bgo#738271).
  + Do not show system chrome over fullscreen windows (bgo#693991).
  + Misc. bug fixes: bgo#737135, bgo#737581, bgo#738146,
    bgo#738384.
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Fix placement of popup windows on wayland (bgo#736812).
  + Only increment serial once per event (bgo#736840).
  + Fix window positioning regression with non-GTK+ toolkits
    (bgo#736719).
  + Updated translations.
* Wed Sep 17 2014 dimstar@opensuse.org
- Update to version 3.13.92:
  + Rewrite background code (bgo#735637, bgo#736568).
  + Fix size in nested mode (bgo#736279).
  + Fix destroy animation of background windows (bgo#735927).
  + Wire keymap changes up to the wayland frontend (bgo#736433).
  + Add a test framework and stacking tests [Owen; #736505]
  + Simplify handling of the merged X and wayland stack
    (bgo#736559).
  + Fix cursor size on HiDPI (bgo#729337).
  + Misc. bug fixes: bgo#735632, bgo#736589, bgo#736694.
* Mon Sep  8 2014 dimstar@opensuse.org
- Update to version 3.13.91:
  + Misc. bug fixes: bg0#735452.
  + Updated translations.
- Add pkgconfig(gbm) and pkgconfig(x11-xcb) BuildRequires: new
  explicit dependencies.
* Wed Aug 20 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Only call XSync() once per frame (bgo#728464).
  + Update capabilities on device list changes (bgo#733563).
  + Make use of GLSL optional (bgo#733623).
  + Handle gestures and touch events on wayland (bgo#733631).
  + Add support for unminimize compositor effects (bgo#733789).
  + Always set the frame background to None (bgo#734054).
  + Add backend methods to handle keymaps (bgo#734301).
  + Actually mark revalidated MetaTextureTower levels as valid
    (bgo#734400).
  + Rely on explicit -backward switcher keybindings instead of
    <shift>-magic (bgo#732295, bgo#732385).
  + Misc. bug fixes and cleanups: bgo#727178, bgo#734852,
    bgo#734960.
  + Updated translations.
- Add pkgconfig(xkbfile), pkgconfig(xkeyboard-config),
  pkgconfig(xkbcommon), pkgconfig(xkbcommon-x11) and
  pkgconfig(xcb-randr) BuildRequires: new dependencies.
* Thu Aug 14 2014 idonmez@suse.com
- Update mutter-bell.patch so it works on all cases (bnc#889218)
* Wed Jul 23 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Fix move/resize operations for wayland clients (bgo#731237).
  + Add ::first-frame signal to MetaWindowActor (bgo#732343).
  + Handle keysyms without the XF86 prefix (bgo#727993).
  + Add touch gesture support.
  + Fix a deadlock when exiting (bgo#733068).
  + Add framework for restarting the compositor with nice visuals
    (bgo#733026).
  + Toggle seat capabilities on VT switch (bgo#733563).
  + Misc bug fixes: bgo#732695, bgo#732350.
  + Updated translations.
- Replace pkgconfig(gio-2.0) BuildRequires with
  pkgconfig(gio-unix-2.0), following upstreams change in configure.
- Add pkgconfig(libinput) BuildRequires: new dependency.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + Improve behavior of window buttons with compositor menus
    (bgo#731058).
  + Implement touch support on wayland (bgo#724442).
  + Update window shadows (bgo#731866).
  + Keep windows on the preferred output (bgo#731760]).
  + Misc bug fixes: bgo#729601, bgo#730681, bgo#731353, bgo#731332,
    bgo#730527, bgo#662962.
- Changes from version 3.13.2:
  + Add basic HiDPI support on wayland (bgo#728902).
  + Replace mutter-launch with logind integration (bgo#724604]).
  + Move window menu into the compositor (bgo#726352).
  + Fix delayed focus-follows-mouse support (bgo#730541).
  + Support fallback app menu in window decorations (bgo#730752).
  + Misc. bug fixes and cleanups: bgo#729732, bgo#729602,
    bgo#726714.
  + Updated translations.
- Changes from version 3.13.1:
  + Merge wayland branch.
  + Don't prevent workspace switches for present_with_time()
    (bgo#728018).
  + Add shortcuts for switching to the last workspace (bgo#659288).
  + Make move/resize menu items behave like the keybindings
    (bgo#728617).
  + Misc. bug fixes and cleanups: bgo#720631, bgo#727979,
    bgo#728423, bgo#728395, bgo#729044.
  + Updated translations.
- Replace pkgconfig(xrender) BuildRequires with pkgconfig(xext),
  following upstream changes.
- Add BuildRequires for the newly merged Wayland support:
  + pkgconfig(clutter-egl-1.0), pkgconfig(clutter-wayland-1.0),
    pkgconfig(clutter-wayland-compositor-1.0) and
    pkgconfig(wayland-server).
- Add BuildRequires for session startup support using systemd:
  + pkgconfig(libdrm) and pkgconfig(libsystemd).
* Wed Jul  9 2014 cxiong@suse.com
- Add relax-some-constraints-on-CSD-windows-in-sle-classic.patch:
  CSD (Client Side Decoration) windows have invisible box wrapping
  around them, which leads to some positioning issues as in this
  bug report. Relax some constraints on window positioning for CSD
  windows s.t. they can be placed at the very top of the monitor.
  This fix works nicely for "sle-classic" as there is no top bar
  any more, and is NOT applied in other GNOME sessions for reasons
  stated in bgo#719772 (bnc#883491).
* Sat May 31 2014 federico@suse.com
- Add mutter-bnc879109-no-monitors-crash.patch:
  Fixes a crash in Mutter when there are no usable monitors, such
  as when a laptop is booted with the lid closed while on a docking
  station, with the intent of plugging an external monitor later
  (bnc#879109).
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Fix in-fullscreen state when moving between monitors
    (bgo#728395).
  + Fix crash when monitors change during suspend (bgo#725637).
  + Misc. bugs fixed: bgo#728423, bgo#729732.
  + Updated translations.
* Wed May  7 2014 sbrabec@suse.cz
- Added support for gnome-patch-translation (2 strings).
* Sun Apr 27 2014 dliang@suse.com
- Update mutter-grab-display.patch to fix (bnc#873763)
  remove the duplicated trap-pop.
* Wed Apr 16 2014 dimstar@opensuse.org
- Update to version 3.12.1:
  + Fix opacity values from _NET_WM_WINDOW_OPACITY (bgo#727874).
  + Misc. cleanups (bgo#720631).
  + Updated translations.
* Sat Apr  5 2014 dimstar@opensuse.org
- Move %%{_datadir}/gtk-doc/html/meta/ to a separate devel-doc
  package (in order to not conflict between mutter and
  mutter-wayland).
* Fri Mar 28 2014 dliang@suse.com
- Add mutter-grab-display.patch (bnc#870285)
  The oracle installer cannot display correctly.
  The bug was introduced in 3.10.4 and is now fixed in upstream.
* Wed Mar 26 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Thu Mar 20 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Fix identification of CSD windows (bgo#723029).
  + Add minimal handling of touch events (bgo#723552).
  + Misc bug fixes and cleanups: bgo#723580, bgo#726352.
  + Updated translations.
* Thu Mar  6 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Don't use keysym to match keybindings (bgo#678001).
  + Fix message tray icons showing up blank (bgo#725180).
  + Improve keybinding lookups (bgo#725588).
  + Fix dynamic updates of titlebar style properties (bgo#725751).
  + Fix positioning of manually positioned windows (bgo#724049).
  + Misc. bug fixes: bgo#724969, bgo#724402, bgo#722266,
    bgo#725338.
  + Updated translations.
* Thu Feb 20 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Use correct output property for backlight control (bgo#723606).
  + Fix double-scaling on high DPI resolutions (bgo#723931).
  + Make tile previews a compositor effect (bgo#665758).
  + Bugs fixed: bgo#722530, bgo#724257, bgo#724258, bgo#724364,
    bgo#720631, bgo#707851, bgo#707897.
  + Updated translations.
* Thu Feb 20 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + Fix CSD titlebars being placed off-screen (bgo#719772).
  + Expose MetaWindow:skip-taskbar property (bgo#723307).
  + Fix legacy tray icons showing up blank (bgo#721596).
  + Fix configuration of cloned monitors (bgo#710610).
  + Misc bug fixes and cleanups (bgo#720631, bgo#723468,
    bgo#723563).
  + Updated translations.
* Thu Feb 20 2014 zaitor@opensuse.org
- Update to version 3.11.4:
  + Don't leave focus on windows that are being unmanaged
    (bgo#711618).
  + Reduce server grabs (bgo#721345, bgo#721709).
  + Improve heuristic to determine display output name
    (bgo#721674).
  + Atomically unmaximize both directions (bgo#722108).
  + Misc bug fixes (bgo#721517, bgo#721674).
* Thu Feb 20 2014 dimstar@opensuse.org
- Update to version 3.11.3:
  + xrandr: Use "hotplug_mode_update" property (bgo#707194).
  + Fix position of attached dialogs for CSD windows (bgo#707194).
  + Fix focus issues with external OSKs (bgo#715030).
  + Add a MetaCullable interface (bgo#714706).
  + Fix window group paint volume (bgo#719669).
  + Fix frame extents problems (bgo#714707).
  + Add shortcut to move windows between monitors (bgo#671054).
  + Fix problems with focus tracking (bgo#720558).
  + Misc. bug fixes and cleanups: bgo#712833, bgo#678989,
    bgo#720106, bgo#720417, bgo#720630.
  + Updated translations.
* Thu Feb 20 2014 dimstar@opensuse.org
- Update to version 3.11.2:
  + Fix resize operations using mouse-button-modifier (bgo#710251).
  + Misc. fixes and cleanups (bgo#711731).
* Thu Feb 20 2014 dimstar@opensuse.org
- Update to version 3.11.1:
  + Name the guard window (bgo#710346).
  + Use new UPower API.
  + Expose min-backlight-stea (bgo#710380).
  + Don't focus the no-focus-window for globally active windows
    (bgo#710296).
  + Misc. fixes and cleanups: bgo#709776.
  + Updated translations.
- Drop mutter-use-new-upower-api.patch: fixed upstream.
* Thu Feb 20 2014 zaitor@opensuse.org
- Update to version 3.10.4:
  + Fix CSD titlebars being placed off-screen (bgo#719772).
  + Expose MetaWindow:skip-taskbar property (bgo#723307).
  + Fix legacy tray icons showing up blank (bgo#721596).
  + Fix configuration of cloned monitors (bgo#710610).
  + Use correct output property for backlight control (bgo#723606).
  + Bugs fixed: bgo#720630, bgo#723468, bgo#724258, bgo#724364.
  + Updated translations.
* Fri Feb 14 2014 fcrozat@suse.com
- Update mutter-bell.patch: correctly get gsetting from the right
  schema [FATE#316042]
* Wed Feb  5 2014 idonmez@suse.com
- Add mutter-bell.patch to make audible bell work out of the box.
  Implements FATE#316042
* Sat Jan 18 2014 zaitor@opensuse.org
- Update to version 3.10.3:
  + xrandr: Use "hotplug_mode_update" property (bgo#711216).
  + Don't focus the no-focus-window for globally active windows
    (bgo#710296).
  + Fix window group paint volume (bgo#719669).
  + Fix checks for KeyPress/ButtonPress (bgo#720545).
  + Fix problems with focus tracking (bgo#720558).
  + Don't leave focus on windows that are being unmanaged
    (bgo#711618).
  + Reduce server grabs (bgo#721345, bgo#721709).
  + Updated translations.
* Tue Dec 10 2013 mgorse@suse.com
- Add mutter-use-new-upower-api.patch: Support UPower 0.99.
* Thu Nov 14 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + Fix resize operations using mouse-button-modifier (bgo#710251).
  + Updated translations.
* Wed Oct 16 2013 dimstar@opensuse.org
- Update to version 3.10.1.1:
  + Don't assert that at least one output is connected
    (bgo#709009).
- Changes from version 3.10.1:
  + Don't apply fullscreen workarounds to CSD windows (bgo#708718).
  + Fix hangs during DND operations (bgo#709340).
  + Use nearest-pixel interpolation when possible (bgo#708389).
  + Fix tile previews getting stuck on right click during drags
    (bgo#704759).
  + Misc bug fixes: bgo#708420.
  + Updated translations.
* Wed Sep 25 2013 dimstar@opensuse.org
- Update to version 3.10.0.1:
  + Fix bug when a window changed size twice in a single frame;
    this can happen with GTK+ client-side decorations (bgo#708367).
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Tue Sep 17 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Don't create a dummy texture for the texture pipeline template
    (bgo#707458).
  + Remove holes generated by disabling the laptop lid
    (bgo#707473).
  + Don't require plugins to pass event to Clutter (bgo#707482).
  + Add support for more cursor types (bgo#707919).
  + Immediately fire idle watches that are already expired
    (bgo#707302).
  + Bugs fixed: bgo#707474, bgo#707563, bgo#707649, bgo#708070.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Drop man pages for removed utilities (bgo#706579).
  + Add support for idle tracking (bgo#706005).
  + Skip CRTC reconfigurations that have no effect (bgo#706672).
  + Ignore skip-taskbar hints on parentless dialogs (bgo#673399).
  + Don't save pixbuf data in user data (bgo#706777).
  + Don't queue redraws for obscured regions (bgo#703332).
  + Turn blending off when drawing entirely opaque regions
    (bgo#706930).
  + Check event timestamps before reconfiguring (bgo#706735).
  + Misc bug fixes: bgo#706582, bgo#706598, bgo#706787,
    bgo#706729, bgo#706825, bgo#707081, bgo#707090, bgo#707250,
    bgo#707267.
  + Updated translations.
* Thu Aug 22 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Add support for _GTK_FRAME_EXTENTS (bgo#705766).
  + Fix quick consecutive <super> presses breaking keyboard input
    (bgo#666101).
  + Work towards running as wayland compositor:
  - Add DBus API for display configuration (bgo#705670,
    bgo#706231, bgo#706233, bgo#706322, bgo#706382).
  - Add abstraction layer for cursor tracking (bgo#705911).
  - Add support for plugin modality under wayland (bgo#705917).
  + Disable GTK+ scaling (bgo#706388).
  + Disable blending while updating tower.
  + Misc bug fixes and cleanups: bgo#703332, bgo#704437,
    bgo#706207.
  + Updated translations.
- Add pkgconfig(upower-glib) and pkgconfig(gnome-desktop-3.0)
  BuildRequires: new dependencies.
- Drop now empty mutter-tools subpackage (empty, as the related
  utilities were removed upstream.
- Obsolete mutter-tools by the main package (not provided). This
  helps for clean updates.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 3.9.5:
  + Don't select for touch events on the stage (bgo#697192).
  + Don't queue redraws for obscured regions (bgo#703332).
  + Export timestamp of global keybinding events (bgo#704858).
  + Misc bug fixes and cleanups (bgo#703970).
* Wed Jul 10 2013 zaitor@opensuse.org
- Update to version 3.9.4:
  + Tweak window shadows (bgo#702141).
  + Ignore our own focus events for focus prediction (bgo#701017).
  + Add API to query if the stage is focused (bgo#700735).
  + Add API to query the monitor for a given position.
  + Don't force attached dialogs to be border-only (bgo#702764).
  + Allow slicing of backgrounds to avoid texture size limits
    (bgo#702283).
  + Miscellaneous bug fixes and cleanups: (bgo#701224, bgo#702564).
* Thu Jun 20 2013 dimstar@opensuse.org
- Update to version 3.9.3:
  + Ensure events are always reported to the grab window
    (bgo#701219).
  + Use new clutter_stage_set_paint_callback() function to prevent
    dropping frames with frame synced toolkits (bgo#698794).
* Tue May 28 2013 dimstar@opensuse.org
- Update to version 3.9.2:
  + Add meta_window_can_close() function (bgo#699269).
  + Add support for string-array preferences (bgo#700223).
  + Fix a potential race condition with _NET_WM_MOVERESIZE
    (bgo#699777).
  + Fix shade window action (bgo#693714).
  + Remove overlay_group (bgo#700735).
  + Improve tracking of the focus window (bgo#647706).
  + Add API to freeze/unfreeze the keyboard (bgo#697001).
  + Grab and emit a signal when XK_ISO_Next_Group is pressed
    (bgo#697002).
  + Other fixed bugs: bgo#699636, bgo#700735, bgo#697000.
  + Updated translations.
* Wed May  1 2013 dimstar@opensuse.org
- Update to version 3.9.1:
  + Fix miscellaneous memory leaks (bgo#698710).
  + Misc fixes and cleanups (bgo#698179, bgo#697758).
* Tue Apr 16 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Fix crash when getting default font (bgo#696814).
  + Fix ungrabbing of keybindings (bgo#697003).
  + Misc fixes and cleanups: bgo#697758.
  + Updated translations.
* Tue Mar 26 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Address major memory leak when changing backgrounds
    (bgo#696157).
  + Updated translations.
* Tue Mar 19 2013 zaitor@opensuse.org
- Update to version 3.7.92:
  + Build and improve reference docs (bgo#676856, bgo#695641,
    bgo#695935).
  + Add tracking of whether there are fullscreen windows
    (bgo#649748).
  + Bugs fixed: bgo#695269, bgo#695711, bgo#694046, bgo#695813,
    bgo#695881, bgo#676856, bgo#696053, bgo#682779, bgo#696089,
    bgo#696091, bgo#696087.
  + Updated translations.
* Tue Mar  5 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Fix windows being treated as remote after hostname changes
    (bgo#688716).
  + Add meta_window_get_all_monitors() (bgo#646861).
  + Add grab API for externally defined accelerators (bgo#643111).
  + Make session registration an explicit step (bgo#694876).
  + Avoid unnecessary stage redraws (bgo#694988, bgo#695006).
  + Misc fixes: bgo#694801, bgo#694725, bgo#694641, bgo#694393,
    bgo#678917, bgo#695093, bgo#694837, bgo#695135, bgo#694771,
    bgo#694321.
  + Updated translations.
* Wed Feb 20 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Support _NET_WM_OPAQUE_REGION (bgo#679901).
  + Add wrapper for XI2.3 pointer barriers (bgo#677215).
  + Update style of resize popups (bgo#692741).
  + Implement compositor <-> application frame synchronization
    (bgo#685463).
  + Handle animated backgrounds (bgo#682427).
  + Add a new window group for override-redirect windows
    (bgo#633620).
  + Pass on pointer events on guard window to Clutter (bgo#681540).
  + Show correct shortcut in window menus (bgo#694045).
  + Don't put minimized windows at the back of alt-tab
    (bgo#693991).
  + Misc bug fixes and cleanups: bgo#692679, bgo#693354,
    bgo#690581, bgo#693439, bgo#692718, bgo#693475, bgo#693482,
    bgo#693540, bgo#690580, bgo#680990, bgo#693833, bgo#693922,
    bgo#693854, bgo#694224.
  + Updated translations.
- Add pkgconfig(xi) BuildRequires: new dependency.
* Thu Feb 14 2013 dimstar@opensuse.org
- Update to version 3.7.5:
  + Don't allow multiline window titles (bgo#683056).
  + Make meta_window_located_on_workspace() public (bgo#691744).
  + Request XI2.3 (bgo#692877).
  + Add meta_window_set_icon_geometry() method (bgo#692997).
  + Require XFixes 5.0 (bgo#677215).
  + Change unredirection hints to match spec changes (bgo#693064).
  + Improve unredict heuristicts (bgo#683786).
  + Misc bug fixes and cleanups: bgo#691874, bgo#679901,
    bgo#692952, bgo#693042.
  + Updated translations.
- Drop mutter-correctly-create-new-pixmap.patch: fixed upstream.
* Thu Feb 14 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + Add support to bypass compositor hints (bgo#683020)
  + Make automaximization optional (bgo#680990)
  + Add method for checking if the application is responding
    (bgo#684340)
  + Expose the xinput opcode (bgo#690590)
  + Rebrand "minimize" as "hide" (bgo#682887)
  + Misc bug fixes and cleanups: bgo#690454, bgo#690573,
    bgo#690593, bgo#690956, bgo#691363, bgo#690609, bgo#690317,
    bgo#689263.
  + Updated translations.
- Drop BUILD_FROM_VCS logic, as it's not used anyway.
* Thu Feb 14 2013 zaitor@opensuse.org
- Update to version 3.7.3:
  + Fix maximized windows jumping to other monitors (bgo#556696)
  + Add 'switch-applications' keybinding (bgo#688913)
  + Add a convenience method to focus the default window
    (bgo#689652)
  + Increase typical icon size to 96 (bgo#689651)
  + Port to XInput2 (bgo#688779)
  + Give dynamic keybindings a keybinding action (bgo#682315)
  + Misc. fixes and cleanups (bgo#688777)
  + Updated translations.
- Drop mutter-stop-jumping-windows.patch: fixed upstream.
* Thu Feb 14 2013 dimstar@opensuse.org
- Update to version 3.7.2:
  + Fix spurious focus changes when showing desktop (bgo#686928)
  + MetaPluginManager: don't send events to Clutter twice
    (bgo#686406)
  + Add the ability to add shader hooks to MetaBackgroundActor
    (bgo#669798)
  + Only process keyboard mapping events for the core X keyboard
    (bgo#674859)
  + Import keybinding files from Metacity (bgo#687672)
  + Add compositor hook to process keybindings selectively
    (bgo#688202)
  + MetaBackgroundActor: add a setter for GLSL uniforms
    (bgo#682536)
  + Misc. fixes and cleanups: bgo#688182
  + Updated translations.
* Thu Feb 14 2013 dimstar@opensuse.org
- Update to version 3.7.1:
  + screen: Ignore num-workspaces when using dynamic workspaces
    (bgo#685439)
  + Updated translations.
* Thu Feb 14 2013 zaitor@opensuse.org
- Update to version 3.6.3:
  + Fix maximized windows jumping between monitors (bgo#556696).
  + Fix windows turning black when redirected again (bgo #693042).
  + Updated translations.
- Drop mutter-stop-jumping-windows.patch and
  mutter-correctly-create-new-pixmap.patch, fixed upstream.
* Fri Feb  8 2013 badshah400@gmail.com
- Add mutter-correctly-create-new-pixmap.patch to correctly create
  a new pixmap when redirecting a window again; patch taken from
  upstream git. Fixes bgo#693042.
* Mon Jan 21 2013 zaitor@opensuse.org
- Add mutter-stop-jumping-windows.patch, windows might in some
  cases jump from one monitor to an other, this patch fixes this.
  (bgo#556696).
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Only process keyboard mapping events for the core X keyboard
    (bgo#674859)
  + Updated translations.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Fix crash when opening large popup menus (bgo#681676)
  + window: Don't move the desktop window after monitor hotplug
    (bgo#681159)
  + Expose MetaPlugin to introspection (bgo#671098)
  + Optionally delay focus changes in focus-follows-mouse mode
    (bgo#678169)
  + Resize the guard window when the X screen is resized
    (bgo#670396)
  + display: Only manage the default X screen (bgo#648156)
  + Misc cleanups (bgo#587255)
  + Updated translations.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Updated translations.
* Wed Sep 19 2012 dimstar@opensuse.org
- Update to version 3.5.92:
  + screen: Allow NULL out arguments in meta_screen_get_size
  + display: Add API to set wm_name / wm_keybindings (bgo#671010)
  + Improve the not responding dialog (bgo#684306)
  + Misc. bugfixes
  + Updated translations.
* Fri Sep  7 2012 vuntz@opensuse.org
- Split a mutter-data subpackage where we put data files (gsettings
  schema, keybindings, etc.) that are needed by libmutter0:
  + Without this, gnome-shell would not run if mutter is not
    installed (which shouldn't be necessary).
  + Move the use of %%glib2_gsettings_schema_* macros from the main
    subpackage to mutter-data.
  + Add a Requires for mutter-data to libmutter0.
- Split a typelib-1_0-Meta-3_0 metapackage:
  + The typelib is private, but we have no other choice than a
    subpackage:
  - it makes no sense to ship it as part of the mutter subpackage
    (since gnome-shell would then install it)
  - we can't ship it as part of libmutter0 because of the fixed
    dependencies it has.
  + Of course, this is abusing the package conventions for
    typelibs.
  + Add a typelib-1_0-Meta-3_0 Requires to devel subpackage.
- Move ownership of %%{_libdir}/mutter/plugins/ directory to
  libmutter0, since gnome-shell will need this directory too.
* Tue Sep  4 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Fix subtracting unredirected windows from visible region
    (bgo#677116)
  + Minor improvements and bugfixes (bgo#682648, bgo#682993)
  + Updated translations.
* Sun Sep  2 2012 dimstar@opensuse.org
- Split out libmutter0 to follow SLPP (bnc#706930).
- Change mutter requires to libmutter0: it's all what's needed to
  develop against this library.
- Move /sbin/ldconfig calls from post/postun of the main package to
  libmutter0.
* Tue Aug 21 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Fix logic for handling translations of the windows group
    (bgo#681221)
  + Handle painting inside a Clutter clone (bgo#681953)
  + Update overlay-key on settings changes (bgo#681906)
  + Add keybinding for overlay-key (bgo#665547)
  + Minor fixes and improvements
  + Updated translations.
- Drop gnome-doc-utils-devel BuildRequires: no longer needed.
* Tue Aug  7 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + Fix flickering around windows when using window group
    (bgo#681221)
  + Updated translations.
* Tue Jul 17 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Make it possible to reimplement move-to-workspace keybindings
    from plugins (bgo#674104)
  + Add a preference to ignore hide-titlebar-when-maximized hint
    (bgo#678947)
  + window: Also use hide-titlebar-when-maximized when tiled
    (bgo#679290)
  + Center modal dialogs on their parent instead (bgo#674499)
  + Reduce amount of markup in translated messages (bgo#679660)
  + Fix focus problem after closing a window with
    focus-follows-mouse (bgo#675982)
  + Handle changes of the attach-modal-dialogs preference
    (bgo#679904)
  + Do not restore tiling on unmaximize (bgo#677565)
  + Bugs fixed: bgo#673824, bgo#679153)
  + Updated translations.
* Mon Jun 25 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + Simplify plugin system [bgo#676855]
  + meta-window-actor: Don't unredirect shaped windows [bgo#677657]
  + screen: Add new public meta_screen_get_current_monitor API
    [bgo#642591]
  + frames: Increase the size of resize corners [bgo#677669]
  + window: Make some window methods public [bgo#678126]
  + Fix crash when running mutter stand-alone [bgo#678238]
  + meta-window-actor: Fix potential crash in shaping code
    [bgo#677977]
  + Misc. fixes
  + Updated translations.
* Thu Jun  7 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + keybindings: Remove 'toggle-recording' binding [bgo#674376]
  + Switch to gtk-doc syntax [bgo#673752]
  + shaped-texture: never slice shape mask texture [bgo#674731]
  + Make Mutter stop relying on Cogl including a GL header
    [bgo#672711]
  + Make support for "XFree86" Xinerama mandatory [bgo#674727]
  + meta_window_move_frame(): fix crash when frame is NULL
    [bgo#675254]
  + Fix memory leaks [bgo#672640]
  + Code cleanups [bgo#671104, bgo#674876, bgo#676052]
  + Look for themes in XDG user data dir [bgo#675316]
  + Remove frame pixel caching [bgo#675111]
  + stack: Ignore keep-on-top property on maximized windows
    [bgo#673581]
  + Misc. fixes
  + Updated translations.
- Drop mutter-fix-crash-when-frame-is-NULL.patch: fixed upstream.
- Drop mutter-never-slice-shape-mask.patch: fixed upstream.
- Drop mutter-use-cogl-texrect-api.patch: fixed upstream.
* Thu May 31 2012 fcrozat@suse.com
- Add mutter-never-slice-shape-mask.patch,
  mutter-use-cogl-texrect-api.patch: Fix window texturing on
  hardware without ARB_texture_non_power_of_two (rh#813648,
  bgo#674731, bgo#672711).
* Sat May  5 2012 zaitor@opensuse.org
- Add mutter-fix-crash-when-frame-is-NULL.patch: fixes crashes in
  various extensions.
* Wed Apr 18 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + API change: the meta_display_add_keybinding() function added in
    3.4 wasn't usable from a GNOME Shell extension, so has been
    changed to take a GSettings object rather than the name of a
    schema [bgo#673014]
  + Don't try to auto-maximize not-maximizable windows; this fixes
    the problem with the Nautilus desktop window being
    mis-positioned when enabled [bgo#673566]
  + Fix a crash in the default plugin (not used in GNOME)
    [bgo#673809]
  + Make the <Super> key work when set as the mouse button modifier
    [bgo#662476]
  + Updated translations.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Fix crash when a full-screen window is opened [bgo#672797]
  + Fix memory leaks [bgo#672640]
  + Updated translations.
* Tue Mar 20 2012 dimstar@opensuse.org
- Update to version 3.3.92:
  + Automaximize large windows on map (bgo#671677).
  + When unmaximizing windows, make sure the unminimized size
    is signficantly less than the maximized size (bgo#671677).
  + Don't offer maximize option for windows larger than the screen
    (bgo#643606).
  + Always focus the window immediately underneath without
    restacking when closing a window (bgo#620744).
  + Avoid drawing shadows when two windows are tiled together
    (bgo#643075).
  + Remove tooltips for window decorations (bgo#645101)
  + Add org.gnome.mutter.dynamic-workspaces GSetting - when this is
    set to true, workspace counts are never saved to GSettings,
    avoiding pointless disk traffic for GNOME dynamic workspaces
    (bgo#671568).
  + Add ::grab-op-begin, ::grab-op-end signals to MetaDisplay
    (bgo#670658).
  + Add meta_display_get_ignored_modifier_mask() (bgo#665215).
  + Remove pointless wrapper methods on MetaPlugin (bgo#671103).
  + Fix frame drawing with 3.3.x GTK+ releases (bgo#671796).
  + Build fixes.
  + Bugs fixed: bgo#661256, bgo#667437, bgo#671087, bgo#671601,
    bgo#672374.
  + Updated translations.
* Thu Feb 23 2012 vuntz@opensuse.org
- Update to version 3.3.90:
  + Update for Cogl API changes
  + Bug fixes (including bgo#659643)
  + Build fixes
  + Updated translations.
- Change clutter-devel and gtk3-devel BuildRequires to
  pkgconfig(clutter-1.0) and pkgconfig(gtk+-3.0).
- Add explicit pkgconfig() BuildRequires: cairo, cogl-1.0, gio-2.0,
  pango.
* Mon Feb 20 2012 vuntz@opensuse.org
- Add explicit libSM-devel, libX11-devel, libXext-devel,
  libXinerama-devel, libXrandr-devel, pkgconfig(xcomposite),
  pkgconfig(xcursor), pkgconfig(xdamage), pkgconfig(xfixes),
  pkgconfig(xrender) BuildRequires: we need all of those, and some
  are not implicitly brought in after the big xorg-x11 packaging
  change.
* Wed Feb  8 2012 vuntz@opensuse.org
- Update to version 3.3.5:
  + MetaShapedTexture no longer is a ClutterTexture subclass
    [bgo#660941]
  + Add meta_shaped_texture_get_image() [bgo#660941]
  + Cleanups [bgo#657639]
  + Updated translations.
- Remove xz BuildRequires now that it comes for free in the build
  system.
- Split non-essential tools to a mutter-tools subpackage.
- Stop checking for non-supported versions of openSUSE (<= 11.1).
- Stop passing --disable-schemas-install to configure: there is no
  gconf schema anymore.
- Stop changing libexecdir in configure: there is no need for that.
* Fri Jan 20 2012 vuntz@opensuse.org
- Update to version 3.3.4:
  + Adapt to changes in GtkStateFlags
  + Redo properties for applications menu corresponding to GTK+
    changes - they are now _GTK_* not DBUS_*.
  + Fix crash on gnome-shell restart when a modal dialog is open
    [bgo#668299]
  + Code cleanup [bgo#666039]
  + Updated translations.
- Drop mutter-fix-build-latest-gtk3.patch: fixed upstream.
* Wed Jan 18 2012 vuntz@opensuse.org
- Add mutter-fix-build-latest-gtk3.patch: fix build caused by an
  API change in GTK+ 3.3.8.
* Thu Jan  5 2012 vuntz@opensuse.org
- Update to version 3.3.3:
  + Add keybindings for tiling to left or right [bgo#648700]
  + Support GTK+'s hide-titlebar-when-maximized hint [bgo#665617]
  + Load _DBUS_APPLICATION_ID, _DBUS_UNIQUE_NAME, _DBUS_OBJECT_PATH
    property [bgo#664851]
  + Handle changes to workspaces-only-on-primary GSetting
    [bgo#664853]
  + Don't use the Clutter default stage [bgo#664028]
  + Fix compilation with --disable-introspection [bgo#661871]
  + Fix problem where stage could end up mis-sized on startup with
    multiple monitors
  + Misc bug fixes [bgo#666015]
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Mon Dec 12 2011 vuntz@opensuse.org
- Drop mutter-clutter-1.10.patch: this actually breaks mutter as we
  need a clutter patch too, which is not ready yet.
- Pass --enable-compile-warnings=maximum to configure: the default
  is error, and we don't want to have -Werror in our CFLAGS.
* Tue Nov 22 2011 dimstar@opensuse.org
- Update to version 3.3.2:
  + Move from GConf to GSettings for preferences [bgo#635378]
  + meta_display_add_keybinding()/meta_display_remove_keybinding()
    added to allow creating new keybindings at runtime [bgo#663428]
  + Add suport for new _NET_WM_STATE_FOCUSED atom in _NET_WM_STATE
    to allow applications to draw unfocused windows differently
    [bgo#661427]
  + Add meta_window_move_resize_frame() to allow specifying the
    size and position of a window via the outside dimensions of the
    window frame.
  + Don't activate window tiling when moving in snap mode
    [bgo#662270]
  + Remove the ability to resize a window from the inner edge of
    the titlebar [bgo#660129]
  + Fix for deprecations in GTK+ [bgo#662574, bgo#662895]
  + Bugs fixed: bgo#662895, bgo#642652, bgo#660941, bgo#662225
  + Updated translations.
- Add mutter-clutter-1.10.patch: Fix build with clutter 1.10.
- Add pkgconfig(gsettings-desktop-schemas) BuildRequires: new
  dependency.
- Drop gconf-devel BuildRequires: migration to GSettings completed.
- Replace gconf schema packaging machinery with
  %%glib2_gsettings_schema_* macros.
* Tue Oct 18 2011 dimstar@opensuse.org
- Update to version 3.2.1:
  + Allow keyboard window switching (alt-Tab) during drag-and-drop
    [bgo#660457]
  + Don't add invisible resize borders to fullscreen windows
    [bgo#659854]
  + Fix crash when toplevel windows were set to unexpected window
    types [bgo#599988]
  + Correct problems with windows moving when restarting or
    switching window managers [bgo#660848]
  + Fix interaction of tiled windows with multiple monitors
    [bgo#657519]
  + Make meta_display_unmanage_screen() public [bgo#660848]
  + Fix problem with turning off window decorations on the fly
    [bgo#660773]
  + Fix spurious assertion failures with themes such as Nodoka
    [bgo#661286]
  + Misc bug fixes [bgo#660464, bgo#660854, bgo#662053]
  + Updated translations.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Fix _NET_WM_FRAME_EXTENTS not to include invisible borders
    [bgo#659848]
  + Fix application-specified window placement (-geometry) for
    invisible borders [bgo#659848]
  + Updated translations.
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + Fix bug with unredirecting full-screen windows on
    multi-monitor, notably affected gnome-screensaver [bgo#657869]
  + Disable top resizing of attached dialogs [bgo#657795]
  + Code cleanup
  + Misc bug fixes [bgo#658069, bgo#659266, bgo#659523, bgo#659477]
  + Updated translations.
* Thu Sep 15 2011 vuntz@opensuse.org
- Update to version 3.1.91.1:
  + Fix problem where certain application updates would get lost
    [bgo#657071]
  + Fix a problem where after resuming from the screensaver, things
    got slow [bgo#658228]
  + When a monitor is plugged or unplugged, keep existing windows
    on their current monitor [bgo#645408]
  + Remove 'Mutter' title from alerts such as
    "The window '%%s' is not responding"
  + Remove pointless warning:
    Received a _NET_WM_MOVERESIZE message for %%s; these
    messages lack timestamps and therefore suck.
  + Misc bug fixes
  + Build fixes
  + Updated translations.
* Thu Sep  1 2011 vuntz@opensuse.org
- Update to version 3.1.90.1:
  + Fix crash when no windows are open [bgo#657692]
  + Fix annotations for new strictness in gobject-introspection
  + Fix some errors with rounded frame drawing [bgo#657661]
- Changes from version 3.1.90:
  + Extend the draggable portion of window borders outside the
    visible frame for easy resizing with thin borders. (New
    draggable_border_width GConf key controls the total width of
    visible and invisible borders.) [bgo#644930]
  + Draw rounded window corners with antialising [bgo#628195]
  + Unredirect override-redirect fullscreen windows, such as
    full-screen 3D games to avoid any performance impact
    [bgo#597014]
  + Add :resizable and :above properties to MetaWindow.
    [bgo#653858]
  + Add MUTTER_DISABLE_FALLBACK_COLOR environment variable to allow
    visualizing places where a color is missing for gtk:custom()
    colors [bgo#656112]
  + Don't attach modal dialogs to special windows like the desktop;
    add meta_window_is_attached_dialog() [bgo#646761]
  + Make MetaBackgroundActor public, allow creating multiple
    instances (sharing a common texture), and add a :dim-factor
    property [bgo#656433]
  + Fix attached dialogs to not be resizable from the top and to be
    position correctly [bgo#656619]
  + Misc bug fixes [bgo#656335, bgo#657583]
  + Updated translations.
* Thu Jul 28 2011 vuntz@opensuse.org
- Update to version 3.1.4:
  + Use better, much more subtle shadow definitions [bgo#649374]
  + Add the ability to use named GTK+ colors in theme files as
    gtk:custom(name,fallback) [bgo#648709]
  + Port from GdkColor to GdkRGBA and from GtkStyle to
    GtkStyleContext [bgo#650586]
  + Try to fix window bindings using the Super key [bgo#624869]
  + Update to using more modern Cogl and Clutter APIs [bgo#654551,
    bgo#654729, bgo#654730, bgo#655064]
  + Fix for srcdir != builddir builds [bgo#624910]
  + Make handling of focus appearance for attached dialogs more
    robust [bgo#647712]
  + Misc bug fixes: bgo#642957, bgo#649374, bgo#650661, bgo#654489,
    bgo#654539.
* Sat Jul  2 2011 vuntz@opensuse.org
- Update to version 3.1.3.1:
  + Back API version down to "3.0": the change to Meta-3.1.gir was
    unintentional.
  + Updated translations.
* Fri Jul  1 2011 dimstar@opensuse.org
- Update to version 3.1.3:
  + bgo#645355: Support dark window theme variants for windows with
    a dark widget theme; this is selected by the _GTK_THEME_VARIANT
    property
  + bgo#635268: Don't draw a shadow under windows with an alpha-
    channel - this fixes transparency for GNOME Terminal
  + bgo#649315: Add a MetaWindow:wm-class property for notification
  + Add a MetaWindow:minimized property for notification
  + bgo#627880: Fix handling of unusual window shapes that Wine was
    setting causing some applications to draw wrong
  + bgo#653121: Improve replacing another compositor and being
    replaced: release compositor selection in the right order and
    wait for compositors that get it wrong.
  + bgo#652369: Remove behavior where left clicking on a window
    border with the titlebar offscreen gave the window menu
  + bgo#649202: Don't set the global default textdomain, since
    Mutter is a library as well as an application
  + Exit with the right (success or failure) exit status
  + Code cleanup
  + Other bugs fixed: bgo#649114, bgo#652507
  + Updated translations.
- Process %%{_datadir}/gnome/wm-properties/mutter-wm.desktop with
  suse_update_desktop_file to fix a rpmlint warning.
* Thu May 26 2011 dimstar@opensuse.org
- Update to version 3.0.2.1:
  + bgo#648828: When saving the session, use the "program name"
    rather than harcoding mutter, fixing session saving for
    gnome-shell.
- Changes from version 3.0.2:
  + bgo#647777: Fix a crash when running without XKB support
  + bgo#649500, bgo#649504: Fix smallish memory leaks
  + bgo#649299: Ignore mirrored monitors when listing monitors,
    fixing drag-and-drop problems in GNOME Shell
  + Don't allow side-by-side tiling of non-maximizable windows
    like dialogs and utility windows
  + bgo#648613: Fix interaction of _NET_WM_WINDOW_OPACITY with
    window effects, making it work again with GNOME Shell
  + Updated translations.
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 3.0.1:
  + bgo#647662: if WM_CLIENT_MACHINE isn't set, don't assume a
    window is remote; fixes behavior of Fox toolkit applications
    under GNOME Shell.
  + bgo#647613: fix cases where windows could get stuck drawing as
    focused after an attached modal dialog was closed.
  + Fix a bug where a window that is too big to be tiled
    side-by-side would behave strangely when using the gesture of
    dragging to the top to maximize.
  + Updated translations.
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Avoid crashing when you have a single window and try to move it
    between workspaces. bgo#642957.
  + Updated translations.
* Tue Mar 29 2011 fcrozat@novell.com
- Update to version 2.91.93:
  + bgo#645408: Fix bug where, when a monitor was hot-plugged, all
    workspaces would collapse to a single workspace. (There are
    still issues when a secondary monitor is hot-plugged to the
    left of the primary monitor).
  + bgo#645843: Fix a crash for the cycle_group action
  + bgo#636904: Fix misdrawing of window shadows on some focus
    changes.
  + bgo#645590: Export meta_get_replace_current_wm() to allow
    fixing a GNOME Shell bug with --replace.
  + Updated translations.
- Changes from version 2.91.92:
  + Add a workspaces_only_on_primary preferences. When set, this
    makes workspaces switching only apply to windows on the primary
    monitor, while windows on other monitors are unaffected.
  + Export API for monitor handling:
    MetaScreen::monitors-changed signal
    meta_screen_get_primary_monitor()
    meta_window_is_on_primary_monitor()
    meta_window_get_monitor()
    MetaWindow::window-entered-monitor,
    MetaWindow::window-left-monitor.
    meta_window_move_to_monitor()
  + Behavior improvements for attached modal dialogs:
  - Allow dragging dragging on the titlebar to move the  parent
  - Allow resizing
  - Constrain to be on the current monitor
  + Don't turn on XSMP autorestart
  + Combine libmutter-wm and libmutter-private into a single
    libmutter.
  + Export methods to move and resize windows
    meta_window_move(), meta_window_resize(),
    meta_window_move_frame().
  + Add a MUTTER_WM_CLASS_FILTER environment variable to allow
    existing windows to be ignored when performance testing.
  + Add a new compositor-based flash for visual bell
  + Fix bug where application specified values for properties like
    "skip taskbar" were sometimes ignored.
  + Bug fixes.
  + Build fixes
- Changes from version 2.91.91:
  + Build a libmutter-wm that contains all of the logic and that
    can be linked to to create custom executables. The mutter
    executable becomes a small stub linked to this library.
  + Move installed headers files into a meta/ subdirectory instead
    of polluting the toplevel namespace.
  + Remove various unused complications:
  - Ability to set the set of plugins via GConf
  - Plugin 'params'
  - meta_restart() and "mutter-message restart"
  + Don't exit when we are requested to exit via XSMP, assume we'll
    be killed along with the X server; this avoids visual artifacts
    from unmanaging windows when logging out.
  + Build fixes
- Changes from version 2.91.90:
  + Change <Alt>Above_Tab from being a cycle_group binding to
    a switch_group binding
  + Make plugin-loading failure fatal
  + Add 'position-changed' signal to MetaWindowActor
  + When 'live_hidden_previews' is enabled, position hidden
    windows to allow the creation of workspace previews
  + Fix bug with opacity of MetaBackgroundActor
- Fix BuildRequires to use pkgconfig(libcanberra-gtk3)
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Fri Feb 11 2011 fcrozat@novell.com
- Update to version 2.91.6:
  + Add meta_screen_override_window_layout() to let a plugin set
    the workspace layout
  + Add a 'size-changed' signal to MetaWindowActor
  + Add meta_window_actor_is_destroyed()
  + Fix problems with window tile previews when cancelling a move
  + Port theme elements that use GTK+ drawing to use
    GtkStyleContext instead of the deprecated GtkStyle.
  + Fix compiler warnings that were causing compilation failures
  + Misc bug fixes
  + Updated translations.
- Add support for source service checkout, with %%BUILD_FROM_VCS:
  + Add gnome-common BuildRequires.
  + Add call to ./autogen.sh.
- Change libcanberra-devel BuildRequires to
  pkgconfig(libcanberra-gtk).
- Remove --with-gtk=3.0 configure option: it's always built against
  GTK+ 3 now.
* Fri Jan 14 2011 vuntz@opensuse.org
- Update to version 2.91.5:
  + Add a Above_Tab key symbol that can be used in key bindings to
    mean the key above the Tab key. This is now the default binding
    for cycle_group in both Mutter and Metacity.
  + Add new frame states for tiled-on-the-left and
    tiled-on-the-right
  + Add new background drawing functions that can be defined in a
    theme for single buttons.
  + Draw the right button backgrounds for all custom button layouts
  + Remove vestigal --composite/--no-composite command line options
  + Fix building on GLES
  + Code cleanups
  + Bugs fixed: bgo#613124, bgo#626875, bgo#629282, bgo#635569,
    bgo#635683, bgo#635686, bgo#637330.
  + Updated translations.
* Fri Jan  7 2011 vuntz@opensuse.org
- Update to version 2.91.4:
  + Update for GTK+ 3 changes.
  + Support maximizing a window by dragging to the top of the
    screen in the same way you can tile by dragging to the edge of
    the screen.
  + Misc bug fixes.
  + Bugs fixed: bgo#630548, bgo#636083, bgo#636301, bgo#636302,
    bgo#636491, bgo#637802.
  + Updated translations.
- Drop mutter-gdk_functions.patch, mutter-gtk_states.patch,
  mutter-port-testgradients-to-gtk3.patch: they're all fixed
  upstream.
- Move %%{_libdir}/mutter/Meta-2.91.gir to devel subpackage.
* Tue Dec 14 2010 dimstar@opensuse.org
- Add patches from upstream git to fix build with latest gtk3L:
  + mutter-gdk_functions.patch: commit 8994e6
  + mutter-port-testgradients-to-gtk3.patch: commit d74659
  + mutter-gtk_states.patch: commit 544c8.
* Tue Nov 30 2010 dimstar@opensuse.org
- Update to version 2.91.3:
  + Better shadows:
  - Shadows can be different for different window types and focus
    states
  - Shadows are larger by default, especially for the currently
    active eindow
  - Shadows for attached modal dialogs and menus are drawn not to
    overlap the attachment point.
  - Shadows follow the shape of shaped windows
  + Optimization:
  - Avoid repainting in situations when windows are potentially
    restacked but aren't actually restacked.
  - Pay attention to partial stage repaints in obscured window
    calculations
  - Better optimization of painting obscured shadows; turn off
    shadows for maximized windows.
  - Move background repainting into Mutter; doing it here rather
    than in plugins allows not painting obscured parts of the
    background.
  + A new frame type 'attached' is added for attached modal dialogs
    and can be referenced in theme files with a theme version 3.2.
  + Fix updating key bindings when the keyboard layout changes
  + Bug fixes
  + Build fixes
  + Updated translations.
* Tue Nov  9 2010 vuntz@opensuse.org
- Update to version 2.91.2:
  + Remove support for GTK+ 2
  + Adapt to deprecation of size_request deprecation in GTK+
  + Include change from Metacity to fix confusion of mouse tracking
    when double-clicking on title bar
  + Fix bug with the the window menu getting stuck when you alt-Tab
  + Bugs fixed: bgo#633133, bgo#633352, bgo#633398, bgo#633401
  + Updated translations.
* Thu Oct 28 2010 vuntz@opensuse.org
- Update to version 2.91.1:
  + Default build is now GTK+ 3 build
  + Mutter namespace prefix is removed, in favor of consistent
    meta_ namespace prefixing. Naming changes:
    MutterWindow              => MetaWindowActor
    mutter_get_windows        => meta_get_window_actors
    mutter_plugin_get_windows => meta_plugin_get_window_actors
  + Add missing values in MetaKeyBindingAction; this fixes a
    problem where key binding lookup wasn't working properly for
    some key bindings.
  + Remove keysym parameter to
    meta_display_get_keybinding_action(); the function expected the
    default keysym for the keycode to always be passed
  + Clean up installed header files; in particular, theme-parser.h
    is merged into a new public-only theme.h and private internals
    are moved to theme-private.h.
  + Fix problems with antialiased rendering of themes
  + Fix problem with parsing color constants in themes
  + Build fixes
  + Miscellaneous bug fixes
  + Fixed bugs: bgo#628401, bgo#628520, bgo#631487, bgo#632116,
    bgo#632149, bgo#632155, bgo#632474, bgo#632494.
  + Updated translations.
* Thu Oct 14 2010 vuntz@opensuse.org
- Remove explicit Requires for clutter-devel and gtk2-devel in
  devel package: they will automatically be added the pkgconfig()
  way.
* Tue Oct  5 2010 vuntz@opensuse.org
- Update to version 2.91.0:
  + Enable side-by-side tiling via a gesture of dragging to the
    left or right edge of the screen. (enabled with an
    off-by-default GConf key)
  + Allow breaking out of maximization/tiling using a
    alt-middle-button window resize
  + Add the ability to have modal dialogs attached to their parent
    window (enabled with an off-by-default GConf key)
  + Draw with Cairo rather than GDK
  + Add compatibility for changes in GTK+ 3
  - libmutter-private is now only installed for GTK+ 3 builds
  - Theme parts of libmutter-private API are changed to take
    cairo_t rather than GdkDrawable
  + Update introspection build and annotations for new behavior of
    g-ir-scanner
  + Fix bug that caused window menu options not to work
  + Fix misbehavior of Wine windows
  + Fix crashes from missing error traps
  + Build fixes
  + Misc bug fixes
  + Cleanups
  + Updated translations.
- Drop mutter-gdk-cairo.patch, mutter-no-gdk_display.patch,
  mutter-gdk-keys.patch: fixed upstream.
* Sat Sep 18 2010 vuntz@opensuse.org
- Add mutter-no-gdk_display.patch: stop using gdk_display that got
  removed in recent GTK+ 3 versions.
- Add mutter-gdk-keys.patch: update the code after some API changes
  in GDK 3.
* Thu Sep  2 2010 dimstar@opensuse.org
- Add mutter-gdk-cairo.patch: replace GDK Drawing API with cairo.
  This fixes building with GTK3 2.90.6.
* Wed Sep  1 2010 vuntz@opensuse.org
- Drop gir-repository BuildRequires: the introspection files that
  were needed from there are now directly with the appropriate
  libraries.
* Fri Jul 16 2010 dimstar@opensuse.org
- Update to 2.31.5:
  + Support building with GTK+ 3.0
  + Remove deprecated usages for compatibility with GTK+ 3.0
  + Export a boxed type for MetaRectangle
  + Allow disabling -Werror with --enable-compile-warnings=yes
  + Build fixes
- Build against GTK+ 3: use gtk3-devel BuildRequires instead of
  gtk2-devel and pass --with-gtk=3.0 to configure.
* Mon Jul  5 2010 dimstar@opensuse.org
- Update to version 2.31.4:
  + Clean up MutterPlugin effect interface
  + Track damage as the bounding box, a significant optimizations
    for rapidly drawing clients
  + Add meta_window_is_remote()
  + Add meta_add_debug_topic() for turning on logging of specific
    topics
  + Fix bug with window unmaximization
  + Bugs fixed:
  - bgo#611838: expose sub-stage redraws by streaming raw updates
    to ClutterX11TexturePixmap
  - bgo#620585: Add meta_window_is_remote
  - bgo#620860: function ‘meta_display_open’
  - bgo#621082: MutterPluginManager should call
    plugin->switch_workspace, when screen doesn't have any
    window. Or function should be renamed.
  - bgo#621413: Maximize/Unmaximize not behaving properly for
    some non-gnome based programs
  + Updated translations.
* Fri May 28 2010 dimstar@opensuse.org
- Update to version 2.31.2:
  + Theme enhancements
  - Add a flexible version mechanism for themes -
    metacity-theme-3.xml is now supported, and can include
    version="> 3.2" type attributes on the root element or
    any subelement.
  - Add frame_x_center/frame_y_center variables
  - Allow a theme to turn on title ellipsization
  + Performance enhancements:
  - Stream raw damage updates to ClutterX11TexturePixmap
    to enable partial stage updates when windos change
  - Don't trap XErrors in meta_compositor_process_event
  + Add meta_prefs_override_preference_location(); this allows
    a plugin like GNOME Shell to redirect preferences to a
    plugin-specific location.
  + Support a _MUTTER_HINTS window property; this is a string
    property holding key-value pairs with plugin-specific
    interpretation
  + Build with GSEAL_ENABLE
  + Add meta_display_get_leader_window()
  + Add meta_display_sort_windows_by_stacking
  + Export
    meta_display_get_last_user_time()
    meta_display_xserver_time_is_before()
    meta_window_foreach_ancestor(),
    meta_window_foreach_transient()
    meta_window_lower()
    meta_window_raise()
    meta_window_set_demands_attention()
    meta_window_unset_demands_attention()
  + Bug fixes
  + Build fixes
- Drop mutter-gcc45.patch, fixed upstream.
* Fri Mar 19 2010 dimstar@opensuse.org
- Update to version 2.29.1:
  + Support and require Clutter 1.2
  + Add meta_display_get_keybinding_action()
  + Add meta_window_get_wm_class_instance()
  + Remove workaround for bug fixed in intel driver Q2/2009 release
  + Build fixes
  + Updated translations.
- Drop upstreamed patch mutter-cogl_texture-deprecated.patch.
* Thu Feb 25 2010 dominique.leuenberger@tmf-group.com
- Refresh mutter-cogl_texture-deprecated.patch to also take care
  of cogl_material_[un]ref, which is deprecated with clutter
  1.1.14.
* Fri Feb 19 2010 dimstar@opensuse.org
- Update to version 2.29.0:
  + Improve appearance of scaled down windows using mipmap
    emulation
  + Added signals: MetaDisplay::window-created,
    MetaDisplay::window-marked-urgent,
    MetaDisplay::window-demands-attention, MetaWindow::unmanaged
  + Added properties: MetaWindow:demands-attention,
    MetaWindow:urgent, MetaWindow:maximized-horizontally,
    MetaWindow:maximized-vertically
  + Fix nasty crash when workspace "struts" changed during a window
    move
  + Bug fixes
  + Build fixes
  + Merge Metacity changes since 2.26. Includes themable sound
    support via libcanberra
- BuildRequire libcanberra-devel for new themable sounds.
- Add mutter-cogl_texture-deprecated.patch to fix build against
  clutter 1.1.12. Reported upstream as bgo#610454.
* Wed Feb  3 2010 vuntz@opensuse.org
- Add mutter-fix-build.patch and mutter-gl-no-cgl.patch to fix the
  build with recent introspection data and with recent clutter.
* Wed Dec  2 2009 vuntz@opensuse.org
- Update the way we remove the ha, la, ig locales for old versions
  of openSUSE.
* Thu Oct  8 2009 vuntz@opensuse.org
- Update to version 2.28.0:
  + Add meta_window_get_stable_sequence
  + mutter_begin_modal_for_plugin(): Check result of
    XGrabKeyboard()
  + mutter_plugin_get_windows returns *Mutter*Window, not
    MetaWindow
  + Remove MetaAltTabHandler
  + Use "later functions" to fix priority problems with Clutter
    redraw
  + Create the dummy timeline for repaint laters with an "infinite"
    duration
  + Added meta_window_get_transient_for_as_xid()
  + Added workareas-changed signal
  + Work around race condition focusing a window on a different
    workspace
  + Updated translations.
* Wed Sep 16 2009 lmedinas@opensuse.org
- Update to version 2.27.5:
  + Fix bug in GConf schemas where the overview activation key was
    specified as '<Super_L>' not 'Super_L'.
  + Updated translations.
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 2.27.4:
  + See http://git.gnome.org/cgit/mutter/log/?id=2.27.4
  + Add new API for plugins.
  + Refer to monitors as "monitors" rather than "xineramas"
  + Fix broken META_IS_SCREEN macro
  + Fix owner and applyto for /apps/mutter/general/overlay_key
    schema
  + Make user-time a GObject property
  + Use meta_window_set_user_time for setting user time
    consistently
  + Export a _GNOME_WM_KEYBINDINGS property
  + Build fixes.
  + Updated translations.
* Sat Aug 29 2009 vuntz@novell.com
- Update to version 2.27.3:
  + See http://git.gnome.org/cgit/mutter/log/?id=2.27.3
  + Do not run effects during WM startup
  + Remove meta_errors_register_foreign_display()
  + Check the opacity of the right actor
  + Always notify on title property change
  + Avoid accessing freed memory when being replaced
  + Fix alt-tab with urgent windows
  + Enforce a policy of single-handling of key events
  + Add a modal mode for plugins
  + Fix custom-alt-tabs for single-handling of key events
  + Check for NULL in meta_screen_tab_popup_destroy() instead of
    asserting
  + Unminimize windows passed to
    meta_workspace_activate_with_focus()
  + Add new API for plugins.
  + Various minor fixes.
  + Updated translations.
* Wed Aug 12 2009 vuntz@novell.com
- Update to version 2.27.2:
  + Fix confusion about MetaPreview in introspection build
  + Queue redraws on MutterWindow's MutterShapedTexture
  + Pass event to clutter when the plugin doesn't have
    xevent_filter
  + Build using Clutter 1.0
  + Don't explicitly set the size of the MutterWindow texture
  + Pass through all scroll events to compositor
  + Tolerate all standard _NET_WM_WINDOW_TYPE types for managed
    windows
  + Set up correct initial values for override redirect windows
  + Add focus-window property to MetaDisplay
  + Accessors for pid and name of client machine associated with
    MetaWindow
  + Added MetaWindow::window-type property
  + Added public prototype for
    meta_window_is_ancestor_of_transient()
  + Avoid overflow when window maximum size hint is set to INT_MAX
  + Fix check for zero-sized textures in MutterShaped texture
  + Remove deprecated glib/gtk symbols
  + Handle FocusIn events for override redirect windows correctly
  + Elimitate use of arithmetic expansion for portability
  + Don't allow override-redirect windows to be META_WINDOW_NORMAL
  + Free MutterWindow description string in finalize() not
    dispose()
  + Take extra reference on the texture inside MutterWindow
  + Use correct timestamp for focus stealing prevention
  + Export meta_screen_get_startup_sequences, add change signal
  + Fix use of uninitialized memory in edge-resistance.c
  + Updated translations.
- Drop mutter-build-fix.patch: fixed upstream.
- Drop mutter-clutter-1.0.patch: fixed upstream.
- Remove gnome-common BuildRequires and gnome-autogen.sh call.
* Mon Aug  3 2009 vuntz@novell.com
- Add mutter-clutter-1.0.patch to fix build with clutter 1.0.
* Tue Jul 21 2009 vuntz@novell.com
- Update to version 2.27.1, first official tarball.
- Add mutter-build-fix.patch to fix build.
* Thu May 14 2009 vuntz@novell.com
- Update to git version as of May 14th.
* Mon May  4 2009 vuntz@novell.com
- Add tarball created from git, and mutter-rename.patch.bz2 to make
  mutter parallel-installable with metacity.
* Fri May  1 2009 vuntz@novell.com
- Initial package, based on the metacity package.
